(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1786332,      36970]
NotebookOptionsPosition[   1785046,      36927]
NotebookOutlinePosition[   1785388,      36942]
CellTagsIndexPosition[   1785345,      36939]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}},
 ExpressionUUID -> "f7d0a75d-e567-40fa-85a9-812893852122"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Ultrasensitivit\[ADoubleDot]t"
}], "Subtitle",
 CellChangeTimes->{
  3.670321495640956*^9, 3.670402706588908*^9, {3.670427551024929*^9, 
   3.670427553031043*^9}, 3.6704872223864946`*^9, 3.67049006284297*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549],
 ExpressionUUID -> "69e382ef-66a6-47b8-b506-8bdae007e1c0"],

Cell[TextData[{
 "In diesem ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs werden wir ein extern entwickeltes Paket vorstellen, das ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ein sehr gutes Fundament f\[UDoubleDot]r Untersuchungen an der \
Schnittstelle von Bioinformatik und Systembiologie zur Verf\[UDoubleDot]gung \
stellt: die von Nikolaus Sonnenschein an der ",
 StyleBox["University of California",
  FontSlant->"Italic"],
 ", San Diego, entwickelteMASS-Toolbox",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[".", "37"], TraditionalForm]],
  ExpressionUUID -> "e366058b-9d0b-4e58-92a0-bcf06ecbccfe"],
 "\n\nDas Paket ist unter der Internetseite \
github.com/opencobra/MASS-Toolbox/releases verf\[UDoubleDot]gbar. Nach \
Entpacken der zip-Datei installiert man das Paket einfach durch Ausf\
\[UDoubleDot]hren der ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Datei Installer.nb. Eine genaue Erl\[ADoubleDot]uterung findet sich unter: \
www.youtube.com/watch?v=cXOArNFLI4s \n\nDie Toolbox kann nun wie jedes andere \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Paket geladen werden:"
}], "Text",
 CellChangeTimes->{{3.6774811286774197`*^9, 3.6774811364150333`*^9}, {
   3.677481186304921*^9, 3.677481191703531*^9}, 3.6774812290977964`*^9},
 ExpressionUUID -> "c0de0029-cadb-4d52-a4c7-5bb64e3bbafd"],

Cell[BoxData[{
 RowBox[{"<<", "Toolbox`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Toolbox`Style`"}]}], "Input",
 CellChangeTimes->{{3.614049483453651*^9, 3.614049492724607*^9}},
 ExpressionUUID -> "5f511753-5f2b-40fb-9e54-5e576e591293"],

Cell["\<\
Durch die MASS-Toolbox hat man z.B. Zugriff auf die gro\[SZ]e Zahl unter \
biomodels.org verf\[UDoubleDot]gbaren, im SBML-Format abgelegten \
mathematischen Modelle zellul\[ADoubleDot]rer Prozesse. Die MASS-Toolbox ist \
damit eine elegante und einfache Schnittstelle zur Systems Biology Markup \
Language (SBML), dem wichtigsten Standard mathematischer Modelle in der \
Systembiologie.

Wir werden hier die im vorliegenden Kapitel bereits ausf\[UDoubleDot]hrlich \
diskutierte MAPK-Kaskade n\[ADoubleDot]her untersuchen. Das Modell von Huang \
und Ferrell (1996) ist unter der Nummer BIOMD0000000009 in biomodels.org \
abgelegt. Es kann mit dem folgenden Befehl geladen werden:\
\>", "Text",
 CellChangeTimes->{{3.677481290717905*^9, 3.6774813008015227`*^9}, 
   3.6774813411441936`*^9, 3.677481429222948*^9, 3.6774855965293636`*^9},
 ExpressionUUID -> "55159997-7dc9-498b-806b-0bbdf1027a3e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"model", "=", 
  RowBox[{"biomodel2model", "[", "\"\<BIOMD0000000009\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.6140494981212254`*^9, 3.614049541668911*^9}, 
   3.6166460651136923`*^9, 3.6166461318847427`*^9, 3.6169915484904957`*^9},
 ExpressionUUID -> "c015d74e-aafc-42fd-9851-469cf16e5aa0"],

Cell[BoxData[
 TagBox[
  DynamicModuleBox[{Typeset`var$$ = 1}, 
   InterpretationBox[
    TagBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          
          PopupMenuBox[Dynamic[Typeset`var$$], {1->"\<\"Overview\"\>", 
           2->"\<\"Stoichiometry matrix\"\>", 3->"\<\"Reactions\"\>", 
           4->"\<\"Rates\"\>", 5->"\<\"ODE\"\>", 6->"\<\"Constraints\"\>", 
           7->"\<\"Initial conditions\"\>", 8->"\<\"Parameters\"\>", 
           9->"\<\"GPR\"\>", 10->"\<\"Pathway map\"\>", 
           11->"\<\"Nullspace\"\>", 12->"\<\"Left Nullspace\"\>", 
           13->"\<\"Notes\"\>"},
           DefaultBaseStyle->"MenuViewLabel",
           Enabled->Automatic],
          Alignment->Left,
          StripOnInput->False]},
        {
         ItemBox[
          StyleBox[
           PaneSelectorBox[{1->
            PaneBox[
             StyleBox[
              TagBox[GridBox[{
                 {"\<\"Number of species(rows):\"\>", "22"},
                 {"\<\"Number of columns(reactions):\"\>", "20"},
                 {"\<\"Number of exchange reactions:\"\>", "0"},
                 {"\<\"Number of irreversible reactions:\"\>", "10"},
                 {"\<\"Matrix rank:\"\>", "15"},
                 {"\<\"Dimensions null space: \"\>", "5"},
                 {"\<\"Dimensions left null space: \"\>", "7"},
                 {"\<\"Number of parameters\"\>", "32"},
                 {"\<\"Number of custom rate equations\"\>", "20"},
                 {"\<\"Number of equilibrium constants:\"\>", "0"},
                 {"\<\"Number of forward rate constants:\"\>", "0"},
                 {"\<\"Number of initial concentrations:\"\>", "22"},
                 {"\<\"Number of genes:\"\>", "0"},
                 {"\<\"Number of proteins:\"\>", "0"}
                },
                AutoDelete->False,
                GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
                    GrayLevel[0.99], 
                    RGBColor[0.87, 0.94, 1]}}},
                
                GridBoxDividers->{
                 "Columns" -> {True, {}, True}, "Rows" -> {{True}}},
                
                GridBoxItemSize->{
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
               "Grid"],
              StripOnInput->False,
              FontSize->12],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 2->
            TemplateBox[{GraphicsBox[
               RasterBox[CompressedData["
1:eJztk8EJwzAMRQ1ZofSeSbpDRwj03NUzQlOKLp9+2sQysaz/wLzYYCFF8rw8
74+plHLd1mVb7+8P621MY31sj+e/4rF7/8Y5K35UY91sj+ey3KMNzfN3Y91s
j+fRXVsX3jsaRz7XRrb5j2pD/ZJlva/RbOj/y542ep+rKHlms+HVFwaLfzTf
VvHlfTZazY93PnIuG5rPXDa8+i73aYbX+2odX/Mv15iRff57NeL9rmW5xsjo
88mIkn82M9SvqH4BozOOdQ==
                "], {{0, 0}, {20, 22}}, {0, 1}], 
               BaseStyle -> {
                FontFamily -> "Helvetica", FontSize -> Scaled[0.015]}, Frame -> 
               True, FrameLabel -> {None, None}, FrameTicks -> {{{{17.5, 
                    FormBox["5", TraditionalForm]}, {12.5, 
                    FormBox["10", TraditionalForm]}, {7.5, 
                    FormBox["15", TraditionalForm]}, {2.5, 
                    FormBox["20", TraditionalForm]}}, {{21.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1", "compartment"], Editable -> False, 
                    Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1", "compartment"], Editable -> False, 
                    Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["E1", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {20.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2", "compartment"], Editable -> False, 
                    Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2", "compartment"], Editable -> False, 
                    Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["E2", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {19.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["K", "compartment"], Editable -> False, 
                    Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["K", "compartment"], Editable -> False, 
                    Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["K", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {18.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KK", "compartment"], Editable -> False, 
                    Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KK", "compartment"], Editable -> False, 
                    Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KK", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {17.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KKPase", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {16.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KKPase_P_KK", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {15.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KPase", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {14.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_P_K", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_P_K", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KPase_P_K", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {13.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_K", "compartment"], Editable -> False, 
                    Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_K", "compartment"], Editable -> False, 
                    Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["P_K", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {12.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KK", "compartment"], Editable -> False,
                     Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KK", "compartment"], Editable -> False,
                     Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["P_KK", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {11.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["P_KKK", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {10.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_KK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_KK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["P_KKK_KK", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {9.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_K", "compartment"], Editable -> False,
                     Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_K", "compartment"], Editable -> False,
                     Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["PP_K", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {8.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_K", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_K", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["PP_KK_K", "compartment"]], "Tooltip"]& ],
                     TraditionalForm]}, {7.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_P_K", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_P_K", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["PP_KK_P_K", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {6.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1_KKK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["E1_KKK", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {5.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2_P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2_P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2_P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2_P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["E2_P_KKK", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {4.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKK", "compartment"], Editable -> False, 
                    Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKK", "compartment"], Editable -> False, 
                    Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KKK", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}, {3.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KKPase_PP_KK", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {2.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_PP_K", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_PP_K", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["KPase_PP_K", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {1.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["P_KKK_P_KK", "compartment"]], 
                    "Tooltip"]& ], TraditionalForm]}, {0.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    StyleBox[
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False], StandardForm], StandardForm, 
                    Editable -> True], FontSize -> Scaled[0.01], StripOnInput -> 
                    False], 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]], Annotation[#, 
                    TraditionalForm[
                    Toolbox`species["PP_KK", "compartment"]], "Tooltip"]& ], 
                    TraditionalForm]}}}, {{{0.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r1a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKK", "compartment"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r1a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r1a", {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["KKK", "compartment"]}, {
                    Toolbox`species["E1_KKK", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r1a", {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["KKK", "compartment"]}, {
                    Toolbox`species["E1_KKK", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {1.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r1b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1_KKK", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E1", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r1b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r1b", {
                    Toolbox`species["E1_KKK", "compartment"]}, {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r1b", {
                    Toolbox`species["E1_KKK", "compartment"]}, {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {2.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r2a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2_P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2_P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r2a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r2a", {
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["E2_P_KKK", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r2a", {
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["E2_P_KKK", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {3.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r2b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2_P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2_P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["E2", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKK", "compartment"], Editable -> False, 
                    Selectable -> False]}]}], 
                    StyleBox["r2b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r2b", {
                    Toolbox`species["E2_P_KKK", "compartment"]}, {
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["KKK", "compartment"]}, {1, 1, 1}, False],
                     Editable -> False, Selectable -> False], StandardForm], 
                    StandardForm, Editable -> True]], Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r2b", {
                    Toolbox`species["E2_P_KKK", "compartment"]}, {
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["KKK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {4.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r3a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KK", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r3a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r3a", {
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["P_KKK_KK", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r3a", {
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["P_KKK_KK", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {5.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r3b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_KK", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KK", "compartment"], Editable -> False,
                     Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r3b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r3b", {
                    Toolbox`species["P_KKK_KK", "compartment"]}, {
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r3b", {
                    Toolbox`species["P_KKK_KK", "compartment"]}, {
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {6.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r4a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KK", "compartment"], Editable -> False,
                     Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r4a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r4a", {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["P_KK", "compartment"]}, {
                    Toolbox`species["KKPase_P_KK", "compartment"]}, {1, 1, 1},
                     True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r4a", {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["P_KK", "compartment"]}, {
                    Toolbox`species["KKPase_P_KK", "compartment"]}, {1, 1, 1},
                     True]], "Tooltip"]& ], TraditionalForm]}, {7.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r4b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KK", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r4b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r4b", {
                    Toolbox`species["KKPase_P_KK", "compartment"]}, {
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["KKPase", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r4b", {
                    Toolbox`species["KKPase_P_KK", "compartment"]}, {
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["KKPase", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {8.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r5a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KK", "compartment"], Editable -> False,
                     Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r5a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r5a", {
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["P_KKK_P_KK", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r5a", {
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["P_KKK_P_KK", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {9.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r5b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK_P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK_P_KK", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KKK", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r5b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r5b", {
                    Toolbox`species["P_KKK_P_KK", "compartment"]}, {
                    Toolbox`species["P_KKK", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r5b", {
                    Toolbox`species["P_KKK_P_KK", "compartment"]}, {
                    Toolbox`species["P_KKK", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {10.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r6a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r6a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r6a", {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["KKPase_PP_KK", "compartment"]}, {1, 1, 
                    1}, True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r6a", {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["KKPase_PP_KK", "compartment"]}, {1, 1, 
                    1}, True]], "Tooltip"]& ], TraditionalForm]}, {11.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r6b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase_PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase_PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KKPase", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_KK", "compartment"], Editable -> False,
                     Selectable -> False]}]}], 
                    StyleBox["r6b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r6b", {
                    Toolbox`species["KKPase_PP_KK", "compartment"]}, {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["P_KK", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r6b", {
                    Toolbox`species["KKPase_PP_KK", "compartment"]}, {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["P_KK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {12.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r7a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["K", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_K", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r7a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r7a", {
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["PP_KK_K", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r7a", {
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["PP_KK_K", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {13.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r7b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_K", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_K", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r7b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r7b", {
                    Toolbox`species["PP_KK_K", "compartment"]}, {
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r7b", {
                    Toolbox`species["PP_KK_K", "compartment"]}, {
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {14.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r8a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_K", "compartment"], Editable -> False, 
                    Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_P_K", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r8a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r8a", {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["P_K", "compartment"]}, {
                    Toolbox`species["KPase_P_K", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r8a", {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["P_K", "compartment"]}, {
                    Toolbox`species["KPase_P_K", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {15.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r8b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_P_K", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["K", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r8b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r8b", {
                    Toolbox`species["KPase_P_K", "compartment"]}, {
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["KPase", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r8b", {
                    Toolbox`species["KPase_P_K", "compartment"]}, {
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["KPase", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {16.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r9a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_K", "compartment"], Editable -> False, 
                    Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_P_K", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r9a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r9a", {
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["PP_KK_P_K", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r9a", {
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["PP_KK_P_K", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {17.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r9b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK_P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK_P_K", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_K", "compartment"], Editable -> False,
                     Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_KK", "compartment"], Editable -> 
                    False, Selectable -> False]}]}], 
                    StyleBox["r9b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r9b", {
                    Toolbox`species["PP_KK_P_K", "compartment"]}, {
                    Toolbox`species["PP_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r9b", {
                    Toolbox`species["PP_KK_P_K", "compartment"]}, {
                    Toolbox`species["PP_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}, {18.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r10a\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["PP_K", "compartment"], Editable -> False,
                     Selectable -> False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_PP_K", "compartment"], Editable -> 
                    False, Selectable -> False]}], 
                    StyleBox["r10a", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r10a", {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["PP_K", "compartment"]}, {
                    Toolbox`species["KPase_PP_K", "compartment"]}, {1, 1, 1}, 
                    True], Editable -> False, Selectable -> False], 
                    StandardForm], StandardForm, Editable -> True]], 
                    Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r10a", {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["PP_K", "compartment"]}, {
                    Toolbox`species["KPase_PP_K", "compartment"]}, {1, 1, 1}, 
                    True]], "Tooltip"]& ], TraditionalForm]}, {19.5, 
                    FormBox[
                    TagBox[
                    TooltipBox[
                    RotationBox[
                    StyleBox[
                    "\"r10b\"", FontSize -> Scaled[0.01], StripOnInput -> 
                    False], BoxRotation -> 1.5707963267948966`], 
                    TagBox[
                    FormBox[
                    InterpretationBox[
                    OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase_PP_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase_PP_K", "compartment"], Editable -> 
                    False, Selectable -> False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["KPase", "compartment"], Editable -> 
                    False, Selectable -> False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True], 
                    StyleBox["compartment", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`species["P_K", "compartment"], Editable -> False, 
                    Selectable -> False]}]}], 
                    StyleBox["r10b", 
                    RGBColor[0, 0, 0], StripOnInput -> False, 
                    ShowSyntaxStyles -> False, AutoSpacing -> False, 
                    ZeroWidthTimes -> True]], 
                    Toolbox`reaction["r10b", {
                    Toolbox`species["KPase_PP_K", "compartment"]}, {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["P_K", "compartment"]}, {1, 1, 1}, False],
                     Editable -> False, Selectable -> False], StandardForm], 
                    StandardForm, Editable -> True]], Annotation[#, 
                    StandardForm[
                    Toolbox`reaction["r10b", {
                    Toolbox`species["KPase_PP_K", "compartment"]}, {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["P_K", "compartment"]}, {1, 1, 1}, 
                    False]], "Tooltip"]& ], TraditionalForm]}}, {{4.5, 
                    FormBox["5", TraditionalForm]}, {9.5, 
                    FormBox["10", TraditionalForm]}, {14.5, 
                    FormBox["15", TraditionalForm]}, {19.5, 
                    FormBox["20", TraditionalForm]}}}}, GridLinesStyle -> 
               Directive[
                 GrayLevel[0.5, 0.4]], ImageSize -> {{800}, {450}}, 
               Method -> {
                "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> 
                 Automatic, "DefaultPlotStyle" -> Automatic, "DomainPadding" -> 
                 Scaled[0.02], "RangePadding" -> Scaled[0.05]}],FormBox[
               FormBox[
                
                TemplateBox[{
                 "\"\\!\\(\\*SubscriptBox[\\(S\\), \\(i, j\\)]\\) = 0\"", 
                  "\"\\!\\(\\*SubscriptBox[\\(S\\), \
\\(\\(i\\)\\(,\\)\\(j\\)\\(\\\\ \\)\\)]\\)> 0\"", 
                  "\"\\!\\(\\*SubscriptBox[\\(S\\), \
\\(\\(i\\)\\(,\\)\\(j\\)\\(\\\\ \\)\\)]\\)< 0\""}, "SwatchLegend", 
                 DisplayFunction -> (FormBox[
                   StyleBox[
                    StyleBox[
                    PaneBox[
                    TagBox[
                    GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    GrayLevel[1]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 1, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0, 0]], 
                    RectangleBox[{0, 0}, {10, 10}, "RoundingRadius" -> 0]}, 
                    AspectRatio -> Full, ImageSize -> {10, 10}, 
                    PlotRangePadding -> None, ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.5}}}], "Grid"]}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                    False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                    GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}],
                     "Grid"], Alignment -> Left, AppearanceElements -> None, 
                    ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
                    "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
                    FontFamily -> "Arial"}, Background -> Automatic, 
                    StripOnInput -> False], TraditionalForm]& ), 
                 InterpretationFunction :> (RowBox[{"SwatchLegend", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[1]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[1], Editable -> False, Selectable -> False], 
                    ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 1, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0.6666666666666666, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 1, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 1, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 1, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{#, ",", #2, ",", #3}], "}"}]}], "]"}]& ), 
                 Editable -> True], TraditionalForm], TraditionalForm]},
             "Legended",
             DisplayFunction->(GridBox[{{
                 TagBox[
                  ItemBox[
                   PaneBox[
                    TagBox[#, "SkipImageSizeLevel"], 
                    Alignment -> {Center, Baseline}, BaselinePosition -> 
                    Baseline], DefaultBaseStyle -> "Labeled"], 
                  "SkipImageSizeLevel"], 
                 ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Center}}, "Rows" -> {{Center}}}, AutoDelete -> 
               False, GridBoxItemSize -> Automatic, 
               BaselinePosition -> {1, 1}]& ),
             Editable->True,
             InterpretationFunction->(RowBox[{"Legended", "[", 
                RowBox[{#, ",", 
                  RowBox[{"Placed", "[", 
                    RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )], 3->
            PaneBox[
             StyleBox[
              TagBox[GridBox[{
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r1a", {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["KKK", "compartment"]}, {
                    Toolbox`species["E1_KKK", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r1b", {
                    Toolbox`species["E1_KKK", "compartment"]}, {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r2a", {
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["E2_P_KKK", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r2b", {
                    Toolbox`species["E2_P_KKK", "compartment"]}, {
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["KKK", "compartment"]}, {1, 1, 1}, False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r3a", {
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["P_KKK_KK", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r3b", {
                    Toolbox`species["P_KKK_KK", "compartment"]}, {
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r4a", {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["P_KK", "compartment"]}, {
                    Toolbox`species["KKPase_P_KK", "compartment"]}, {1, 1, 1},
                     True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r4b", {
                    Toolbox`species["KKPase_P_KK", "compartment"]}, {
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["KKPase", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r5a", {
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"]}, {
                    Toolbox`species["P_KKK_P_KK", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r5b", {
                    Toolbox`species["P_KKK_P_KK", "compartment"]}, {
                    Toolbox`species["P_KKK", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r6a", {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["KKPase_PP_KK", "compartment"]}, {1, 1, 
                    1}, True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r6b", {
                    Toolbox`species["KKPase_PP_KK", "compartment"]}, {
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["P_KK", "compartment"]}, {1, 1, 1}, False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r7a", {
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["PP_KK_K", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r7b", {
                    Toolbox`species["PP_KK_K", "compartment"]}, {
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r8a", {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["P_K", "compartment"]}, {
                    Toolbox`species["KPase_P_K", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r8b", {
                    Toolbox`species["KPase_P_K", "compartment"]}, {
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["KPase", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r9a", {
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {
                    Toolbox`species["PP_KK_P_K", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r9b", {
                    Toolbox`species["PP_KK_P_K", "compartment"]}, {
                    Toolbox`species["PP_K", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                    False],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False]}], "\[Equilibrium]", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False]}], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r10a", {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["PP_K", "compartment"]}, {
                    Toolbox`species["KPase_PP_K", "compartment"]}, {1, 1, 1}, 
                    True],
                   Editable->False,
                   Selectable->False]},
                 {
                  InterpretationBox[
                   OverscriptBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "\[RightArrow]", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False]}]}], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`reaction["r10b", {
                    Toolbox`species["KPase_PP_K", "compartment"]}, {
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["P_K", "compartment"]}, {1, 1, 1}, False],
                   Editable->False,
                   Selectable->False]}
                },
                DefaultBaseStyle->"Column",
                GridBoxAlignment->{"Columns" -> {{Left}}},
                GridBoxBackground->{"Columns" -> {{Automatic}}, "Rows" -> {{
                    GrayLevel[0.99], 
                    RGBColor[0.87, 0.94, 1]}}},
                
                GridBoxDividers->{
                 "Columns" -> {True, {}, True}, "Rows" -> {{True}}},
                
                GridBoxItemSize->{
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
               "Column"],
              StripOnInput->False,
              FontSize->12],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 4->
            PaneBox[
             TabViewBox[{{1,"\<\"Type I\"\>"->
              StyleBox[
               TagBox[GridBox[{
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d1", "r1a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a1", "r1a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r1b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d2", "r2a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a2", "r2a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r2b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k3", "r3b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d4", "r4a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a4", "r4a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k4", "r4b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k5", "r5b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d6", "r6a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a6", "r6a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k6", "r6b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k7", "r7b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d8", "r8a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a8", "r8a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k8", "r8b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k9", "r9b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d10", "r10a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a10", "r10a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k10", "r10b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}
                 },
                 AutoDelete->False,
                 GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
                    GrayLevel[0.99], 
                    RGBColor[0.87, 0.94, 1]}}},
                 
                 GridBoxDividers->{
                  "Columns" -> {True, {}, True}, "Rows" -> {{True}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                 GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
                "Grid"],
               StripOnInput->False,
               FontSize->12]}, {2,"\<\"Type II\"\>"->
              StyleBox[
               TagBox[GridBox[{
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d1", "r1a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a1", "r1a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r1b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d2", "r2a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a2", "r2a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r2b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k3", "r3b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d4", "r4a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a4", "r4a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k4", "r4b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k5", "r5b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d6", "r6a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a6", "r6a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k6", "r6b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k7", "r7b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d8", "r8a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a8", "r8a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k8", "r8b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k9", "r9b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d10", "r10a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a10", "r10a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k10", "r10b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}
                 },
                 AutoDelete->False,
                 GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
                    GrayLevel[0.99], 
                    RGBColor[0.87, 0.94, 1]}}},
                 
                 GridBoxDividers->{
                  "Columns" -> {True, {}, True}, "Rows" -> {{True}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                 GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
                "Grid"],
               StripOnInput->False,
               FontSize->12]}, {3,"\<\"Type III\"\>"->
              StyleBox[
               TagBox[GridBox[{
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d1", "r1a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a1", "r1a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r1b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d2", "r2a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a2", "r2a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r2b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k3", "r3b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d4", "r4a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a4", "r4a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k4", "r4b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k5", "r5b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d6", "r6a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a6", "r6a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k6", "r6b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k7", "r7b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d8", "r8a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a8", "r8a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k8", "r8b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k9", "r9b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10a"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d10", "r10a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a10", "r10a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]},
                  {
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10b"],
                    Editable->False,
                    Selectable->False], 
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k10", "r10b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}
                 },
                 AutoDelete->False,
                 GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
                    GrayLevel[0.99], 
                    RGBColor[0.87, 0.94, 1]}}},
                 GridBoxDividers->{
                  "Columns" -> {True, {}, True}, "Rows" -> {{True}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                 GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
                "Grid"],
               StripOnInput->False,
               FontSize->12]}}, 1],
             ImageSize->{{800}, {450}},
             Scrollbars->{False, True}], 5->
            PaneBox[
             StyleBox[
              TagBox[GridBox[{
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r1b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d1", "r1a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a1", "r1a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r2b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d2", "r2a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a2", "r2a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k8", "r8b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k4", "r4b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k4", "r4b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k6", "r6b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d4", "r4a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a4", "r4a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d6", "r6a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a6", "r6a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k4", "r4b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d4", "r4a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a4", "r4a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k8", "r8b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k10", "r10b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d8", "r8a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a8", "r8a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d10", "r10a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a10", "r10a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k8", "r8b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d8", "r8a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a8", "r8a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k10", "r10b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d8", "r8a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a8", "r8a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k7", "r7b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k6", "r6b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d4", "r4a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a4", "r4a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k3", "r3b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r1b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d2", "r2a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a2", "r2a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k3", "r3b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k5", "r5b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k3", "r3b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d3", "r3a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d10", "r10a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a10", "r10a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k9", "r9b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k7", "r7b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k9", "r9b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r1b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d1", "r1a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a1", "r1a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r2b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d2", "r2a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a2", "r2a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k2", "r2b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d1", "r1a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a1", "r1a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k6", "r6b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d6", "r6a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a6", "r6a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k10", "r10b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d10", "r10a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a10", "r10a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k5", "r5b"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d5", "r5a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", 
                   RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k5", "r5b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d6", "r6a"],
                    Editable->False,
                    Selectable->False]}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a6", "r6a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k7", "r7b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d7", "r7a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}], "+", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["k9", "r9b"],
                    Editable->False,
                    Selectable->False], " ", 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["Volume", "compartment"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["a9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["d9", "r9a"],
                    Editable->False,
                    Selectable->False], " ", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]}], ")"}]}]}]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"K_PP", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K_PP_norm", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "\[Equal]", 
                   FractionBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"rel_K", "_PP", "_max"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["rel_K_PP_max", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "\[Equal]", 
                   FractionBox[
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"K_PP", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K_PP_norm", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], 
                    InterpretationBox[
                    UnderscriptBox[
                    StyleBox[
                    RowBox[{"K_PP", "_norm", "_max"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["Global",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`parameter["K_PP_norm_max"],
                    Editable->False,
                    Selectable->False]]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KK_PP", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK_PP_norm", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "\[Equal]", 
                   FractionBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]]}]},
                 {
                  RowBox[{
                   RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKK_P", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK_P_norm", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "\[Equal]", 
                   FractionBox[
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}], "+", 
                    RowBox[{
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "[", "t", "]"}]}]]}]}
                },
                DefaultBaseStyle->"Column",
                GridBoxAlignment->{"Columns" -> {{Left}}},
                GridBoxBackground->{"Columns" -> {{Automatic}}, "Rows" -> {{
                    GrayLevel[0.99], 
                    RGBColor[0.87, 0.94, 1]}}},
                
                GridBoxDividers->{
                 "Columns" -> {True, {}, True}, "Rows" -> {{True}}},
                
                GridBoxItemSize->{
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{1}}}],
               "Column"],
              StripOnInput->False,
              FontSize->10],
             ImageSize->{{800}, {450}},
             Scrollbars->{False, True}], 6->
            PaneBox[
             StyleBox[
              TagBox[
               TagBox[GridBox[{
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]},
                  {
                   RowBox[{"0", "\[LessEqual]", 
                    InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10b"],
                    Editable->False,
                    Selectable->False], "\[LessEqual]", "\[Infinity]"}]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                Column],
               Function[BoxForm`e$, 
                TableForm[BoxForm`e$]]],
              StripOnInput->False,
              FontSize->10],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 7->
            PaneBox[
             StyleBox[
              TagBox[
               TagBox[GridBox[{
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.00003`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0.00003, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.0003`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.003`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0.003, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"1.2`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"1.2`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.12`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0.12, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.0003`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    InterpretationBox[
                    RowBox[{"0.`", " ", 
                    RowBox[{"micromole", 
                    SuperscriptBox["Liter", 
                    RowBox[{"-", "1"}]]}]}],
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
                    AutoDelete->True]}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"K_PP", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K_PP_norm", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    "0.`"}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"rel_K", "_PP", "_max"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["rel_K_PP_max", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    "0.`"}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KK_PP", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK_PP_norm", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    "0.`"}]},
                  {
                   RowBox[{
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKK_P", "_norm"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK_P_norm", "compartment"],
                    Editable->False,
                    Selectable->False], ")"}], "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], "\[Equal]", 
                    "0.`"}]}
                 },
                 
                 GridBoxAlignment->{
                  "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                 GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                   "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
                Column],
               Function[BoxForm`e$, 
                TableForm[BoxForm`e$]]],
              StripOnInput->False,
              FontSize->10],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 8->
            PaneBox[
             StyleBox[
              TagBox[GridBox[{
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox[
                    RowBox[{"K_PP", "_norm", "_max"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["Global",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["K_PP_norm_max"],
                   Editable->False,
                   Selectable->False], "0.900049`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["Volume",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["Volume", "compartment"],
                   Editable->False,
                   Selectable->False], 
                  InterpretationBox[
                   RowBox[{"4.`*^-12", " ", "Liter"}],
                   AutomaticUnits`Unit[4.*^-12, "Liter"],
                   AutoDelete->True]},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a1", "r1a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d1", "r1a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k2", "r1b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a2", "r2a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d2", "r2a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k2", "r2b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a3", "r3a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d3", "r3a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k3",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k3", "r3b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a4", "r4a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d4", "r4a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k4",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k4", "r4b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a5", "r5a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d5", "r5a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k5",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k5", "r5b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a6", "r6a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d6", "r6a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k6",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k6", "r6b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a7", "r7a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d7", "r7a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k7",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k7", "r7b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a8", "r8a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d8", "r8a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k8",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k8", "r8b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a9", "r9a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d9", "r9a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k9",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k9", "r9b"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["a10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["a10", "r10a"],
                   Editable->False,
                   Selectable->False], "1000.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["d10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["d10", "r10a"],
                   Editable->False,
                   Selectable->False], "150.`"},
                 {
                  InterpretationBox[
                   UnderscriptBox[
                    StyleBox["k10",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                   Toolbox`parameter["k10", "r10b"],
                   Editable->False,
                   Selectable->False], "150.`"}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[2.0999999999999996`]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               Function[BoxForm`e$, 
                TableForm[BoxForm`e$]]],
              StripOnInput->False,
              FontSize->10],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 9->
            TagBox[
             DynamicModuleBox[{Typeset`var$$ = 1}, 
              InterpretationBox[
               TagBox[
                PanelBox[GridBox[{
                   {
                    ItemBox[GridBox[{
                    {GridBox[{
                    {
                    TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[FirstPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFunction:>If[Typeset`var$$ =!= 1, Typeset`var$$ = 1],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    DynamicBox[
                    ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"], 
                    StandardForm]]],
                    Annotation[#, 
                    Dynamic[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]], 
                    "Tooltip"]& ], 
                    TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[LeftPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFunction:>If[Typeset`var$$ > 1, 
                    PreDecrement[Typeset`var$$]],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    DynamicBox[
                    ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"], 
                    StandardForm]]],
                    Annotation[#, 
                    Dynamic[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]], 
                    "Tooltip"]& ], 
                    TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[RightPointer]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFunction:>If[Typeset`var$$ < 1, 
                    PreIncrement[Typeset`var$$]],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    DynamicBox[
                    ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"], 
                    StandardForm]]],
                    Annotation[#, 
                    Dynamic[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]], 
                    "Tooltip"]& ], 
                    TagBox[
                    TooltipBox[
                    ButtonBox[
                    StyleBox["\<\"\[LastPage]\"\>",
                    StripOnInput->False,
                    FontSize->18],
                    Appearance->"Palette",
                    ButtonFunction:>If[Typeset`var$$ =!= 1, Typeset`var$$ = 1],
                    Enabled->Automatic,
                    Evaluator->Automatic,
                    ImageSize->Small,
                    Method->"Preemptive"],
                    DynamicBox[
                    ToBoxes[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"], 
                    StandardForm]]],
                    Annotation[#, 
                    Dynamic[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]], 
                    "Tooltip"]& ]}
                    },
                    AutoDelete->False,
                    
                    GridBoxItemSize->{
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                    GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}], 
                    AnimatorBox[Dynamic[Typeset`var$$], {1, 1, 1},
                    AnimationRunning->False,
                    AnimationTimeIndex->Automatic,
                    
                    AppearanceElements->{
                    "ProgressSlider", "PlayPauseButton", 
                    "FasterSlowerButtons", "DirectionButton"},
                    Enabled->Automatic], 
                    TagBox[GridBox[{
                    {
                    ButtonBox[
                    DynamicBox[ToBoxes[
                    If[Typeset`var$$ === 1, 
                    Style[
                    "\[FilledCircle]", FontColor -> RGBColor[0.7, 0.7, 1]], 
                    Style["\[FilledCircle]", FontColor -> GrayLevel[0.85]]], 
                    StandardForm]],
                    Appearance->None,
                    BaseStyle->{},
                    ButtonFunction:>(Typeset`var$$ = 1),
                    ContentPadding->False,
                    Evaluator->Automatic,
                    Method->"Preemptive"]}
                    },
                    AutoDelete->False,
                    
                    GridBoxItemSize->{
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
                    GridBoxSpacings->{"Columns" -> {{0.25}}}],
                    "Grid"], 
                    StyleBox[
                    TemplateBox[{DynamicBox[
                    ToBoxes[Typeset`var$$, StandardForm]],"\"/\"","1"},
                    "RowDefault"], "Panel",
                    StripOnInput->False]}
                    },
                    AutoDelete->False,
                    
                    GridBoxAlignment->{
                    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Center}}, "RowsIndexed" -> {}},
                    
                    GridBoxItemSize->{
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                    Alignment->Left,
                    StripOnInput->False]},
                   {
                    ItemBox[
                    StyleBox[
                    
                    PaneSelectorBox[{
                    1->"\<\"No GPR associations defined\"\>"}, Dynamic[
                    Typeset`var$$],
                    Alignment->Automatic,
                    ImageSize->{{800}, {450}},
                    TransitionDirection->Horizontal,
                    TransitionDuration->0.5,
                    TransitionEffect->Automatic],
                    Deployed->False,
                    StripOnInput->False],
                    Background->GrayLevel[1],
                    Frame->True,
                    FrameStyle->GrayLevel[0.8235294117647058],
                    StripOnInput->False]}
                  },
                  AutoDelete->False,
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 BaselinePosition->Automatic,
                 DefaultBaseStyle->"SlideView",
                 FrameMargins->6,
                 ImageMargins->Automatic],
                Deploy,
                DefaultBaseStyle->"Deploy"],
               
               SlideView[{"No GPR associations defined"}, AppearanceElements -> 
                All, ImageSize -> {{800}, {450}}]],
              DynamicModuleValues:>Automatic],
             Setting[#, {0}]& ], 10->
            TagBox[
             StyleBox[
              
              DynamicModuleBox[{Toolbox`Private`method$$ = "Remove", 
               Toolbox`p$$ = 0, Toolbox`Private`pltfunc$$ = LayeredGraphPlot, 
               Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
               Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, 
               Typeset`animvar$$ = 1, Typeset`name$$ = "\"untitled\"", 
               Typeset`specs$$ = {{{
                  Hold[Toolbox`p$$], 0, "Currency metabolites to remove"}, 0, 
                 22, 1}, {{
                  Hold[Toolbox`Private`method$$], "Remove", 
                  "How to treat currency metabolites"}, {"Remove", "Mask"}}, {{
                  Hold[Toolbox`Private`pltfunc$$], LayeredGraphPlot, 
                  "Plot function"}, {LayeredGraphPlot, GraphPlot, TreePlot}}},
                Typeset`size$$ = Automatic, Typeset`update$$ = 0, 
               Typeset`initDone$$, Typeset`skipInitDone$$ = True, 
               Toolbox`p$10026$$ = 0, Toolbox`Private`method$10031$$ = False, 
               Toolbox`Private`pltfunc$10032$$ = 0}, 
               
               DynamicBox[Manipulate`ManipulateBoxes[
                1, StandardForm, 
                 "Variables" :> {
                  Toolbox`Private`method$$ = "Remove", Toolbox`p$$ = 0, 
                   Toolbox`Private`pltfunc$$ = LayeredGraphPlot}, 
                 "ControllerVariables" :> {
                   Hold[Toolbox`p$$, Toolbox`p$10026$$, 0], 
                   Hold[
                   Toolbox`Private`method$$, Toolbox`Private`method$10031$$, 
                    False], 
                   Hold[
                   Toolbox`Private`pltfunc$$, Toolbox`Private`pltfunc$10032$$,
                     0]}, 
                 "OtherVariables" :> {
                  Typeset`show$$, Typeset`bookmarkList$$, 
                   Typeset`bookmarkMode$$, Typeset`animator$$, 
                   Typeset`animvar$$, Typeset`name$$, Typeset`specs$$, 
                   Typeset`size$$, Typeset`update$$, Typeset`initDone$$, 
                   Typeset`skipInitDone$$}, "Body" :> 
                 Toolbox`visualizePathways[
                   Toolbox`pathwaytize[
                    Toolbox`model2bipartite[
                    
                    Toolbox`MASSmodel[{
                    "ID" -> "BIOMD0000000009", "Stoichiometry" -> 
                    SparseArray[
                    Automatic, {22, 20}, 0, {
                    1, {{0, 2, 4, 6, 8, 12, 14, 18, 20, 24, 28, 34, 36, 38, 
                    40, 42, 44, 46, 48, 50, 52, 54, 60}, {{1}, {2}, {3}, {
                    4}, {13}, {16}, {5}, {8}, {7}, {8}, {11}, {12}, {7}, {
                    8}, {15}, {16}, {19}, {20}, {15}, {16}, {14}, {15}, {
                    17}, {20}, {6}, {7}, {9}, {12}, {2}, {3}, {5}, {6}, {9}, {
                    10}, {5}, {6}, {18}, {19}, {13}, {14}, {17}, {18}, {1}, {
                    2}, {3}, {4}, {1}, {4}, {11}, {12}, {19}, {20}, {9}, {
                    10}, {10}, {11}, {13}, {14}, {17}, {18}}}, {-1, 1, -1, 
                    1, -1, 1, -1, 1, -1, 1, -1, 1, 1, -1, -1, 1, -1, 1, 1, -1,
                     1, -1, -1, 1, 1, -1, -1, 1, 1, -1, -1, 1, -1, 1, 1, -1, 
                    1, -1, 1, -1, 1, -1, 1, -1, 1, -1, -1, 1, 1, -1, 1, -1, 
                    1, -1, 1, -1, -1, 1, -1, 1}}], "Species" -> {
                    Toolbox`species["E1", "compartment"], 
                    Toolbox`species["E2", "compartment"], 
                    Toolbox`species["K", "compartment"], 
                    Toolbox`species["KK", "compartment"], 
                    Toolbox`species["KKPase", "compartment"], 
                    Toolbox`species["KKPase_P_KK", "compartment"], 
                    Toolbox`species["KPase", "compartment"], 
                    Toolbox`species["KPase_P_K", "compartment"], 
                    Toolbox`species["P_K", "compartment"], 
                    Toolbox`species["P_KK", "compartment"], 
                    Toolbox`species["P_KKK", "compartment"], 
                    Toolbox`species["P_KKK_KK", "compartment"], 
                    Toolbox`species["PP_K", "compartment"], 
                    Toolbox`species["PP_KK_K", "compartment"], 
                    Toolbox`species["PP_KK_P_K", "compartment"], 
                    Toolbox`species["E1_KKK", "compartment"], 
                    Toolbox`species["E2_P_KKK", "compartment"], 
                    Toolbox`species["KKK", "compartment"], 
                    Toolbox`species["KKPase_PP_KK", "compartment"], 
                    Toolbox`species["KPase_PP_K", "compartment"], 
                    Toolbox`species["P_KKK_P_KK", "compartment"], 
                    Toolbox`species["PP_KK", "compartment"]}, "Fluxes" -> {
                    Toolbox`v["r1a"], 
                    Toolbox`v["r1b"], 
                    Toolbox`v["r2a"], 
                    Toolbox`v["r2b"], 
                    Toolbox`v["r3a"], 
                    Toolbox`v["r3b"], 
                    Toolbox`v["r4a"], 
                    Toolbox`v["r4b"], 
                    Toolbox`v["r5a"], 
                    Toolbox`v["r5b"], 
                    Toolbox`v["r6a"], 
                    Toolbox`v["r6b"], 
                    Toolbox`v["r7a"], 
                    Toolbox`v["r7b"], 
                    Toolbox`v["r8a"], 
                    Toolbox`v["r8b"], 
                    Toolbox`v["r9a"], 
                    Toolbox`v["r9b"], 
                    Toolbox`v["r10a"], 
                    Toolbox`v["r10b"]}, 
                    "Constraints" -> {Toolbox`v["r1b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r2b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r3b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r4b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r5b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r6b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r7b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r8b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r9b"] -> {0, 
                    DirectedInfinity[1]}, Toolbox`v["r10b"] -> {0, 
                    DirectedInfinity[1]}}, 
                    "InitialConditions" -> {
                    Toolbox`species["E1", "compartment"] -> 
                    AutomaticUnits`Unit[0.00003, "Liter"^(-1) "micromole"], 
                    Toolbox`species["E2", "compartment"] -> 
                    AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"], 
                    Toolbox`species["KKK", "compartment"] -> 
                    AutomaticUnits`Unit[0.003, "Liter"^(-1) "micromole"], 
                    Toolbox`species["P_KKK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["KK", "compartment"] -> 
                    AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"], 
                    Toolbox`species["P_KK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["PP_KK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["K", "compartment"] -> 
                    AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"], 
                    Toolbox`species["P_K", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["PP_K", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["KPase", "compartment"] -> 
                    AutomaticUnits`Unit[0.12, "Liter"^(-1) "micromole"], 
                    Toolbox`species["KKPase", "compartment"] -> 
                    AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"], 
                    Toolbox`species["E1_KKK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["E2_P_KKK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["P_KKK_KK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["P_KKK_P_KK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["PP_KK_K", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["PP_KK_P_K", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["KKPase_PP_KK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["KKPase_P_KK", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["KPase_PP_K", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["KPase_P_K", "compartment"] -> 
                    AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
                    Toolbox`species["K_PP_norm", "compartment"] -> 0., 
                    Toolbox`species["rel_K_PP_max", "compartment"] -> 0., 
                    Toolbox`species["KK_PP_norm", "compartment"] -> 0., 
                    Toolbox`species["KKK_P_norm", "compartment"] -> 0.}, 
                    "Parameters" -> {
                    Toolbox`parameter["K_PP_norm_max"] -> 0.900049, 
                    Toolbox`parameter["Volume", "compartment"] -> 
                    AutomaticUnits`Unit[4.*^-12, "Liter"], 
                    Toolbox`parameter["a1", "r1a"] -> 1000., 
                    Toolbox`parameter["d1", "r1a"] -> 150., 
                    Toolbox`parameter["k2", "r1b"] -> 150., 
                    Toolbox`parameter["a2", "r2a"] -> 1000., 
                    Toolbox`parameter["d2", "r2a"] -> 150., 
                    Toolbox`parameter["k2", "r2b"] -> 150., 
                    Toolbox`parameter["a3", "r3a"] -> 1000., 
                    Toolbox`parameter["d3", "r3a"] -> 150., 
                    Toolbox`parameter["k3", "r3b"] -> 150., 
                    Toolbox`parameter["a4", "r4a"] -> 1000., 
                    Toolbox`parameter["d4", "r4a"] -> 150., 
                    Toolbox`parameter["k4", "r4b"] -> 150., 
                    Toolbox`parameter["a5", "r5a"] -> 1000., 
                    Toolbox`parameter["d5", "r5a"] -> 150., 
                    Toolbox`parameter["k5", "r5b"] -> 150., 
                    Toolbox`parameter["a6", "r6a"] -> 1000., 
                    Toolbox`parameter["d6", "r6a"] -> 150., 
                    Toolbox`parameter["k6", "r6b"] -> 150., 
                    Toolbox`parameter["a7", "r7a"] -> 1000., 
                    Toolbox`parameter["d7", "r7a"] -> 150., 
                    Toolbox`parameter["k7", "r7b"] -> 150., 
                    Toolbox`parameter["a8", "r8a"] -> 1000., 
                    Toolbox`parameter["d8", "r8a"] -> 150., 
                    Toolbox`parameter["k8", "r8b"] -> 150., 
                    Toolbox`parameter["a9", "r9a"] -> 1000., 
                    Toolbox`parameter["d9", "r9a"] -> 150., 
                    Toolbox`parameter["k9", "r9b"] -> 150., 
                    Toolbox`parameter["a10", "r10a"] -> 1000., 
                    Toolbox`parameter["d10", "r10a"] -> 150., 
                    Toolbox`parameter["k10", "r10b"] -> 150.}, "GPR" -> {}, 
                    "BoundaryConditions" -> {}, "Constant" -> {}, 
                    "ReversibleColumnIndices" -> {1, 3, 5, 7, 9, 11, 13, 15, 
                    17, 19}, 
                    "CustomRateLaws" -> {
                    Toolbox`v["r1a"] -> 
                    Toolbox`parameter[
                    "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
                    Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
                    Toolbox`parameter["a1", "r1a"] 
                    Toolbox`species["E1", "compartment"][Toolbox`t] 
                    Toolbox`species["KKK", "compartment"][Toolbox`t]), 
                    Toolbox`v["r1b"] -> 
                    Toolbox`parameter["k2", "r1b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["E1_KKK", "compartment"][Toolbox`t], 
                    Toolbox`v["r2a"] -> 
                    Toolbox`parameter[
                    "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
                    Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
                    Toolbox`parameter["a2", "r2a"] 
                    Toolbox`species["E2", "compartment"][Toolbox`t] 
                    Toolbox`species["P_KKK", "compartment"][Toolbox`t]), 
                    Toolbox`v["r2b"] -> 
                    Toolbox`parameter["k2", "r2b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t], 
                    Toolbox`v["r3a"] -> 
                    Toolbox`parameter["Volume", "compartment"] (
                    Toolbox`parameter["a3", "r3a"] 
                    Toolbox`species["KK", "compartment"][Toolbox`t] 
                    Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                    Toolbox`parameter["d3", "r3a"] 
                    Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]), 
                    Toolbox`v["r3b"] -> 
                    Toolbox`parameter["k3", "r3b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t], 
                    Toolbox`v["r4a"] -> 
                    Toolbox`parameter[
                    "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
                    Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                    Toolbox`parameter["a4", "r4a"] 
                    Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                    Toolbox`species["P_KK", "compartment"][Toolbox`t]), 
                    Toolbox`v["r4b"] -> 
                    Toolbox`parameter["k4", "r4b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t], 
                    Toolbox`v["r5a"] -> 
                    Toolbox`parameter["Volume", "compartment"] (
                    Toolbox`parameter["a5", "r5a"] 
                    Toolbox`species["P_KK", "compartment"][Toolbox`t] 
                    Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                    Toolbox`parameter["d5", "r5a"] 
                    Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]), 
                    Toolbox`v["r5b"] -> 
                    Toolbox`parameter["k5", "r5b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t], 
                    Toolbox`v["r6a"] -> 
                    Toolbox`parameter[
                    "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
                    Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                    Toolbox`parameter["a6", "r6a"] 
                    Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                    Toolbox`species["PP_KK", "compartment"][Toolbox`t]), 
                    Toolbox`v["r6b"] -> 
                    Toolbox`parameter["k6", "r6b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t],
                     Toolbox`v["r7a"] -> 
                    Toolbox`parameter["Volume", "compartment"] (
                    Toolbox`parameter["a7", "r7a"] 
                    Toolbox`species["K", "compartment"][Toolbox`t] 
                    Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                    Toolbox`parameter["d7", "r7a"] 
                    Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]), 
                    Toolbox`v["r7b"] -> 
                    Toolbox`parameter["k7", "r7b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["PP_KK_K", "compartment"][Toolbox`t], 
                    Toolbox`v["r8a"] -> 
                    Toolbox`parameter[
                    "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
                    Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                    Toolbox`parameter["a8", "r8a"] 
                    Toolbox`species["KPase", "compartment"][Toolbox`t] 
                    Toolbox`species["P_K", "compartment"][Toolbox`t]), 
                    Toolbox`v["r8b"] -> 
                    Toolbox`parameter["k8", "r8b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["KPase_P_K", "compartment"][Toolbox`t], 
                    Toolbox`v["r9a"] -> 
                    Toolbox`parameter["Volume", "compartment"] (
                    Toolbox`parameter["a9", "r9a"] 
                    Toolbox`species["P_K", "compartment"][Toolbox`t] 
                    Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                    Toolbox`parameter["d9", "r9a"] 
                    Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
                    Toolbox`v["r9b"] -> 
                    Toolbox`parameter["k9", "r9b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t], 
                    Toolbox`v["r10a"] -> 
                    Toolbox`parameter[
                    "Volume", "compartment"] (-
                    Toolbox`parameter["d10", "r10a"] 
                    Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                    Toolbox`parameter["a10", "r10a"] 
                    Toolbox`species["KPase", "compartment"][Toolbox`t] 
                    Toolbox`species["PP_K", "compartment"][Toolbox`t]), 
                    Toolbox`v["r10b"] -> 
                    Toolbox`parameter["k10", "r10b"] 
                    Toolbox`parameter["Volume", "compartment"] 
                    Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t]}, 
                    "CustomODE" -> {
                    Toolbox`species["K_PP_norm", "compartment"][
                    Toolbox`t] == (
                    Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_K", "compartment"][Toolbox`t])/(
                    Toolbox`species["K", "compartment"][Toolbox`t] + 
                    Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
                    Toolbox`species["rel_K_PP_max", "compartment"][Toolbox`t] == 
                    Toolbox`parameter["K_PP_norm_max"]^(-1) 
                    Toolbox`species["K_PP_norm", "compartment"][Toolbox`t], 
                    Toolbox`species["KK_PP_norm", "compartment"][
                    Toolbox`t] == (
                    Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t])/(
                    Toolbox`species["KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
                    Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
                    Toolbox`species["KKK_P_norm", "compartment"][
                    Toolbox`t] == (
                    Toolbox`species["P_KKK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])/(
                    Toolbox`species["KKK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
                    Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])},
                     "Name" -> "Huang1996 - Ultrasensitivity in MAPK cascade",
                     "ElementalComposition" -> {
                    Toolbox`species["E1", "compartment"] -> "&E1&", 
                    Toolbox`species["E1_KKK", "compartment"] -> "&E1_KKK&", 
                    Toolbox`species["E2", "compartment"] -> "&E2&", 
                    Toolbox`species["E2_P_KKK", "compartment"] -> 
                    "&E2_P_KKK&", Toolbox`species["K", "compartment"] -> 
                    "&K&", Toolbox`species["KK", "compartment"] -> "&KK&", 
                    Toolbox`species["KKK", "compartment"] -> "&KKK&", 
                    Toolbox`species["KKPase", "compartment"] -> "&KKPase&", 
                    Toolbox`species["KKPase_P_KK", "compartment"] -> 
                    "&KKPase_P_KK&", 
                    Toolbox`species["KKPase_PP_KK", "compartment"] -> 
                    "&KKPase_PP_KK&", Toolbox`species["KPase", "compartment"] -> 
                    "&KPase&", Toolbox`species["KPase_P_K", "compartment"] -> 
                    "&KPase_P_K&", 
                    Toolbox`species["KPase_PP_K", "compartment"] -> 
                    "&KPase_PP_K&", Toolbox`species["P_K", "compartment"] -> 
                    "&P_K&", Toolbox`species["P_KK", "compartment"] -> 
                    "&P_KK&", Toolbox`species["P_KKK", "compartment"] -> 
                    "&P_KKK&", Toolbox`species["P_KKK_KK", "compartment"] -> 
                    "&P_KKK_KK&", 
                    Toolbox`species["P_KKK_P_KK", "compartment"] -> 
                    "&P_KKK_P_KK&", Toolbox`species["PP_K", "compartment"] -> 
                    "&PP_K&", Toolbox`species["PP_KK", "compartment"] -> 
                    "&PP_KK&", Toolbox`species["PP_KK_K", "compartment"] -> 
                    "&PP_KK_K&", Toolbox`species["PP_KK_P_K", "compartment"] -> 
                    "&PP_KK_P_K&"}, "Notes" -> 
                    "Huang1996 - Ultrasensitivity in MAPK cascade  \n \nThe \
temporal sequence of kinase activation, from MAPKKK (activated RAF) to the \
final effector MAPK (activated ERK), is described here. It is observed from \
the model that there is an increase in sensitivity along the levels of the \
cascade, where the activity of MAPK reaches its maximal before MAPKKK.    \n \
\nThis model is described in the article:  \n  Ultrasensitivity in the \
mitogen-activated protein kinase cascade.    \nHuang CY, Ferrell JE Jr  \n\
Proc. Natl. Acad. Sci. U.S.A. 1996:93(19):10078-83  \nAbstract:  \n \nThe \
mitogen-activated protein kinase (MAPK) cascade is a highly conserved series \
of three protein kinases implicated in diverse biological processes. Here we \
demonstrate that the cascade arrangement has unexpected consequences for the \
dynamics of MAPK signaling. We solved the rate equations for the cascade \
numerically and found that MAPK is predicted to behave like a highly \
cooperative enzyme, even though it was not assumed that any of the enzymes in \
the cascade were regulated cooperatively. Measurements of MAPK activation in \
Xenopus oocyte extracts confirmed this prediction. The stimulus/response \
curve of the MAPK was found to be as steep as that of a cooperative enzyme \
with a Hill coefficient of 4-5, well in excess of that of the classical \
allosteric protein hemoglobin. The shape of the MAPK stimulus/ response curve \
may make the cascade particularly appropriate for mediating processes like \
mitogenesis, cell fate induction, and oocyte maturation, where a cell \
switches from one discrete state to another.      \n \nThe species K_PP_norm, \
KKK_P_norm and KK_PP_norm are the relative concentrations of the active MAPK, \
MAPKK and MAPKKK, that is the double, or single resp. phophorylated forms \
divided by the total concentrations of each kinase. For MAPK additionally the \
also active MAPK divided by the maximal concentration of active MAPK is given \
by rel_K_PP_max. The parameter K_PP_norm_max, the maximal ratio of active \
MapK, has to be calculated for each change of parameters.    \n \nThis model \
is hosted on BioModels Database and identified by: BIOMD0000000009 .  \nTo \
cite BioModels Database, please use: BioModels Database: An enhanced, curated \
and annotated resource for published quantitative kinetic models .    \n \nTo \
the extent possible under law, all copyright and related or neighbouring \
rights to this encoded model have been dedicated to the public domain \
worldwide. Please refer to CC0 Public Domain Dedication for more \
information.", "Ignore" -> {}, "UnitChecking" -> False, 
                    "Synonyms" -> {
                    Toolbox`species["E1", "compartment"] -> 
                    "MAPKKK activator (Ras)", 
                    Toolbox`species["E2", "compartment"] -> 
                    "MAPKKK inactivator", 
                    Toolbox`species["KKK", "compartment"] -> "Mos", 
                    Toolbox`species["P_KKK", "compartment"] -> "Mos-P", 
                    Toolbox`species["KK", "compartment"] -> "Mek1", 
                    Toolbox`species["P_KK", "compartment"] -> "Mek1-P", 
                    Toolbox`species["PP_KK", "compartment"] -> "Mek1-PP", 
                    Toolbox`species["K", "compartment"] -> "Erk2", 
                    Toolbox`species["P_K", "compartment"] -> "Erk2-P", 
                    Toolbox`species["PP_K", "compartment"] -> "Erk2-PP", 
                    Toolbox`species["KPase", "compartment"] -> "MAPK-Pase", 
                    Toolbox`species["KKPase", "compartment"] -> "MAPKK-Pase", 
                    Toolbox`species["E1_KKK", "compartment"] -> "E1_Mos", 
                    Toolbox`species["E2_P_KKK", "compartment"] -> "E2_Mos-P", 
                    Toolbox`species["P_KKK_KK", "compartment"] -> 
                    "P-Mos_Mek1", 
                    Toolbox`species["P_KKK_P_KK", "compartment"] -> 
                    "P-Mos_P-Mek1", Toolbox`species["PP_KK_K", "compartment"] -> 
                    "PP-Mek1_Erk2", 
                    Toolbox`species["PP_KK_P_K", "compartment"] -> 
                    "PP-Mek1_P-Erk2", 
                    Toolbox`species["KKPase_PP_KK", "compartment"] -> 
                    "MAPKK-Pase_PP-Mek1", 
                    Toolbox`species["KKPase_P_KK", "compartment"] -> 
                    "MAPKK-Pase_P-Mek1", 
                    Toolbox`species["KPase_PP_K", "compartment"] -> 
                    "MAPK-Pase_PP-Erk2", 
                    Toolbox`species["KPase_P_K", "compartment"] -> 
                    "MAPK-Pase_P-Erk2", 
                    Toolbox`species["K_PP_norm", "compartment"] -> 
                    "K_PP_norm", Toolbox`species["KK_PP_norm", "compartment"] -> 
                    "KK_PP_norm", 
                    Toolbox`species["KKK_P_norm", "compartment"] -> 
                    "KKK_P_norm", 
                    Toolbox`species["rel_K_PP_max", "compartment"] -> 
                    "relative maximal K_PP"}, "Events" -> {}}]], Toolbox`p$$, 
                    Method -> Toolbox`Private`method$$], Toolbox`PlotFunction -> 
                   Toolbox`Private`pltfunc$$, 
                   ImageSize -> {{Toolbox`Private`width}, {
                    Toolbox`Private`height - 140}}], 
                 "Specifications" :> {{{
                    Toolbox`p$$, 0, "Currency metabolites to remove"}, 0, 22, 
                    1}, {{Toolbox`Private`method$$, "Remove", 
                    "How to treat currency metabolites"}, {
                    "Remove", "Mask"}}, {{
                    Toolbox`Private`pltfunc$$, LayeredGraphPlot, 
                    "Plot function"}, {
                    LayeredGraphPlot, GraphPlot, TreePlot}}}, "Options" :> {},
                  "DefaultOptions" :> {TrackedSymbols :> True}],
                SingleEvaluation->True],
               Deinitialization:>None,
               DynamicModuleValues:>{},
               SynchronousInitialization->True,
               UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
               UnsavedVariables:>{Typeset`initDone$$},
               UntrackedVariables:>{Typeset`size$$}], "Manipulate",
              Deployed->True,
              StripOnInput->False],
             Manipulate`InterpretManipulate[1]], 11->
            PaneBox[
             TagBox[
              TagBox[GridBox[{
                 {
                  RowBox[{
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r10b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r10b"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r9b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r9b"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r7b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r7b"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r8b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r8b"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r5b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r5b"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r6b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r6b"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r3b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r3b"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r4b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r4b"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r1b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r1b"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2a",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2a"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SubscriptBox[
                    StyleBox["v",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["r2b",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`v["r2b"],
                    Editable->False,
                    Selectable->False]}]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               Column],
              Function[BoxForm`e$, 
               TableForm[BoxForm`e$, TableHeadings -> {None, {
                   Toolbox`v["r1a"], 
                   Toolbox`v["r1b"], 
                   Toolbox`v["r2a"], 
                   Toolbox`v["r2b"], 
                   Toolbox`v["r3a"], 
                   Toolbox`v["r3b"], 
                   Toolbox`v["r4a"], 
                   Toolbox`v["r4b"], 
                   Toolbox`v["r5a"], 
                   Toolbox`v["r5b"], 
                   Toolbox`v["r6a"], 
                   Toolbox`v["r6b"], 
                   Toolbox`v["r7a"], 
                   Toolbox`v["r7b"], 
                   Toolbox`v["r8a"], 
                   Toolbox`v["r8b"], 
                   Toolbox`v["r9a"], 
                   Toolbox`v["r9b"], 
                   Toolbox`v["r10a"], 
                   Toolbox`v["r10b"]}}]]],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 12->
            PaneBox[
             TagBox[
              TagBox[GridBox[{
                 {
                  RowBox[{
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KK", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_KK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   RowBox[{"-", 
                    InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False]}], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"P_KKK", "_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_KKK_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KPase_PP", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase_PP_K", "compartment"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KKPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_P", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_P_KK", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"KKPase_PP", "_KK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KKPase_PP_KK", "compartment"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E2",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"E2_P", "_KKK"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E2_P_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["E1_KKK",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["E1_KKK", "compartment"],
                    Editable->False,
                    Selectable->False]}]},
                 {
                  RowBox[{
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["K", "compartment"],
                    Editable->False,
                    Selectable->False], "-", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["KPase",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["KPase", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["P_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["P_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox["PP_K",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_K", "compartment"],
                    Editable->False,
                    Selectable->False], "+", 
                   InterpretationBox[
                    SuperscriptBox[
                    StyleBox[
                    RowBox[{"PP_KK", "_P", "_K"}],
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]], 
                    StyleBox["compartment",
                    StripOnInput->False,
                    ShowSyntaxStyles->False,
                    AutoSpacing->False,
                    ZeroWidthTimes->True,
                    LineColor->RGBColor[0, 0, 0],
                    FrontFaceColor->RGBColor[0, 0, 0],
                    BackFaceColor->RGBColor[0, 0, 0],
                    GraphicsColor->RGBColor[0, 0, 0],
                    FontColor->RGBColor[0, 0, 0]]],
                    Toolbox`species["PP_KK_P_K", "compartment"],
                    Editable->False,
                    Selectable->False]}]}
                },
                
                GridBoxAlignment->{
                 "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.5599999999999999]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                  "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}],
               Column],
              Function[BoxForm`e$, 
               TableForm[BoxForm`e$, TableHeadings -> {None, {
                   Toolbox`species["E1", "compartment"], 
                   Toolbox`species["E2", "compartment"], 
                   Toolbox`species["K", "compartment"], 
                   Toolbox`species["KK", "compartment"], 
                   Toolbox`species["KKPase", "compartment"], 
                   Toolbox`species["KKPase_P_KK", "compartment"], 
                   Toolbox`species["KPase", "compartment"], 
                   Toolbox`species["KPase_P_K", "compartment"], 
                   Toolbox`species["P_K", "compartment"], 
                   Toolbox`species["P_KK", "compartment"], 
                   Toolbox`species["P_KKK", "compartment"], 
                   Toolbox`species["P_KKK_KK", "compartment"], 
                   Toolbox`species["PP_K", "compartment"], 
                   Toolbox`species["PP_KK_K", "compartment"], 
                   Toolbox`species["PP_KK_P_K", "compartment"], 
                   Toolbox`species["E1_KKK", "compartment"], 
                   Toolbox`species["E2_P_KKK", "compartment"], 
                   Toolbox`species["KKK", "compartment"], 
                   Toolbox`species["KKPase_PP_KK", "compartment"], 
                   Toolbox`species["KPase_PP_K", "compartment"], 
                   Toolbox`species["P_KKK_P_KK", "compartment"], 
                   Toolbox`species["PP_KK", "compartment"]}}]]],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}], 13->
            PaneBox[
             
             StyleBox["\<\"Huang1996 - Ultrasensitivity in MAPK cascade  \\n \
\\nThe temporal sequence of kinase activation, from MAPKKK (activated RAF) to \
the final effector MAPK (activated ERK), is described here. It is observed \
from the model that there is an increase in sensitivity along the levels of \
the cascade, where the activity of MAPK reaches its maximal before MAPKKK.    \
\\n \\nThis model is described in the article:  \\n  Ultrasensitivity in the \
mitogen-activated protein kinase cascade.    \\nHuang CY, Ferrell JE Jr  \
\\nProc. Natl. Acad. Sci. U.S.A. 1996:93(19):10078-83  \\nAbstract:  \\n \
\\nThe mitogen-activated protein kinase (MAPK) cascade is a highly conserved \
series of three protein kinases implicated in diverse biological processes. \
Here we demonstrate that the cascade arrangement has unexpected consequences \
for the dynamics of MAPK signaling. We solved the rate equations for the \
cascade numerically and found that MAPK is predicted to behave like a highly \
cooperative enzyme, even though it was not assumed that any of the enzymes in \
the cascade were regulated cooperatively. Measurements of MAPK activation in \
Xenopus oocyte extracts confirmed this prediction. The stimulus/response \
curve of the MAPK was found to be as steep as that of a cooperative enzyme \
with a Hill coefficient of 4-5, well in excess of that of the classical \
allosteric protein hemoglobin. The shape of the MAPK stimulus/ response curve \
may make the cascade particularly appropriate for mediating processes like \
mitogenesis, cell fate induction, and oocyte maturation, where a cell \
switches from one discrete state to another.      \\n \\nThe species \
K_PP_norm, KKK_P_norm and KK_PP_norm are the relative concentrations of the \
active MAPK, MAPKK and MAPKKK, that is the double, or single resp. \
phophorylated forms divided by the total concentrations of each kinase. For \
MAPK additionally the also active MAPK divided by the maximal concentration \
of active MAPK is given by rel_K_PP_max. The parameter K_PP_norm_max, the \
maximal ratio of active MapK, has to be calculated for each change of \
parameters.    \\n \\nThis model is hosted on BioModels Database and \
identified by: BIOMD0000000009 .  \\nTo cite BioModels Database, please use: \
BioModels Database: An enhanced, curated and annotated resource for published \
quantitative kinetic models .    \\n \\nTo the extent possible under law, all \
copyright and related or neighbouring rights to this encoded model have been \
dedicated to the public domain worldwide. Please refer to CC0 Public Domain \
Dedication for more information.\"\>",
              StripOnInput->False,
              FontSize->10],
             ImageSize->{{800}, {450}},
             Scrollbars->{True, True}]}, Dynamic[Typeset`var$$],
            Alignment->{Left, Top},
            ImageSize->{{800}, {450}},
            TransitionDirection->Horizontal,
            TransitionDuration->0.5,
            TransitionEffect->Automatic],
           Deployed->False,
           StripOnInput->False],
          Background->GrayLevel[1],
          Frame->True,
          FrameStyle->GrayLevel[0.8235294117647058],
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      BaselinePosition->Automatic,
      DefaultBaseStyle->"MenuView",
      FrameMargins->6,
      ImageMargins->Automatic],
     Deploy,
     DefaultBaseStyle->"Deploy"],
    MenuView[{"Overview" -> Pane[
        Style[
         Grid[{{"Number of species(rows):", 22}, {
           "Number of columns(reactions):", 20}, {
           "Number of exchange reactions:", 0}, {
           "Number of irreversible reactions:", 10}, {"Matrix rank:", 15}, {
           "Dimensions null space: ", 5}, {
           "Dimensions left null space: ", 7}, {"Number of parameters", 32}, {
           "Number of custom rate equations", 20}, {
           "Number of equilibrium constants:", 0}, {
           "Number of forward rate constants:", 0}, {
           "Number of initial concentrations:", 22}, {
           "Number of genes:", 0}, {"Number of proteins:", 0}}, 
          Dividers -> {True, All}, Background -> {None, {{
              GrayLevel[0.99], 
              RGBColor[0.87, 0.94, 1]}}}, Spacings -> {1, 1}], FontSize -> 
         12], {{800}, {450}}, Scrollbars -> {True, True}], 
      "Stoichiometry matrix" -> Legended[
        Graphics[
         Raster[CompressedData["
1:eJztk8EJwzAMRQ1ZofSeSbpDRwj03NUzQlOKLp9+2sQysaz/wLzYYCFF8rw8
74+plHLd1mVb7+8P621MY31sj+e/4rF7/8Y5K35UY91sj+ey3KMNzfN3Y91s
j+fRXVsX3jsaRz7XRrb5j2pD/ZJlva/RbOj/y542ep+rKHlms+HVFwaLfzTf
VvHlfTZazY93PnIuG5rPXDa8+i73aYbX+2odX/Mv15iRff57NeL9rmW5xsjo
88mIkn82M9SvqH4BozOOdQ==
          "], {{0, 0}, {20, 22}}, {0, 1}], 
         BaseStyle -> {FontFamily -> "Helvetica", FontSize -> Scaled[0.015]}, 
         Frame -> True, FrameLabel -> {None, None}, 
         FrameTicks -> {{{{17.5, 5}, {12.5, 10}, {7.5, 15}, {2.5, 20}}, {{
             21.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["E1", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["E1", "compartment"]]]}, {20.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["E2", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["E2", "compartment"]]]}, {19.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["K", "compartment"]]]}, {18.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KK", "compartment"]]]}, {17.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KKPase", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KKPase", "compartment"]]]}, {16.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KKPase_P_KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KKPase_P_KK", "compartment"]]]}, {15.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KPase", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KPase", "compartment"]]]}, {14.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KPase_P_K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KPase_P_K", "compartment"]]]}, {13.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["P_K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["P_K", "compartment"]]]}, {12.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["P_KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["P_KK", "compartment"]]]}, {11.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["P_KKK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["P_KKK", "compartment"]]]}, {10.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["P_KKK_KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["P_KKK_KK", "compartment"]]]}, {9.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["PP_K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["PP_K", "compartment"]]]}, {8.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["PP_KK_K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["PP_KK_K", "compartment"]]]}, {7.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["PP_KK_P_K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["PP_KK_P_K", "compartment"]]]}, {6.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["E1_KKK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["E1_KKK", "compartment"]]]}, {5.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["E2_P_KKK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["E2_P_KKK", "compartment"]]]}, {4.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KKK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KKK", "compartment"]]]}, {3.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KKPase_PP_KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KKPase_PP_KK", "compartment"]]]}, {2.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["KPase_PP_K", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["KPase_PP_K", "compartment"]]]}, {1.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["P_KKK_P_KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["P_KKK_P_KK", "compartment"]]]}, {0.5, 
              Tooltip[
               Style[
                StandardForm[
                 Toolbox`species["PP_KK", "compartment"]], FontSize -> 
                Scaled[0.01]], 
               TraditionalForm[
                Toolbox`species["PP_KK", "compartment"]]]}}}, {{{0.5, 
              Tooltip[
               Rotate[
                Style["r1a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r1a", {
                  Toolbox`species["E1", "compartment"], 
                  Toolbox`species["KKK", "compartment"]}, {
                  Toolbox`species["E1_KKK", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {1.5, 
              Tooltip[
               Rotate[
                Style["r1b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r1b", {
                  Toolbox`species["E1_KKK", "compartment"]}, {
                  Toolbox`species["E1", "compartment"], 
                  Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {2.5, 
              Tooltip[
               Rotate[
                Style["r2a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r2a", {
                  Toolbox`species["E2", "compartment"], 
                  Toolbox`species["P_KKK", "compartment"]}, {
                  Toolbox`species["E2_P_KKK", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {3.5, 
              Tooltip[
               Rotate[
                Style["r2b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r2b", {
                  Toolbox`species["E2_P_KKK", "compartment"]}, {
                  Toolbox`species["E2", "compartment"], 
                  Toolbox`species["KKK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {4.5, 
              Tooltip[
               Rotate[
                Style["r3a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r3a", {
                  Toolbox`species["KK", "compartment"], 
                  Toolbox`species["P_KKK", "compartment"]}, {
                  Toolbox`species["P_KKK_KK", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {5.5, 
              Tooltip[
               Rotate[
                Style["r3b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r3b", {
                  Toolbox`species["P_KKK_KK", "compartment"]}, {
                  Toolbox`species["P_KK", "compartment"], 
                  Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {6.5, 
              Tooltip[
               Rotate[
                Style["r4a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r4a", {
                  Toolbox`species["KKPase", "compartment"], 
                  Toolbox`species["P_KK", "compartment"]}, {
                  Toolbox`species["KKPase_P_KK", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {7.5, 
              Tooltip[
               Rotate[
                Style["r4b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r4b", {
                  Toolbox`species["KKPase_P_KK", "compartment"]}, {
                  Toolbox`species["KK", "compartment"], 
                  Toolbox`species["KKPase", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {8.5, 
              Tooltip[
               Rotate[
                Style["r5a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r5a", {
                  Toolbox`species["P_KK", "compartment"], 
                  Toolbox`species["P_KKK", "compartment"]}, {
                  Toolbox`species["P_KKK_P_KK", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {9.5, 
              Tooltip[
               Rotate[
                Style["r5b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r5b", {
                  Toolbox`species["P_KKK_P_KK", "compartment"]}, {
                  Toolbox`species["P_KKK", "compartment"], 
                  Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {10.5, 
              Tooltip[
               Rotate[
                Style["r6a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r6a", {
                  Toolbox`species["KKPase", "compartment"], 
                  Toolbox`species["PP_KK", "compartment"]}, {
                  Toolbox`species["KKPase_PP_KK", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {11.5, 
              Tooltip[
               Rotate[
                Style["r6b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r6b", {
                  Toolbox`species["KKPase_PP_KK", "compartment"]}, {
                  Toolbox`species["KKPase", "compartment"], 
                  Toolbox`species["P_KK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {12.5, 
              Tooltip[
               Rotate[
                Style["r7a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r7a", {
                  Toolbox`species["K", "compartment"], 
                  Toolbox`species["PP_KK", "compartment"]}, {
                  Toolbox`species["PP_KK_K", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {13.5, 
              Tooltip[
               Rotate[
                Style["r7b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r7b", {
                  Toolbox`species["PP_KK_K", "compartment"]}, {
                  Toolbox`species["P_K", "compartment"], 
                  Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {14.5, 
              Tooltip[
               Rotate[
                Style["r8a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r8a", {
                  Toolbox`species["KPase", "compartment"], 
                  Toolbox`species["P_K", "compartment"]}, {
                  Toolbox`species["KPase_P_K", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {15.5, 
              Tooltip[
               Rotate[
                Style["r8b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r8b", {
                  Toolbox`species["KPase_P_K", "compartment"]}, {
                  Toolbox`species["K", "compartment"], 
                  Toolbox`species["KPase", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {16.5, 
              Tooltip[
               Rotate[
                Style["r9a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r9a", {
                  Toolbox`species["P_K", "compartment"], 
                  Toolbox`species["PP_KK", "compartment"]}, {
                  Toolbox`species["PP_KK_P_K", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {17.5, 
              Tooltip[
               Rotate[
                Style["r9b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r9b", {
                  Toolbox`species["PP_KK_P_K", "compartment"]}, {
                  Toolbox`species["PP_K", "compartment"], 
                  Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, 
                 False]]]}, {18.5, 
              Tooltip[
               Rotate[
                Style["r10a", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r10a", {
                  Toolbox`species["KPase", "compartment"], 
                  Toolbox`species["PP_K", "compartment"]}, {
                  Toolbox`species["KPase_PP_K", "compartment"]}, {1, 1, 1}, 
                 True]]]}, {19.5, 
              Tooltip[
               Rotate[
                Style["r10b", FontSize -> Scaled[0.01]], 90 Degree], 
               StandardForm[
                Toolbox`reaction["r10b", {
                  Toolbox`species["KPase_PP_K", "compartment"]}, {
                  Toolbox`species["KPase", "compartment"], 
                  Toolbox`species["P_K", "compartment"]}, {1, 1, 1}, 
                 False]]]}}, {{4.5, 5}, {9.5, 10}, {14.5, 15}, {19.5, 20}}}}, 
         GridLinesStyle -> Directive[
           GrayLevel[0.5, 0.4]], ImageSize -> {{800}, {450}}, 
         Method -> {
          "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
           "DefaultPlotStyle" -> Automatic, "DomainPadding" -> Scaled[0.02], 
           "RangePadding" -> Scaled[0.05]}], 
        SwatchLegend[{
          GrayLevel[1], 
          RGBColor[0, 1, 0], 
          RGBColor[1, 0, 0]}, {
         "\!\(\*SubscriptBox[\(S\), \(i, j\)]\) = 0", 
          "\!\(\*SubscriptBox[\(S\), \(\(i\)\(,\)\(j\)\(\\ \)\)]\)> 0", 
          "\!\(\*SubscriptBox[\(S\), \(\(i\)\(,\)\(j\)\(\\ \)\)]\)< 0"}]], 
      "Reactions" -> Pane[
        Style[
         Column[{
           Toolbox`reaction["r1a", {
             Toolbox`species["E1", "compartment"], 
             Toolbox`species["KKK", "compartment"]}, {
             Toolbox`species["E1_KKK", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r1b", {
             Toolbox`species["E1_KKK", "compartment"]}, {
             Toolbox`species["E1", "compartment"], 
             Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r2a", {
             Toolbox`species["E2", "compartment"], 
             Toolbox`species["P_KKK", "compartment"]}, {
             Toolbox`species["E2_P_KKK", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r2b", {
             Toolbox`species["E2_P_KKK", "compartment"]}, {
             Toolbox`species["E2", "compartment"], 
             Toolbox`species["KKK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r3a", {
             Toolbox`species["KK", "compartment"], 
             Toolbox`species["P_KKK", "compartment"]}, {
             Toolbox`species["P_KKK_KK", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r3b", {
             Toolbox`species["P_KKK_KK", "compartment"]}, {
             Toolbox`species["P_KK", "compartment"], 
             Toolbox`species["P_KKK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r4a", {
             Toolbox`species["KKPase", "compartment"], 
             Toolbox`species["P_KK", "compartment"]}, {
             Toolbox`species["KKPase_P_KK", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r4b", {
             Toolbox`species["KKPase_P_KK", "compartment"]}, {
             Toolbox`species["KK", "compartment"], 
             Toolbox`species["KKPase", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r5a", {
             Toolbox`species["P_KK", "compartment"], 
             Toolbox`species["P_KKK", "compartment"]}, {
             Toolbox`species["P_KKK_P_KK", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r5b", {
             Toolbox`species["P_KKK_P_KK", "compartment"]}, {
             Toolbox`species["P_KKK", "compartment"], 
             Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r6a", {
             Toolbox`species["KKPase", "compartment"], 
             Toolbox`species["PP_KK", "compartment"]}, {
             Toolbox`species["KKPase_PP_KK", "compartment"]}, {1, 1, 1}, 
            True], 
           Toolbox`reaction["r6b", {
             Toolbox`species["KKPase_PP_KK", "compartment"]}, {
             Toolbox`species["KKPase", "compartment"], 
             Toolbox`species["P_KK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r7a", {
             Toolbox`species["K", "compartment"], 
             Toolbox`species["PP_KK", "compartment"]}, {
             Toolbox`species["PP_KK_K", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r7b", {
             Toolbox`species["PP_KK_K", "compartment"]}, {
             Toolbox`species["P_K", "compartment"], 
             Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r8a", {
             Toolbox`species["KPase", "compartment"], 
             Toolbox`species["P_K", "compartment"]}, {
             Toolbox`species["KPase_P_K", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r8b", {
             Toolbox`species["KPase_P_K", "compartment"]}, {
             Toolbox`species["K", "compartment"], 
             Toolbox`species["KPase", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r9a", {
             Toolbox`species["P_K", "compartment"], 
             Toolbox`species["PP_KK", "compartment"]}, {
             Toolbox`species["PP_KK_P_K", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r9b", {
             Toolbox`species["PP_KK_P_K", "compartment"]}, {
             Toolbox`species["PP_K", "compartment"], 
             Toolbox`species["PP_KK", "compartment"]}, {1, 1, 1}, False], 
           Toolbox`reaction["r10a", {
             Toolbox`species["KPase", "compartment"], 
             Toolbox`species["PP_K", "compartment"]}, {
             Toolbox`species["KPase_PP_K", "compartment"]}, {1, 1, 1}, True], 
           Toolbox`reaction["r10b", {
             Toolbox`species["KPase_PP_K", "compartment"]}, {
             Toolbox`species["KPase", "compartment"], 
             Toolbox`species["P_K", "compartment"]}, {1, 1, 1}, False]}, 
          Dividers -> {True, All}, Background -> {{
             GrayLevel[0.99], 
             RGBColor[0.87, 0.94, 1]}}, Spacings -> {1, 1}], FontSize -> 
         12], {{800}, {450}}, Scrollbars -> {True, True}], "Rates" -> Pane[
        TabView[{"Type I" -> Style[
            Grid[{{
               Toolbox`v["r1a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
                 Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a1", "r1a"] 
                 Toolbox`species["E1", "compartment"][Toolbox`t] 
                 Toolbox`species["KKK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r1b"], Toolbox`parameter["k2", "r1b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["E1_KKK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r2a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
                 Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a2", "r2a"] 
                 Toolbox`species["E2", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r2b"], Toolbox`parameter["k2", "r2b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r3a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a3", "r3a"] 
                 Toolbox`species["KK", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d3", "r3a"] 
                Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r3b"], Toolbox`parameter["k3", "r3b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r4a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
                 Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a4", "r4a"] 
                 Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r4b"], Toolbox`parameter["k4", "r4b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r5a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a5", "r5a"] 
                 Toolbox`species["P_KK", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d5", "r5a"] 
                Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r5b"], Toolbox`parameter["k5", "r5b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r6a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
                 Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a6", "r6a"] 
                 Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r6b"], Toolbox`parameter["k6", "r6b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r7a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a7", "r7a"] 
                 Toolbox`species["K", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d7", "r7a"] 
                Toolbox`species["PP_KK_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r7b"], Toolbox`parameter["k7", "r7b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r8a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
                 Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a8", "r8a"] 
                 Toolbox`species["KPase", "compartment"][Toolbox`t] 
                 Toolbox`species["P_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r8b"], Toolbox`parameter["k8", "r8b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KPase_P_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r9a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a9", "r9a"] 
                 Toolbox`species["P_K", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d9", "r9a"] 
                Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r9b"], Toolbox`parameter["k9", "r9b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r10a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
                 Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a10", "r10a"] 
                 Toolbox`species["KPase", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r10b"], Toolbox`parameter["k10", "r10b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t]}}, 
             Dividers -> {True, All}, Background -> {None, {{
                 GrayLevel[0.99], 
                 RGBColor[0.87, 0.94, 1]}}}, Spacings -> {1, 1}], FontSize -> 
            12], "Type II" -> Style[
            Grid[{{
               Toolbox`v["r1a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
                 Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a1", "r1a"] 
                 Toolbox`species["E1", "compartment"][Toolbox`t] 
                 Toolbox`species["KKK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r1b"], Toolbox`parameter["k2", "r1b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["E1_KKK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r2a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
                 Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a2", "r2a"] 
                 Toolbox`species["E2", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r2b"], Toolbox`parameter["k2", "r2b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r3a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a3", "r3a"] 
                 Toolbox`species["KK", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d3", "r3a"] 
                Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r3b"], Toolbox`parameter["k3", "r3b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r4a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
                 Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a4", "r4a"] 
                 Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r4b"], Toolbox`parameter["k4", "r4b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r5a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a5", "r5a"] 
                 Toolbox`species["P_KK", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d5", "r5a"] 
                Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r5b"], Toolbox`parameter["k5", "r5b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r6a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
                 Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a6", "r6a"] 
                 Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r6b"], Toolbox`parameter["k6", "r6b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r7a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a7", "r7a"] 
                 Toolbox`species["K", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d7", "r7a"] 
                Toolbox`species["PP_KK_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r7b"], Toolbox`parameter["k7", "r7b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r8a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
                 Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a8", "r8a"] 
                 Toolbox`species["KPase", "compartment"][Toolbox`t] 
                 Toolbox`species["P_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r8b"], Toolbox`parameter["k8", "r8b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KPase_P_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r9a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a9", "r9a"] 
                 Toolbox`species["P_K", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d9", "r9a"] 
                Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r9b"], Toolbox`parameter["k9", "r9b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r10a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
                 Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a10", "r10a"] 
                 Toolbox`species["KPase", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r10b"], Toolbox`parameter["k10", "r10b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t]}}, 
             Dividers -> {True, All}, Background -> {None, {{
                 GrayLevel[0.99], 
                 RGBColor[0.87, 0.94, 1]}}}, Spacings -> {1, 1}], FontSize -> 
            12], "Type III" -> Style[
            Grid[{{
               Toolbox`v["r1a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
                 Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a1", "r1a"] 
                 Toolbox`species["E1", "compartment"][Toolbox`t] 
                 Toolbox`species["KKK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r1b"], Toolbox`parameter["k2", "r1b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["E1_KKK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r2a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
                 Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a2", "r2a"] 
                 Toolbox`species["E2", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r2b"], Toolbox`parameter["k2", "r2b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r3a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a3", "r3a"] 
                 Toolbox`species["KK", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d3", "r3a"] 
                Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r3b"], Toolbox`parameter["k3", "r3b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r4a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
                 Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a4", "r4a"] 
                 Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r4b"], Toolbox`parameter["k4", "r4b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r5a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a5", "r5a"] 
                 Toolbox`species["P_KK", "compartment"][Toolbox`t] 
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d5", "r5a"] 
                Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r5b"], Toolbox`parameter["k5", "r5b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r6a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
                 Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a6", "r6a"] 
                 Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t])}, {
               Toolbox`v["r6b"], Toolbox`parameter["k6", "r6b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t]}, {
               Toolbox`v["r7a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a7", "r7a"] 
                 Toolbox`species["K", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d7", "r7a"] 
                Toolbox`species["PP_KK_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r7b"], Toolbox`parameter["k7", "r7b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r8a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
                 Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a8", "r8a"] 
                 Toolbox`species["KPase", "compartment"][Toolbox`t] 
                 Toolbox`species["P_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r8b"], Toolbox`parameter["k8", "r8b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KPase_P_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r9a"], 
               Toolbox`parameter["Volume", "compartment"] (
                Toolbox`parameter["a9", "r9a"] 
                 Toolbox`species["P_K", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                Toolbox`parameter["d9", "r9a"] 
                Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r9b"], Toolbox`parameter["k9", "r9b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]}, {
               Toolbox`v["r10a"], 
               Toolbox`parameter[
                "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
                 Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                Toolbox`parameter["a10", "r10a"] 
                 Toolbox`species["KPase", "compartment"][Toolbox`t] 
                 Toolbox`species["PP_K", "compartment"][Toolbox`t])}, {
               Toolbox`v["r10b"], Toolbox`parameter["k10", "r10b"] 
               Toolbox`parameter["Volume", "compartment"] 
               Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t]}}, 
             Dividers -> {True, All}, Background -> {None, {{
                 GrayLevel[0.99], 
                 RGBColor[0.87, 0.94, 1]}}}, Spacings -> {1, 1}], FontSize -> 
            12]}], {{800}, {450}}, Scrollbars -> {False, True}], "ODE" -> Pane[
        Style[
         Column[{Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["E1", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k2", "r1b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["E1_KKK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
              Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a1", "r1a"] 
              Toolbox`species["E1", "compartment"][Toolbox`t] 
              Toolbox`species["KKK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["E2", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k2", "r2b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
              Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a2", "r2a"] 
              Toolbox`species["E2", "compartment"][Toolbox`t] 
              Toolbox`species["P_KKK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["K", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k8", "r8b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a7", "r7a"] 
              Toolbox`species["K", "compartment"][Toolbox`t] 
              Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d7", "r7a"] 
             Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KK", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k4", "r4b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a3", "r3a"] 
              Toolbox`species["KK", "compartment"][Toolbox`t] 
              Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d3", "r3a"] 
             Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KKPase", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k4", "r4b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
            Toolbox`parameter["k6", "r6b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
              Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a4", "r4a"] 
              Toolbox`species["KKPase", "compartment"][Toolbox`t] 
              Toolbox`species["P_KK", "compartment"][Toolbox`t]) - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
              Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a6", "r6a"] 
              Toolbox`species["KKPase", "compartment"][Toolbox`t] 
              Toolbox`species["PP_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KKPase_P_KK", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k4", "r4b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
            Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
               Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a4", "r4a"] 
               Toolbox`species["KKPase", "compartment"][Toolbox`t] 
               Toolbox`species["P_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KPase", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k8", "r8b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
            Toolbox`parameter["k10", "r10b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
              Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a8", "r8a"] 
              Toolbox`species["KPase", "compartment"][Toolbox`t] 
              Toolbox`species["P_K", "compartment"][Toolbox`t]) - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
              Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a10", "r10a"] 
              Toolbox`species["KPase", "compartment"][Toolbox`t] 
              Toolbox`species["PP_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KPase_P_K", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k8", "r8b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
            Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
               Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a8", "r8a"] 
               Toolbox`species["KPase", "compartment"][Toolbox`t] 
               Toolbox`species["P_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["P_K", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k10", "r10b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
              Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a8", "r8a"] 
              Toolbox`species["KPase", "compartment"][Toolbox`t] 
              Toolbox`species["P_K", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k7", "r7b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a9", "r9a"] 
              Toolbox`species["P_K", "compartment"][Toolbox`t] 
              Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d9", "r9a"] 
             Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["P_KK", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k6", "r6b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
              Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a4", "r4a"] 
              Toolbox`species["KKPase", "compartment"][Toolbox`t] 
              Toolbox`species["P_KK", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k3", "r3b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a5", "r5a"] 
              Toolbox`species["P_KK", "compartment"][Toolbox`t] 
              Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d5", "r5a"] 
             Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["P_KKK", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k2", "r1b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["E1_KKK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
              Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a2", "r2a"] 
              Toolbox`species["E2", "compartment"][Toolbox`t] 
              Toolbox`species["P_KKK", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k3", "r3b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a3", "r3a"] 
              Toolbox`species["KK", "compartment"][Toolbox`t] 
              Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d3", "r3a"] 
             Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k5", "r5b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a5", "r5a"] 
              Toolbox`species["P_KK", "compartment"][Toolbox`t] 
              Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d5", "r5a"] 
             Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["P_KKK_KK", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k3", "r3b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
            Toolbox`parameter["Volume", "compartment"] (
              Toolbox`parameter["a3", "r3a"] 
               Toolbox`species["KK", "compartment"][Toolbox`t] 
               Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
              Toolbox`parameter["d3", "r3a"] 
              Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["PP_K", "compartment"]][Toolbox`t] == -
             Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
               Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a10", "r10a"] 
               Toolbox`species["KPase", "compartment"][Toolbox`t] 
               Toolbox`species["PP_K", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k9", "r9b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t], 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["PP_KK_K", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k7", "r7b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
            Toolbox`parameter["Volume", "compartment"] (
              Toolbox`parameter["a7", "r7a"] 
               Toolbox`species["K", "compartment"][Toolbox`t] 
               Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
              Toolbox`parameter["d7", "r7a"] 
              Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["PP_KK_P_K", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k9", "r9b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t] + 
            Toolbox`parameter["Volume", "compartment"] (
              Toolbox`parameter["a9", "r9a"] 
               Toolbox`species["P_K", "compartment"][Toolbox`t] 
               Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
              Toolbox`parameter["d9", "r9a"] 
              Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["E1_KKK", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k2", "r1b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
            Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
               Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a1", "r1a"] 
               Toolbox`species["E1", "compartment"][Toolbox`t] 
               Toolbox`species["KKK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["E2_P_KKK", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k2", "r2b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
            Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
               Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a2", "r2a"] 
               Toolbox`species["E2", "compartment"][Toolbox`t] 
               Toolbox`species["P_KKK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KKK", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k2", "r2b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
              Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a1", "r1a"] 
              Toolbox`species["E1", "compartment"][Toolbox`t] 
              Toolbox`species["KKK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KKPase_PP_KK", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k6", "r6b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
            Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
               Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a6", "r6a"] 
               Toolbox`species["KKPase", "compartment"][Toolbox`t] 
               Toolbox`species["PP_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["KPase_PP_K", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k10", "r10b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
            Toolbox`parameter[
              "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
               Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
              Toolbox`parameter["a10", "r10a"] 
               Toolbox`species["KPase", "compartment"][Toolbox`t] 
               Toolbox`species["PP_K", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["P_KKK_P_KK", "compartment"]][Toolbox`t] == -
             Toolbox`parameter["k5", "r5b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t] + 
            Toolbox`parameter["Volume", "compartment"] (
              Toolbox`parameter["a5", "r5a"] 
               Toolbox`species["P_KK", "compartment"][Toolbox`t] 
               Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
              Toolbox`parameter["d5", "r5a"] 
              Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]), 
           Toolbox`parameter["Volume", "compartment"] Derivative[1][
              Toolbox`species["PP_KK", "compartment"]][Toolbox`t] == 
           Toolbox`parameter["k5", "r5b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t] - 
            Toolbox`parameter[
             "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
              Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
             Toolbox`parameter["a6", "r6a"] 
              Toolbox`species["KKPase", "compartment"][Toolbox`t] 
              Toolbox`species["PP_KK", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k7", "r7b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a7", "r7a"] 
              Toolbox`species["K", "compartment"][Toolbox`t] 
              Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d7", "r7a"] 
             Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]) + 
            Toolbox`parameter["k9", "r9b"] 
             Toolbox`parameter["Volume", "compartment"] 
             Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t] - 
            Toolbox`parameter["Volume", "compartment"] (
             Toolbox`parameter["a9", "r9a"] 
              Toolbox`species["P_K", "compartment"][Toolbox`t] 
              Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
             Toolbox`parameter["d9", "r9a"] 
             Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
           Toolbox`species["K_PP_norm", "compartment"][
            Toolbox`t] == (
             Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
             Toolbox`species["PP_K", "compartment"][Toolbox`t])/(
            Toolbox`species["K", "compartment"][Toolbox`t] + 
            Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
            Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
            Toolbox`species["P_K", "compartment"][Toolbox`t] + 
            Toolbox`species["PP_K", "compartment"][Toolbox`t] + 
            Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
            Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
           Toolbox`species["rel_K_PP_max", "compartment"][Toolbox`t] == 
           Toolbox`parameter["K_PP_norm_max"]^(-1) 
            Toolbox`species["K_PP_norm", "compartment"][Toolbox`t], 
           Toolbox`species["KK_PP_norm", "compartment"][
            Toolbox`t] == (
             Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
             Toolbox`species["PP_KK", "compartment"][Toolbox`t] + 
             Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
             Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t])/(
            Toolbox`species["KK", "compartment"][Toolbox`t] + 
            Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["P_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["PP_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
            Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
           Toolbox`species["KKK_P_norm", "compartment"][
            Toolbox`t] == (Toolbox`species["P_KKK", "compartment"][Toolbox`t] + 
             Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
             Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])/(
            Toolbox`species["KKK", "compartment"][Toolbox`t] + 
            Toolbox`species["P_KKK", "compartment"][Toolbox`t] + 
            Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
            Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])}, 
          Dividers -> {True, All}, Background -> {{
             GrayLevel[0.99], 
             RGBColor[0.87, 0.94, 1]}}, Spacings -> {1, 1}], FontSize -> 
         10], {{800}, {450}}, Scrollbars -> {False, True}], "Constraints" -> 
      Pane[
        Style[
         TableForm[{
          0 <= Toolbox`v["r1b"] <= DirectedInfinity[1], 0 <= Toolbox`v["r2b"] <= 
           DirectedInfinity[1], 0 <= Toolbox`v["r3b"] <= DirectedInfinity[1], 
           0 <= Toolbox`v["r4b"] <= DirectedInfinity[1], 0 <= 
           Toolbox`v["r5b"] <= DirectedInfinity[1], 0 <= Toolbox`v["r6b"] <= 
           DirectedInfinity[1], 0 <= Toolbox`v["r7b"] <= DirectedInfinity[1], 
           0 <= Toolbox`v["r8b"] <= DirectedInfinity[1], 0 <= 
           Toolbox`v["r9b"] <= DirectedInfinity[1], 0 <= Toolbox`v["r10b"] <= 
           DirectedInfinity[1]}], FontSize -> 10], {{800}, {450}}, 
        Scrollbars -> {True, True}], "Initial conditions" -> Pane[
        Style[
         TableForm[{Derivative[1][
             Toolbox`species["E1", "compartment"]][0] == 
           AutomaticUnits`Unit[0.00003, "Liter"^(-1) "micromole"], 
           Derivative[1][
             Toolbox`species["E2", "compartment"]][0] == 
           AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"], 
           Derivative[1][
             Toolbox`species["KKK", "compartment"]][0] == 
           AutomaticUnits`Unit[0.003, "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["P_KKK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KK", "compartment"]][0] == 
           AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["P_KK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["PP_KK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["K", "compartment"]][0] == 
           AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["P_K", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["PP_K", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KPase", "compartment"]][0] == 
           AutomaticUnits`Unit[0.12, "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KKPase", "compartment"]][0] == 
           AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"], 
           Derivative[1][
             Toolbox`species["E1_KKK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["E2_P_KKK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["P_KKK_KK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["P_KKK_P_KK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["PP_KK_K", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["PP_KK_P_K", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KKPase_PP_KK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KKPase_P_KK", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KPase_PP_K", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["KPase_P_K", "compartment"]][0] == 
           AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], Derivative[1][
             Toolbox`species["K_PP_norm", "compartment"]][0] == 0., 
           Derivative[1][
             Toolbox`species["rel_K_PP_max", "compartment"]][0] == 0., 
           Derivative[1][
             Toolbox`species["KK_PP_norm", "compartment"]][0] == 0., 
           Derivative[1][
             Toolbox`species["KKK_P_norm", "compartment"]][0] == 0.}], 
         FontSize -> 10], {{800}, {450}}, Scrollbars -> {True, True}], 
      "Parameters" -> Pane[
        Style[
         TableForm[{{
            Toolbox`parameter["K_PP_norm_max"], 0.900049}, {
            Toolbox`parameter["Volume", "compartment"], 
            AutomaticUnits`Unit[4.*^-12, "Liter"]}, {
            Toolbox`parameter["a1", "r1a"], 1000.}, {
            Toolbox`parameter["d1", "r1a"], 150.}, {
            Toolbox`parameter["k2", "r1b"], 150.}, {
            Toolbox`parameter["a2", "r2a"], 1000.}, {
            Toolbox`parameter["d2", "r2a"], 150.}, {
            Toolbox`parameter["k2", "r2b"], 150.}, {
            Toolbox`parameter["a3", "r3a"], 1000.}, {
            Toolbox`parameter["d3", "r3a"], 150.}, {
            Toolbox`parameter["k3", "r3b"], 150.}, {
            Toolbox`parameter["a4", "r4a"], 1000.}, {
            Toolbox`parameter["d4", "r4a"], 150.}, {
            Toolbox`parameter["k4", "r4b"], 150.}, {
            Toolbox`parameter["a5", "r5a"], 1000.}, {
            Toolbox`parameter["d5", "r5a"], 150.}, {
            Toolbox`parameter["k5", "r5b"], 150.}, {
            Toolbox`parameter["a6", "r6a"], 1000.}, {
            Toolbox`parameter["d6", "r6a"], 150.}, {
            Toolbox`parameter["k6", "r6b"], 150.}, {
            Toolbox`parameter["a7", "r7a"], 1000.}, {
            Toolbox`parameter["d7", "r7a"], 150.}, {
            Toolbox`parameter["k7", "r7b"], 150.}, {
            Toolbox`parameter["a8", "r8a"], 1000.}, {
            Toolbox`parameter["d8", "r8a"], 150.}, {
            Toolbox`parameter["k8", "r8b"], 150.}, {
            Toolbox`parameter["a9", "r9a"], 1000.}, {
            Toolbox`parameter["d9", "r9a"], 150.}, {
            Toolbox`parameter["k9", "r9b"], 150.}, {
            Toolbox`parameter["a10", "r10a"], 1000.}, {
            Toolbox`parameter["d10", "r10a"], 150.}, {
            Toolbox`parameter["k10", "r10b"], 150.}}], FontSize -> 10], {{
        800}, {450}}, Scrollbars -> {True, True}], "GPR" -> 
      SlideView[{"No GPR associations defined"}, AppearanceElements -> All, 
        ImageSize -> {{800}, {450}}], "Pathway map" -> Manipulate[
        Toolbox`visualizePathways[
         Toolbox`pathwaytize[
          Toolbox`model2bipartite[
           
           Toolbox`MASSmodel[{
            "ID" -> "BIOMD0000000009", "Stoichiometry" -> 
             SparseArray[
              Automatic, {22, 20}, 0, {
               1, {{0, 2, 4, 6, 8, 12, 14, 18, 20, 24, 28, 34, 36, 38, 40, 42,
                  44, 46, 48, 50, 52, 54, 60}, {{1}, {2}, {3}, {4}, {13}, {
                 16}, {5}, {8}, {7}, {8}, {11}, {12}, {7}, {8}, {15}, {16}, {
                 19}, {20}, {15}, {16}, {14}, {15}, {17}, {20}, {6}, {7}, {
                 9}, {12}, {2}, {3}, {5}, {6}, {9}, {10}, {5}, {6}, {18}, {
                 19}, {13}, {14}, {17}, {18}, {1}, {2}, {3}, {4}, {1}, {4}, {
                 11}, {12}, {19}, {20}, {9}, {10}, {10}, {11}, {13}, {14}, {
                 17}, {18}}}, {-1, 1, -1, 1, -1, 1, -1, 1, -1, 1, -1, 1, 
                1, -1, -1, 1, -1, 1, 1, -1, 1, -1, -1, 1, 1, -1, -1, 1, 
                1, -1, -1, 1, -1, 1, 1, -1, 1, -1, 1, -1, 1, -1, 1, -1, 
                1, -1, -1, 1, 1, -1, 1, -1, 1, -1, 1, -1, -1, 1, -1, 1}}], 
             "Species" -> {
               Toolbox`species["E1", "compartment"], 
               Toolbox`species["E2", "compartment"], 
               Toolbox`species["K", "compartment"], 
               Toolbox`species["KK", "compartment"], 
               Toolbox`species["KKPase", "compartment"], 
               Toolbox`species["KKPase_P_KK", "compartment"], 
               Toolbox`species["KPase", "compartment"], 
               Toolbox`species["KPase_P_K", "compartment"], 
               Toolbox`species["P_K", "compartment"], 
               Toolbox`species["P_KK", "compartment"], 
               Toolbox`species["P_KKK", "compartment"], 
               Toolbox`species["P_KKK_KK", "compartment"], 
               Toolbox`species["PP_K", "compartment"], 
               Toolbox`species["PP_KK_K", "compartment"], 
               Toolbox`species["PP_KK_P_K", "compartment"], 
               Toolbox`species["E1_KKK", "compartment"], 
               Toolbox`species["E2_P_KKK", "compartment"], 
               Toolbox`species["KKK", "compartment"], 
               Toolbox`species["KKPase_PP_KK", "compartment"], 
               Toolbox`species["KPase_PP_K", "compartment"], 
               Toolbox`species["P_KKK_P_KK", "compartment"], 
               Toolbox`species["PP_KK", "compartment"]}, "Fluxes" -> {
               Toolbox`v["r1a"], 
               Toolbox`v["r1b"], 
               Toolbox`v["r2a"], 
               Toolbox`v["r2b"], 
               Toolbox`v["r3a"], 
               Toolbox`v["r3b"], 
               Toolbox`v["r4a"], 
               Toolbox`v["r4b"], 
               Toolbox`v["r5a"], 
               Toolbox`v["r5b"], 
               Toolbox`v["r6a"], 
               Toolbox`v["r6b"], 
               Toolbox`v["r7a"], 
               Toolbox`v["r7b"], 
               Toolbox`v["r8a"], 
               Toolbox`v["r8b"], 
               Toolbox`v["r9a"], 
               Toolbox`v["r9b"], 
               Toolbox`v["r10a"], 
               Toolbox`v["r10b"]}, "Constraints" -> {Toolbox`v["r1b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r2b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r3b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r4b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r5b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r6b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r7b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r8b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r9b"] -> {0, 
                 DirectedInfinity[1]}, Toolbox`v["r10b"] -> {0, 
                 DirectedInfinity[1]}}, 
             "InitialConditions" -> {
              Toolbox`species["E1", "compartment"] -> 
               AutomaticUnits`Unit[0.00003, "Liter"^(-1) "micromole"], 
               Toolbox`species["E2", "compartment"] -> 
               AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"], 
               Toolbox`species["KKK", "compartment"] -> 
               AutomaticUnits`Unit[0.003, "Liter"^(-1) "micromole"], 
               Toolbox`species["P_KKK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["KK", "compartment"] -> 
               AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"], 
               Toolbox`species["P_KK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["PP_KK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["K", "compartment"] -> 
               AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"], 
               Toolbox`species["P_K", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["PP_K", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["KPase", "compartment"] -> 
               AutomaticUnits`Unit[0.12, "Liter"^(-1) "micromole"], 
               Toolbox`species["KKPase", "compartment"] -> 
               AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"], 
               Toolbox`species["E1_KKK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["E2_P_KKK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["P_KKK_KK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["P_KKK_P_KK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["PP_KK_K", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["PP_KK_P_K", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["KKPase_PP_KK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["KKPase_P_KK", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["KPase_PP_K", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["KPase_P_K", "compartment"] -> 
               AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"], 
               Toolbox`species["K_PP_norm", "compartment"] -> 0., 
               Toolbox`species["rel_K_PP_max", "compartment"] -> 0., 
               Toolbox`species["KK_PP_norm", "compartment"] -> 0., 
               Toolbox`species["KKK_P_norm", "compartment"] -> 0.}, 
             "Parameters" -> {
              Toolbox`parameter["K_PP_norm_max"] -> 0.900049, 
               Toolbox`parameter["Volume", "compartment"] -> 
               AutomaticUnits`Unit[4.*^-12, "Liter"], 
               Toolbox`parameter["a1", "r1a"] -> 1000., 
               Toolbox`parameter["d1", "r1a"] -> 150., 
               Toolbox`parameter["k2", "r1b"] -> 150., 
               Toolbox`parameter["a2", "r2a"] -> 1000., 
               Toolbox`parameter["d2", "r2a"] -> 150., 
               Toolbox`parameter["k2", "r2b"] -> 150., 
               Toolbox`parameter["a3", "r3a"] -> 1000., 
               Toolbox`parameter["d3", "r3a"] -> 150., 
               Toolbox`parameter["k3", "r3b"] -> 150., 
               Toolbox`parameter["a4", "r4a"] -> 1000., 
               Toolbox`parameter["d4", "r4a"] -> 150., 
               Toolbox`parameter["k4", "r4b"] -> 150., 
               Toolbox`parameter["a5", "r5a"] -> 1000., 
               Toolbox`parameter["d5", "r5a"] -> 150., 
               Toolbox`parameter["k5", "r5b"] -> 150., 
               Toolbox`parameter["a6", "r6a"] -> 1000., 
               Toolbox`parameter["d6", "r6a"] -> 150., 
               Toolbox`parameter["k6", "r6b"] -> 150., 
               Toolbox`parameter["a7", "r7a"] -> 1000., 
               Toolbox`parameter["d7", "r7a"] -> 150., 
               Toolbox`parameter["k7", "r7b"] -> 150., 
               Toolbox`parameter["a8", "r8a"] -> 1000., 
               Toolbox`parameter["d8", "r8a"] -> 150., 
               Toolbox`parameter["k8", "r8b"] -> 150., 
               Toolbox`parameter["a9", "r9a"] -> 1000., 
               Toolbox`parameter["d9", "r9a"] -> 150., 
               Toolbox`parameter["k9", "r9b"] -> 150., 
               Toolbox`parameter["a10", "r10a"] -> 1000., 
               Toolbox`parameter["d10", "r10a"] -> 150., 
               Toolbox`parameter["k10", "r10b"] -> 150.}, "GPR" -> {}, 
             "BoundaryConditions" -> {}, "Constant" -> {}, 
             "ReversibleColumnIndices" -> {1, 3, 5, 7, 9, 11, 13, 15, 17, 19},
              "CustomRateLaws" -> {
              Toolbox`v["r1a"] -> 
               Toolbox`parameter[
                 "Volume", "compartment"] (-Toolbox`parameter["d1", "r1a"] 
                  Toolbox`species["E1_KKK", "compartment"][Toolbox`t] + 
                 Toolbox`parameter["a1", "r1a"] 
                  Toolbox`species["E1", "compartment"][Toolbox`t] 
                  Toolbox`species["KKK", "compartment"][Toolbox`t]), 
               Toolbox`v["r1b"] -> 
               Toolbox`parameter["k2", "r1b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["E1_KKK", "compartment"][Toolbox`t], 
               Toolbox`v["r2a"] -> 
               Toolbox`parameter[
                 "Volume", "compartment"] (-Toolbox`parameter["d2", "r2a"] 
                  Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t] + 
                 Toolbox`parameter["a2", "r2a"] 
                  Toolbox`species["E2", "compartment"][Toolbox`t] 
                  Toolbox`species["P_KKK", "compartment"][Toolbox`t]), 
               Toolbox`v["r2b"] -> 
               Toolbox`parameter["k2", "r2b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["E2_P_KKK", "compartment"][Toolbox`t], 
               Toolbox`v["r3a"] -> 
               Toolbox`parameter["Volume", "compartment"] (
                 Toolbox`parameter["a3", "r3a"] 
                  Toolbox`species["KK", "compartment"][Toolbox`t] 
                  Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                 Toolbox`parameter["d3", "r3a"] 
                 Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t]), 
               Toolbox`v["r3b"] -> 
               Toolbox`parameter["k3", "r3b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t], 
               Toolbox`v["r4a"] -> 
               Toolbox`parameter[
                 "Volume", "compartment"] (-Toolbox`parameter["d4", "r4a"] 
                  Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                 Toolbox`parameter["a4", "r4a"] 
                  Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                  Toolbox`species["P_KK", "compartment"][Toolbox`t]), 
               Toolbox`v["r4b"] -> 
               Toolbox`parameter["k4", "r4b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t], 
               Toolbox`v["r5a"] -> 
               Toolbox`parameter["Volume", "compartment"] (
                 Toolbox`parameter["a5", "r5a"] 
                  Toolbox`species["P_KK", "compartment"][Toolbox`t] 
                  Toolbox`species["P_KKK", "compartment"][Toolbox`t] - 
                 Toolbox`parameter["d5", "r5a"] 
                 Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t]), 
               Toolbox`v["r5b"] -> 
               Toolbox`parameter["k5", "r5b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t], 
               Toolbox`v["r6a"] -> 
               Toolbox`parameter[
                 "Volume", "compartment"] (-Toolbox`parameter["d6", "r6a"] 
                  Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                 Toolbox`parameter["a6", "r6a"] 
                  Toolbox`species["KKPase", "compartment"][Toolbox`t] 
                  Toolbox`species["PP_KK", "compartment"][Toolbox`t]), 
               Toolbox`v["r6b"] -> 
               Toolbox`parameter["k6", "r6b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t], 
               Toolbox`v["r7a"] -> 
               Toolbox`parameter["Volume", "compartment"] (
                 Toolbox`parameter["a7", "r7a"] 
                  Toolbox`species["K", "compartment"][Toolbox`t] 
                  Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                 Toolbox`parameter["d7", "r7a"] 
                 Toolbox`species["PP_KK_K", "compartment"][Toolbox`t]), 
               Toolbox`v["r7b"] -> 
               Toolbox`parameter["k7", "r7b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["PP_KK_K", "compartment"][Toolbox`t], 
               Toolbox`v["r8a"] -> 
               Toolbox`parameter[
                 "Volume", "compartment"] (-Toolbox`parameter["d8", "r8a"] 
                  Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                 Toolbox`parameter["a8", "r8a"] 
                  Toolbox`species["KPase", "compartment"][Toolbox`t] 
                  Toolbox`species["P_K", "compartment"][Toolbox`t]), 
               Toolbox`v["r8b"] -> 
               Toolbox`parameter["k8", "r8b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["KPase_P_K", "compartment"][Toolbox`t], 
               Toolbox`v["r9a"] -> 
               Toolbox`parameter["Volume", "compartment"] (
                 Toolbox`parameter["a9", "r9a"] 
                  Toolbox`species["P_K", "compartment"][Toolbox`t] 
                  Toolbox`species["PP_KK", "compartment"][Toolbox`t] - 
                 Toolbox`parameter["d9", "r9a"] 
                 Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
               Toolbox`v["r9b"] -> 
               Toolbox`parameter["k9", "r9b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t], 
               Toolbox`v["r10a"] -> 
               Toolbox`parameter[
                 "Volume", "compartment"] (-Toolbox`parameter["d10", "r10a"] 
                  Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                 Toolbox`parameter["a10", "r10a"] 
                  Toolbox`species["KPase", "compartment"][Toolbox`t] 
                  Toolbox`species["PP_K", "compartment"][Toolbox`t]), 
               Toolbox`v["r10b"] -> 
               Toolbox`parameter["k10", "r10b"] 
                Toolbox`parameter["Volume", "compartment"] 
                Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t]}, 
             "CustomODE" -> {
              Toolbox`species["K_PP_norm", "compartment"][
                Toolbox`t] == (
                 Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                 Toolbox`species["PP_K", "compartment"][Toolbox`t])/(
                Toolbox`species["K", "compartment"][Toolbox`t] + 
                Toolbox`species["KPase_P_K", "compartment"][Toolbox`t] + 
                Toolbox`species["KPase_PP_K", "compartment"][Toolbox`t] + 
                Toolbox`species["P_K", "compartment"][Toolbox`t] + 
                Toolbox`species["PP_K", "compartment"][Toolbox`t] + 
                Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
                Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
               Toolbox`species["rel_K_PP_max", "compartment"][Toolbox`t] == 
               Toolbox`parameter["K_PP_norm_max"]^(-1) 
                Toolbox`species["K_PP_norm", "compartment"][Toolbox`t], 
               Toolbox`species["KK_PP_norm", "compartment"][
                Toolbox`t] == (
                 Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                 Toolbox`species["PP_KK", "compartment"][Toolbox`t] + 
                 Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
                 Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t])/(
                Toolbox`species["KK", "compartment"][Toolbox`t] + 
                Toolbox`species["KKPase_P_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["KKPase_PP_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["P_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["PP_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["PP_KK_K", "compartment"][Toolbox`t] + 
                Toolbox`species["PP_KK_P_K", "compartment"][Toolbox`t]), 
               Toolbox`species["KKK_P_norm", "compartment"][
                Toolbox`t] == (
                 Toolbox`species["P_KKK", "compartment"][Toolbox`t] + 
                 Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
                 Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])/(
                Toolbox`species["KKK", "compartment"][Toolbox`t] + 
                Toolbox`species["P_KKK", "compartment"][Toolbox`t] + 
                Toolbox`species["P_KKK_KK", "compartment"][Toolbox`t] + 
                Toolbox`species["P_KKK_P_KK", "compartment"][Toolbox`t])}, 
             "Name" -> "Huang1996 - Ultrasensitivity in MAPK cascade", 
             "ElementalComposition" -> {
              Toolbox`species["E1", "compartment"] -> "&E1&", 
               Toolbox`species["E1_KKK", "compartment"] -> "&E1_KKK&", 
               Toolbox`species["E2", "compartment"] -> "&E2&", 
               Toolbox`species["E2_P_KKK", "compartment"] -> "&E2_P_KKK&", 
               Toolbox`species["K", "compartment"] -> "&K&", 
               Toolbox`species["KK", "compartment"] -> "&KK&", 
               Toolbox`species["KKK", "compartment"] -> "&KKK&", 
               Toolbox`species["KKPase", "compartment"] -> "&KKPase&", 
               Toolbox`species["KKPase_P_KK", "compartment"] -> 
               "&KKPase_P_KK&", 
               Toolbox`species["KKPase_PP_KK", "compartment"] -> 
               "&KKPase_PP_KK&", Toolbox`species["KPase", "compartment"] -> 
               "&KPase&", Toolbox`species["KPase_P_K", "compartment"] -> 
               "&KPase_P_K&", Toolbox`species["KPase_PP_K", "compartment"] -> 
               "&KPase_PP_K&", Toolbox`species["P_K", "compartment"] -> 
               "&P_K&", Toolbox`species["P_KK", "compartment"] -> "&P_KK&", 
               Toolbox`species["P_KKK", "compartment"] -> "&P_KKK&", 
               Toolbox`species["P_KKK_KK", "compartment"] -> "&P_KKK_KK&", 
               Toolbox`species["P_KKK_P_KK", "compartment"] -> "&P_KKK_P_KK&",
                Toolbox`species["PP_K", "compartment"] -> "&PP_K&", 
               Toolbox`species["PP_KK", "compartment"] -> "&PP_KK&", 
               Toolbox`species["PP_KK_K", "compartment"] -> "&PP_KK_K&", 
               Toolbox`species["PP_KK_P_K", "compartment"] -> "&PP_KK_P_K&"}, 
             "Notes" -> 
             "Huang1996 - Ultrasensitivity in MAPK cascade  \n \nThe temporal \
sequence of kinase activation, from MAPKKK (activated RAF) to the final \
effector MAPK (activated ERK), is described here. It is observed from the \
model that there is an increase in sensitivity along the levels of the \
cascade, where the activity of MAPK reaches its maximal before MAPKKK.    \n \
\nThis model is described in the article:  \n  Ultrasensitivity in the \
mitogen-activated protein kinase cascade.    \nHuang CY, Ferrell JE Jr  \n\
Proc. Natl. Acad. Sci. U.S.A. 1996:93(19):10078-83  \nAbstract:  \n \nThe \
mitogen-activated protein kinase (MAPK) cascade is a highly conserved series \
of three protein kinases implicated in diverse biological processes. Here we \
demonstrate that the cascade arrangement has unexpected consequences for the \
dynamics of MAPK signaling. We solved the rate equations for the cascade \
numerically and found that MAPK is predicted to behave like a highly \
cooperative enzyme, even though it was not assumed that any of the enzymes in \
the cascade were regulated cooperatively. Measurements of MAPK activation in \
Xenopus oocyte extracts confirmed this prediction. The stimulus/response \
curve of the MAPK was found to be as steep as that of a cooperative enzyme \
with a Hill coefficient of 4-5, well in excess of that of the classical \
allosteric protein hemoglobin. The shape of the MAPK stimulus/ response curve \
may make the cascade particularly appropriate for mediating processes like \
mitogenesis, cell fate induction, and oocyte maturation, where a cell \
switches from one discrete state to another.      \n \nThe species K_PP_norm, \
KKK_P_norm and KK_PP_norm are the relative concentrations of the active MAPK, \
MAPKK and MAPKKK, that is the double, or single resp. phophorylated forms \
divided by the total concentrations of each kinase. For MAPK additionally the \
also active MAPK divided by the maximal concentration of active MAPK is given \
by rel_K_PP_max. The parameter K_PP_norm_max, the maximal ratio of active \
MapK, has to be calculated for each change of parameters.    \n \nThis model \
is hosted on BioModels Database and identified by: BIOMD0000000009 .  \nTo \
cite BioModels Database, please use: BioModels Database: An enhanced, curated \
and annotated resource for published quantitative kinetic models .    \n \nTo \
the extent possible under law, all copyright and related or neighbouring \
rights to this encoded model have been dedicated to the public domain \
worldwide. Please refer to CC0 Public Domain Dedication for more \
information.", "Ignore" -> {}, "UnitChecking" -> False, 
             "Synonyms" -> {
              Toolbox`species["E1", "compartment"] -> 
               "MAPKKK activator (Ras)", Toolbox`species["E2", "compartment"] -> 
               "MAPKKK inactivator", Toolbox`species["KKK", "compartment"] -> 
               "Mos", Toolbox`species["P_KKK", "compartment"] -> "Mos-P", 
               Toolbox`species["KK", "compartment"] -> "Mek1", 
               Toolbox`species["P_KK", "compartment"] -> "Mek1-P", 
               Toolbox`species["PP_KK", "compartment"] -> "Mek1-PP", 
               Toolbox`species["K", "compartment"] -> "Erk2", 
               Toolbox`species["P_K", "compartment"] -> "Erk2-P", 
               Toolbox`species["PP_K", "compartment"] -> "Erk2-PP", 
               Toolbox`species["KPase", "compartment"] -> "MAPK-Pase", 
               Toolbox`species["KKPase", "compartment"] -> "MAPKK-Pase", 
               Toolbox`species["E1_KKK", "compartment"] -> "E1_Mos", 
               Toolbox`species["E2_P_KKK", "compartment"] -> "E2_Mos-P", 
               Toolbox`species["P_KKK_KK", "compartment"] -> "P-Mos_Mek1", 
               Toolbox`species["P_KKK_P_KK", "compartment"] -> "P-Mos_P-Mek1",
                Toolbox`species["PP_KK_K", "compartment"] -> "PP-Mek1_Erk2", 
               Toolbox`species["PP_KK_P_K", "compartment"] -> 
               "PP-Mek1_P-Erk2", 
               Toolbox`species["KKPase_PP_KK", "compartment"] -> 
               "MAPKK-Pase_PP-Mek1", 
               Toolbox`species["KKPase_P_KK", "compartment"] -> 
               "MAPKK-Pase_P-Mek1", 
               Toolbox`species["KPase_PP_K", "compartment"] -> 
               "MAPK-Pase_PP-Erk2", 
               Toolbox`species["KPase_P_K", "compartment"] -> 
               "MAPK-Pase_P-Erk2", 
               Toolbox`species["K_PP_norm", "compartment"] -> "K_PP_norm", 
               Toolbox`species["KK_PP_norm", "compartment"] -> "KK_PP_norm", 
               Toolbox`species["KKK_P_norm", "compartment"] -> "KKK_P_norm", 
               Toolbox`species["rel_K_PP_max", "compartment"] -> 
               "relative maximal K_PP"}, "Events" -> {}}]], Toolbox`p, Method -> 
          Toolbox`Private`method], Toolbox`PlotFunction -> 
         Toolbox`Private`pltfunc, 
         ImageSize -> {{Toolbox`Private`width}, {
           Toolbox`Private`height - 140}}], {{
         Toolbox`p, 0, "Currency metabolites to remove"}, 0, 22, 1}, {{
         Toolbox`Private`method, "Remove", 
          "How to treat currency metabolites"}, {"Remove", "Mask"}}, {{
         Toolbox`Private`pltfunc, LayeredGraphPlot, "Plot function"}, {
         LayeredGraphPlot, GraphPlot, TreePlot}}], "Nullspace" -> Pane[
        TableForm[{
         Toolbox`v["r10a"] + Toolbox`v["r10b"] + Toolbox`v["r9a"] + 
          Toolbox`v["r9b"], Toolbox`v["r7a"] + Toolbox`v["r7b"] + 
          Toolbox`v["r8a"] + Toolbox`v["r8b"], Toolbox`v["r5a"] + 
          Toolbox`v["r5b"] + Toolbox`v["r6a"] + Toolbox`v["r6b"], 
          Toolbox`v["r3a"] + Toolbox`v["r3b"] + Toolbox`v["r4a"] + 
          Toolbox`v["r4b"], Toolbox`v["r1a"] + Toolbox`v["r1b"] + 
          Toolbox`v["r2a"] + Toolbox`v["r2b"]}, TableHeadings -> {None, {
            Toolbox`v["r1a"], 
            Toolbox`v["r1b"], 
            Toolbox`v["r2a"], 
            Toolbox`v["r2b"], 
            Toolbox`v["r3a"], 
            Toolbox`v["r3b"], 
            Toolbox`v["r4a"], 
            Toolbox`v["r4b"], 
            Toolbox`v["r5a"], 
            Toolbox`v["r5b"], 
            Toolbox`v["r6a"], 
            Toolbox`v["r6b"], 
            Toolbox`v["r7a"], 
            Toolbox`v["r7b"], 
            Toolbox`v["r8a"], 
            Toolbox`v["r8b"], 
            Toolbox`v["r9a"], 
            Toolbox`v["r9b"], 
            Toolbox`v["r10a"], 
            Toolbox`v["r10b"]}}], {{800}, {450}}, Scrollbars -> {True, True}],
       "Left Nullspace" -> Pane[
        TableForm[{
         Toolbox`species["E1", "compartment"] + 
          Toolbox`species["E2", "compartment"] - Toolbox`species[
          "K", "compartment"] + Toolbox`species["KK", "compartment"] - 
          Toolbox`species["KKK", "compartment"] - Toolbox`species[
          "KKPase", "compartment"] + Toolbox`species["KPase", "compartment"] - 
          Toolbox`species["P_K", "compartment"] + 
          Toolbox`species["P_KK", "compartment"] - Toolbox`species[
          "P_KKK", "compartment"] - Toolbox`species["PP_K", "compartment"] + 
          Toolbox`species["PP_KK", "compartment"], -
           Toolbox`species["E1", "compartment"] - Toolbox`species[
          "E2", "compartment"] + Toolbox`species["KKK", "compartment"] + 
          Toolbox`species["P_KKK", "compartment"] + 
          Toolbox`species["P_KKK_KK", "compartment"] + 
          Toolbox`species["P_KKK_P_KK", "compartment"], 
          Toolbox`species["KPase", "compartment"] + 
          Toolbox`species["KPase_P_K", "compartment"] + 
          Toolbox`species["KPase_PP_K", "compartment"], 
          Toolbox`species["KKPase", "compartment"] + 
          Toolbox`species["KKPase_P_KK", "compartment"] + 
          Toolbox`species["KKPase_PP_KK", "compartment"], 
          Toolbox`species["E2", "compartment"] + 
          Toolbox`species["E2_P_KKK", "compartment"], 
          Toolbox`species["E1", "compartment"] + 
          Toolbox`species["E1_KKK", "compartment"], 
          Toolbox`species["K", "compartment"] - Toolbox`species[
          "KPase", "compartment"] + Toolbox`species["P_K", "compartment"] + 
          Toolbox`species["PP_K", "compartment"] + 
          Toolbox`species["PP_KK_K", "compartment"] + 
          Toolbox`species["PP_KK_P_K", "compartment"]}, 
         TableHeadings -> {None, {
            Toolbox`species["E1", "compartment"], 
            Toolbox`species["E2", "compartment"], 
            Toolbox`species["K", "compartment"], 
            Toolbox`species["KK", "compartment"], 
            Toolbox`species["KKPase", "compartment"], 
            Toolbox`species["KKPase_P_KK", "compartment"], 
            Toolbox`species["KPase", "compartment"], 
            Toolbox`species["KPase_P_K", "compartment"], 
            Toolbox`species["P_K", "compartment"], 
            Toolbox`species["P_KK", "compartment"], 
            Toolbox`species["P_KKK", "compartment"], 
            Toolbox`species["P_KKK_KK", "compartment"], 
            Toolbox`species["PP_K", "compartment"], 
            Toolbox`species["PP_KK_K", "compartment"], 
            Toolbox`species["PP_KK_P_K", "compartment"], 
            Toolbox`species["E1_KKK", "compartment"], 
            Toolbox`species["E2_P_KKK", "compartment"], 
            Toolbox`species["KKK", "compartment"], 
            Toolbox`species["KKPase_PP_KK", "compartment"], 
            Toolbox`species["KPase_PP_K", "compartment"], 
            Toolbox`species["P_KKK_P_KK", "compartment"], 
            Toolbox`species["PP_KK", "compartment"]}}], {{800}, {450}}, 
        Scrollbars -> {True, True}], "Notes" -> Pane[
        Style[
        "Huang1996 - Ultrasensitivity in MAPK cascade  \n \nThe temporal \
sequence of kinase activation, from MAPKKK (activated RAF) to the final \
effector MAPK (activated ERK), is described here. It is observed from the \
model that there is an increase in sensitivity along the levels of the \
cascade, where the activity of MAPK reaches its maximal before MAPKKK.    \n \
\nThis model is described in the article:  \n  Ultrasensitivity in the \
mitogen-activated protein kinase cascade.    \nHuang CY, Ferrell JE Jr  \n\
Proc. Natl. Acad. Sci. U.S.A. 1996:93(19):10078-83  \nAbstract:  \n \nThe \
mitogen-activated protein kinase (MAPK) cascade is a highly conserved series \
of three protein kinases implicated in diverse biological processes. Here we \
demonstrate that the cascade arrangement has unexpected consequences for the \
dynamics of MAPK signaling. We solved the rate equations for the cascade \
numerically and found that MAPK is predicted to behave like a highly \
cooperative enzyme, even though it was not assumed that any of the enzymes in \
the cascade were regulated cooperatively. Measurements of MAPK activation in \
Xenopus oocyte extracts confirmed this prediction. The stimulus/response \
curve of the MAPK was found to be as steep as that of a cooperative enzyme \
with a Hill coefficient of 4-5, well in excess of that of the classical \
allosteric protein hemoglobin. The shape of the MAPK stimulus/ response curve \
may make the cascade particularly appropriate for mediating processes like \
mitogenesis, cell fate induction, and oocyte maturation, where a cell \
switches from one discrete state to another.      \n \nThe species K_PP_norm, \
KKK_P_norm and KK_PP_norm are the relative concentrations of the active MAPK, \
MAPKK and MAPKKK, that is the double, or single resp. phophorylated forms \
divided by the total concentrations of each kinase. For MAPK additionally the \
also active MAPK divided by the maximal concentration of active MAPK is given \
by rel_K_PP_max. The parameter K_PP_norm_max, the maximal ratio of active \
MapK, has to be calculated for each change of parameters.    \n \nThis model \
is hosted on BioModels Database and identified by: BIOMD0000000009 .  \nTo \
cite BioModels Database, please use: BioModels Database: An enhanced, curated \
and annotated resource for published quantitative kinetic models .    \n \nTo \
the extent possible under law, all copyright and related or neighbouring \
rights to this encoded model have been dedicated to the public domain \
worldwide. Please refer to CC0 Public Domain Dedication for more \
information.", FontSize -> 10], {{800}, {450}}, Scrollbars -> {True, True}]}, 
     ImageSize -> {{800}, {450}}]],
   DynamicModuleValues:>{}],
  Setting[#, {0}]& ]], "Output",
 CellChangeTimes->{3.670490096586829*^9, 3.670490646325642*^9, 
  3.670490778225275*^9, 3.6716140853167224`*^9, 3.67161429140851*^9, 
  3.6775543077538795`*^9, 3.713270855132305*^9, 3.7132710244289885`*^9, 
  3.713271181686983*^9},
 ExpressionUUID -> "f54a637d-ec0e-4bea-8bb4-02192a7c9021"]
}, Open  ]],

Cell["\<\
Die automatisch erzeugte interaktive Tabelle gibt einen \
\[CapitalUDoubleDot]berblick \[UDoubleDot]ber das gerade geladene Modell. Mit \
dem Befehl simulate l\[ADoubleDot]sst sich das Modell nun numerisch \
simulieren. Dabei werden die in dem SBML-Modell abgelegten Standardwerte der \
Parameter und der Anfangsbedingungen verwendet. Diese Werte \
k\[ODoubleDot]nnen \[UDoubleDot]ber die oben angegebene Tabelle oder auch \
\[UDoubleDot]ber den Befehl\
\>", "Text",
 CellChangeTimes->{
  3.6774818723089275`*^9, {3.677481928227426*^9, 3.677481974585108*^9}, {
   3.6774822275469537`*^9, 3.6774822319149613`*^9}},
 ExpressionUUID -> "3a91f1a8-8458-4b40-ba28-b4c4c1e523e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"model", "[", "\"\<InitialConditions\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.616991921237954*^9, 3.6169919299524527`*^9}},
 ExpressionUUID -> "8c3cf289-4884-4610-9364-33f923b07ea6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["E1",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["E1", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.00003`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0.00003, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["E2",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["E2", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.0003`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["KKK",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KKK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.003`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0.003, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["P_KKK",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["P_KKK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["KK",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"1.2`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["P_KK",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["P_KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["PP_KK",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["PP_KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["K",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"1.2`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[1.2, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["P_K",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["P_K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["PP_K",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["PP_K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["KPase",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KPase", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.12`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0.12, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["KKPase",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KKPase", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.0003`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0.0003, "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox["E1_KKK",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["E1_KKK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"E2_P", "_KKK"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["E2_P_KKK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"P_KKK", "_KK"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["P_KKK_KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"P_KKK", "_P", "_KK"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["P_KKK_P_KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"PP_KK", "_K"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["PP_KK_K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"PP_KK", "_P", "_K"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["PP_KK_P_K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"KKPase_PP", "_KK"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KKPase_PP_KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"KKPase_P", "_KK"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KKPase_P_KK", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"KPase_PP", "_K"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KPase_PP_K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"KPase_P", "_K"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KPase_P_K", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", 
    InterpretationBox[
     RowBox[{"0.`", " ", 
      RowBox[{"micromole", 
       SuperscriptBox["Liter", 
        RowBox[{"-", "1"}]]}]}],
     AutomaticUnits`Unit[0., "Liter"^(-1) "micromole"],
     AutoDelete->True]}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"K_PP", "_norm"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["K_PP_norm", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", "0.`"}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"rel_K", "_PP", "_max"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["rel_K_PP_max", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", "0.`"}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"KK_PP", "_norm"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KK_PP_norm", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", "0.`"}], ",", 
   RowBox[{
    InterpretationBox[
     SuperscriptBox[
      StyleBox[
       RowBox[{"KKK_P", "_norm"}],
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]], 
      StyleBox["compartment",
       StripOnInput->False,
       ShowSyntaxStyles->False,
       AutoSpacing->False,
       ZeroWidthTimes->True,
       LineColor->RGBColor[0, 0, 0],
       FrontFaceColor->RGBColor[0, 0, 0],
       BackFaceColor->RGBColor[0, 0, 0],
       GraphicsColor->RGBColor[0, 0, 0],
       FontColor->RGBColor[0, 0, 0]]],
     Toolbox`species["KKK_P_norm", "compartment"],
     Editable->False,
     Selectable->False], "\[Rule]", "0.`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.616991930557509*^9, 3.6178487749162073`*^9, 
  3.6178490174576483`*^9, 3.6704906467000427`*^9, 3.6704907784748755`*^9, 
  3.6716140858387523`*^9, 3.6716142916225224`*^9, 3.677554308502681*^9, 
  3.713270855272313*^9, 3.713271024519994*^9, 3.7132711819549985`*^9},
 ExpressionUUID -> "23738edd-413d-4e13-867b-963d43ea80bf"]
}, Open  ]],

Cell[TextData[{
 "abgefragt werden. \[CapitalUDoubleDot]ber einen innerhalb des Pakets \
definierten ",
 StyleBox["Plot",
  FontWeight->"Bold"],
 "-Befehl lassen sich die Ergebnisse der Simulation darstellen:"
}], "Text",
 CellChangeTimes->{{3.6774819841851254`*^9, 3.6774820290734043`*^9}, {
  3.6774822202461405`*^9, 3.6774822238185472`*^9}},
 ExpressionUUID -> "6ea4a523-53b1-4d33-99d3-29b5bfb2e03c"],

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"concSol", ",", "fluxSol"}], "}"}], "=", 
    RowBox[{"simulate", "[", 
     RowBox[{"model", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "400"}], "}"}]}], "]"}]}], ";"}],
  FontColor->GrayLevel[0]]], "Input",
 CellChangeTimes->{{3.614049563510305*^9, 3.614049597298951*^9}, {
  3.616646187421036*^9, 3.616646197863765*^9}, {3.616991639150857*^9, 
  3.61699164340681*^9}, {3.616991719931168*^9, 3.616991720150769*^9}},
 ExpressionUUID -> "508693b1-441a-404e-b4c6-d2a045aa7495"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plotSimulation", "[", 
  RowBox[{
   RowBox[{"FilterRules", "[", 
    RowBox[{"concSol", ",", 
     RowBox[{"model", "[", "\"\<Species\>\"", "]"}]}], "]"}], ",", 
   RowBox[{"PlotFunction", "\[Rule]", "Plot"}], ",", 
   RowBox[{"Legend", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.614049582294355*^9, 3.614049593441156*^9}, {
   3.614049884572686*^9, 3.6140498972759943`*^9}, 3.616646199428361*^9, 
   3.616991648070613*^9, 3.61699168723792*^9},
 ExpressionUUID -> "df6d68fd-ca86-4992-a472-69da43e3d379"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwt1nc81G8cAPCTvSIjIjLTELKScfchKyvjCElWyOpcxqGQlGQ2RNkJUUYp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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["E1", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["E1", "compartment"], Editable -> False, Selectable -> 
          False]], Annotation[#, 
         Toolbox`species["E1", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwt13k4VN8bAHBrIUkIJZS0SWVP5MyLsSQ0tjH2vWRLUqasadPizkVEslQi
ZKuUpWxRaUGiJBWK8C3ZlSy/g99f83ye+8x5zznve9577nrXw+YeHGxsbFfZ
2djmf2VYM7dSpbpQOr+oXc46XmRwJIvX17OSIv3oaENxTxwy65JnbfFspMTY
VuRkd8ShOa6nxsuJDxSO4xfKz7+LQ/Sk32ZLPL9SjrnRnMJfxqH3okTuXPo3
SkKdqNPp6jjE4SK7Yzr6ByW+ffWSKyVxiDFOUx4/+JsiwlVwoD0zDtWkjbYz
c4YpbnzmOwRT49CHWrR2Mn2Ucuy861rzePz/Fa2po9GTlMTkYZ+p03HI5hZ7
xs+Dc5RMNfE/7S5xaJd7ZoBqARsEv5Eo9rfB403siwvMYQfF75e2CJnFoTaJ
qy0j6ZywUUViPAjiEOeB7da/o5eCiJWD8xvpOGQ7ZWPfd3AFDPzl/hPTGYsC
noVXxCkKAuvu9JtPbbGohNVsqlwgCN08hh4Kb2ORjgzzcEDOSljdMp36tzoW
MQyeFg6lC8Nt7/YcvoxYdCbGRvlXtBjU0w4JS3jFovaN59R7D0oDc4n4+msz
MWhG9sxX0SFp6O8lLK5OxCBBIe2nG/asg46lHEZpv2OQ0kqKl2XtOmg9I6TX
2BWDmCs0S4pb1sOmn2VTec9iEBe/siVzfAPwldLZ7GJj0FruDZdn1LZAo1nU
D2nFGJTPdfPrquAt8G0qWcdhWwyicK1X3lG5BSjBTwZubYxBrpzS7Y4GW6Hn
8K9p4zUx6A67xJYqazlQrbDbtpwrBinPCtVGMuXhX/69HegjiW4Hs89yOiiA
B+Jct/0iiSLHnl9uCFEA/dGQne/OksjZl5BIuq4AaaKtFyNOkWitk8TuHR0K
cMfgntAwk0SxOqqBDDtF4P3Y27/Fk0ThvIcG7toowZqfc2xDBiSyj9x5IuiE
ErS+XPuch0oijX/jS3WSlGD7oEvCFiDRxM/IjR/alECFxdAOVSeRT9N1Z3aG
MqTkNjmf3Eoim6tN763oKjAR+Dyqip9EaoJXPdYdVwHFnEwZQ14SiVxwGBuI
V4EkxtML77lJ1HRyYGVEqwrEqFKdV8yykL4jl0mOpSp0DFh+PfaNhZQ3qj+d
NVcDn0TqzaeFLLT8flpB1n51CItv8t1pxULHRf8mNvupQ1zYB/7Z/Sz05YR5
5Ey0Olwwtu1vM2KhQuC2snitDo+Cc/XvAwuZN3hNzRruhtH2I3xT8iyU2K+q
R9fRgGUhehWvlrIQmwlrxykXDaBcP7jEnpOFDhX2id2N0IA6Tx29P7ME0ghK
HmCv1ICQq1sSLScI9JmLnczT1ISHtLzt13sIJLPudTuX6h54Y16xwf0ZgS6d
3li703IPuLn/2nWvhkBjvWF5tkf3gFb5CgH+SgLV5SlGFBbtAbOEd2Pdjwjk
qXl1o/0OLbgLmk6SOQRqSh0SOG+iBUPaLNX6TALt5jD6U+SjBVPxW0sibhGI
r3765dJcLRDK5ygRSiFQHt3V//5mBBEJUfY1JIFEy8ptvugjyApatf9VNIHC
JFfp8h5AIPRRqf3rRQLRvj9f5ZSBYKjgduG2swQaObK9nG89BXr06taaniTQ
df1pDsXlAMbWT/rLDxCI3ynsmrgUQOHRHmkTdwKFBLEpse0EEBwYb/jPhUD2
d7hcGmkAo8zkS2YOBFrLt7zS9wqA06GRzRWWBLosw6Jb3QbY1BTYUGZOoGmN
lYN7HgKsTkxpqaURqMN7lSR/G4BH+NERNhMc/41kcI6ENoyRasKr9XH83jSh
WHlt+JasRo+g4viz63NOaGmDiWBox5gOjr9z00dDJ214sNvhFjcQ6LXBHX8F
f21Yr8LRcQMRaI+zHI/4KW3wauY03KeF5xezY9ePm9pQdkUzu04Dzy+7sKHh
vjZsjK6LT9iN51etdOBhrTZU7dqfEaiO5zeiFn+2VxvmuntEGGoEMl5WKu87
qQ1B6319HVQJ9HiDZq0ljw685PnRcliFQCmWlNENcjrw6bXe43IlAgn4Vl9c
pqkDVg03FccVcT7O6sqM7tMBrcnhdE3swZS60nZ7Hej8L5eLpUAgx4cGZjW+
OgBHea1/7yRQQ0N9X3aYDpytUYq1x0Y/9kXEsHSg2mhX4fsdBMqfeyN2Il0H
5InOHAdsKXFagXORDlC9h4OHtxOIUGjWN6zRAQbvn7Wx2LOGll92vtMBw0qV
8xRsP5f3x8S+68D9kPH7f+UJfJ4Yy+fGdEBOQ+l6FbZpbHtGL7cuqI48UL+C
XZFjv6dBVBeez1EiA7F3PP3yrnizLvy00D/igp36ydk7RV0XCrhWzNpiC4x1
c5zdqwtPil+um38exu9xzcdWF2xDXN4exR6U/aFo6a0LY3rnl8ZhO2odqtcM
0YVPFtVlFdgNVv85b4jWhUtxrt0T2MjP9w9fqi4whs4d08Tzzz/3mzWSrws+
RSu8L2NLpR3Z3F6pC5ue5ZX2z6//0WhFdZMuaHW0Wlvg/ZltPEbP7tIFna3V
mvXYfn2Tv8gRXVhtd9JuH97fL2wnzzI5qdAf9fLuR2zT1dNrnUWo8O+T2sZA
nJ8KxbAHBhupcK2Mv2wNzl+qa+Q3UQMqWIkN8F/G+U6cPJ/3mU6FiCs/GwyV
CRR3OToo4wAVtitmTKzA9RH1MHGZ0jkquNiupD3B9RO5L7X1TzwVOpvrfW/h
+grtvJVWeZsKslRqfdwuAgXwFSib1FGB71/sijhcnz5pD2aEW6mgUFL//Qau
34MqZc/bv1PB3T3+dZkmPg+OdXaeXHqQ1BSTyYfrX//ep9OndfXAkDNZY70u
gcCgy8TIQg8+INIuHJ8nzY5esZVuepD7ymrnDz0CKSwZyU2N1IPV400l7wwJ
tMaWp6W0Wg+85GbfS+0nkMjv5akRb/WguLFTsB6f3xVnhD0NuvRg6FHR5RB8
vrnypaZb2PQh74WswJwVzi+7quwQRR8qOF9e9cf9oS9BY/Dhfn0YWxqu6uZE
oG/boCTUSR+qa5cmO+J+0ma1z3hZuD48yAkNPexBoJpsl8BNFfqw7fbLsElf
AiWYEbX2ewygT8G0mIwgENkbR2wwNgComKQuPY37b3ASY8DOAPizp/3P4v4W
cTvjZ1CwATx0tN2XiPuf198ykbgyA/A7Z/hkVTyBtG78cK9XN4T20amT9rm4
X1+vMevei/0pVeZUPoFyElPQP1tDmFFyFc8rwv2VtBDfHmoI1ub1gWtK8PrC
Kl+R1YbAcyQu2qCOQOn2V5UYRnuB6ctzsbGTQBziBmw/7IxA7qJ9Y4EEC70g
MpO5wo0hL1TGTyeJhWrnXha/YRlD0+3QENkUFqry/92YkG4MGwuu5HDfYKFH
5upcW2uMoVEm9k/tHRbKFH3pY8JtAtw7TtiplLDQ6dRfWgmXTECUpXay8j0L
oXyVzs2JptDDpRc1zIPf59I2U0N3TMH0uHvhYz78fiZDRcpKTSHkytKps/h9
vT3gmaHxJ1P40u3YKiSI7w9qjCJ/qf3wovVCk4gYif4+CY4szdgP/KzewPuy
JGo/4BJ7m0GDLJEHrxQRiVIciktOONNAhL//3jUKvo9Y8n418aSBtlKME7s2
iXq1i7ZNBNEgvJiX7YUuiUbWstfpX6WBrd+PTRp7SbTsXfrkj1YarDJ4dbvQ
gkQN9WOSjz/TYPWUp/C4Jb6/VBlSyR4aSLme3bmLTiLx/CFSfZwG1/bZH3nA
IJHsBZC7IGIGS38rCcc5kGgPpdNezsIMlqTWN3ceINGcqsrpWVszUH4kJ8mG
7z818lHZza5m4PB7v7jkIRIZrlGYOBlgBveqXWRp3iSyGg9nvYoxA/XAP/nX
DpPIL1e6xqfJDDo4c7NqgkiUJua0ucDEHGI/fB45dI5EVdWSTvJ0c6Cy2dEs
z5Oo07sjIdvRHHiFSfU9USSSqbJZknHYHPK6FYq58P0t09OyJzHGHHbfiapj
RpMov3TvrchWcziz+v6OoTgSNbrxfJr7bA7lDW8bH1wh0dDy50KhveZwO+C4
clA8iZRcqZFBk+awxbmUNp5AomI+iovPagugSWqbfEgi0WM7FWm6gwX8lbqe
pZpGos/co/R3HhZw8m3Frjbs2YIiguZnAXeYyc+Z6SQCrp2zRuEWoF92eOL+
DRLV3t36mXLDAqR7q+aEMkj0akYqeWuPBVD6XykE3SHRz6zPzZm/LODrPVbC
P2x+8+t8shMWMPxlViMsm0SmmatPSi21BC6BiP1hOSRqNhWxEd5qCQIE3yqv
u7h+0njFZnws4ZRUpu9oAY7Pw9fXH2gJmzJmLtML8f7485W+D7GE0sK1tiXY
AdrL7AovW8L58SxeZhGul2/8aW53LUG2NUaw7x7O9ybBzS//s4TPVnstootJ
dJMQ/PNw1BKEuJ8WdWDzTArW3/pnCfpDr3/KPSRRy/OV3qHLrGD9noectdi+
h4QLFLZZwdTmLo7+RyRKvSu666qXFeT+97WIrYxEXKvEeM4EWMGg1xJZCrZX
qNhH/5NWUCm9IjUEW81UPNjoohVsmdJ/MIbd+Ht15Uy2FbBq+e99LMfPGWvI
gSIr6B72zxV8TKLrVWtcPpRawZ4LXVX62J4xEpxF9VYQwX57byE2m7KkgXu/
FQR0jIieeEKiA8mS4mbDVnC+YFQlG/s1p1S/1l8ruKRtENmGndQidUmMlw5r
gnvuq1Tg+ji+rvHlFjoEKU4UfcN2K91grehJh7au8eVSVfj+3vECTRymg1DS
dqY2duCc76byIDoAQdd0xz6nVzJOPU8Htm5KSxZ2zlvjK4xMOqza9vrc5moS
3R8bDpbMp0Plh9xBPezHYlfduovpMCyXXuGG3eDQpeRTR4flcm0pKdgj/cfe
hn+nw879cxf5akj0j1+ilPqTDsJjM+6y2FwKVem8Y3ScD5ViLWzR43z+cZzW
0GFjUOmHvZsjTSBLxhqmtkPWS2ydjdQJbzlryJ52cunENjLs/6ygZA05MVWp
49j2hHJembY1/CvNyZZ6SqKINS/2NThbQ01Vjbw39gUtX+U4T2voLNfYHood
6ywkwfC3Br0QgycEdkam/UBXuDXQHn2LKcR+rjQcNZ5qDbpzZ1V/YzdZJfiX
ZVpD2HLOTzPYbUxNRni+NSh/T5HgryXRQMXZzbwV1hAonXJ0M7bAvjXP1n62
BuF/4zdtsMX8KvO6vlvDihIlfQ/sdTHu8Zk/reHi7SnCH1vpQ767wrQ1nGqh
i57D1pyyMB7nZIB2UIQ1iU2V/KtctowBU/qOutew6W66nFQJBrz7OiGdh+10
rm+AZwMD9szNCj3E9syObn4jx4AnYa7FFdgnf3+4Ya3BAEfx9/yN2CnBPuBt
wwBrgexNP7G9tlxWMvBiwD7aJe4pbPXWXNkNwQzYzbidtKSOREsiX4nOXWLA
aatDv1Ziv9vxH8+n6ww4VaK7bC22X5Tcr9gKBnza/6tBHpu3+9Bbo04GPP28
RG03NiW+L6lsgw1MvsoQ18c+ZnjQVe6gDSSncvyiYgvezNTvjrKB8C+KxRTs
3H89ctdybKAh+vCjXdj6VhtXmL+2Aeldq+S3Y3flu4/yDtqAy00jo3XYITwZ
H6pX2IKZngZ1fn5irt/KTyjagqHBPSM27O8CnPlWOrb4fuK1fhKv7165TLqi
hS3I9hhe/oVtssr1TH+gLZx0CVf+iJ2BuLMzztiCpHGzyvx+TR+888bpii0g
mfUDtdh3ywZF39+3hSRPIrwAm985OLtmxBascz6Wn8J+nXOlIdnfDuo3P3KR
xN4Hz8VNfeyB885SASquH8cmirNdqD2MrueXV8UOcC7J8iTsQf/LR9om7GsR
2WqnC+2hI17jIQ92X9Uly5Ixexj8wCPVgOv9rDaNlAl1ANct2Un4AxAlvn3x
YSfhAK99BdtMse+6aEtrpTkAP6+FkjZ2yymlfOtqB2j/0qu1CVumRuT1ZW5H
4LgwUjeMz2ulzselk9GO0GdVv4aFLW6YHPIg1RHEujqvncYOMHEYPlLgCCK/
2RATW5bR1f6zyRGe/Nk/6IId5duf1y3sBOzFb/+pYXcF5MqkyzrBRIJ8kjy2
BtP3qoOqE2T1FdvKYP+KHI5oozuBRxnNSADbPPGvRUOSE/D50j79wP0nN6X8
xaUcJ2DWFiV9wea6Faq1txyP1zYU3Ir9KI99c22HE/i1puc+xSa6uGY6VjiD
mAD/gxvYIxP8Tc3mzrBX24Ay39/eM82DDrs6w9NMV2lr7NKpq1L8Ac5QN+bh
b4QdMSvjqxfjDAHFpQ5K2O4RniLd6c6Q+dlyYhO2IUd+eVihM7iZGP+RwF6x
ZDdfSaMz+MU927F0Pt75sCLLr87gfGGD00wljsdbyxgedIaYSwpDo9ipy/dn
yQm4gLnBt23d2B4r28fdtrvAtJtHw1ts+VUe1BRjF1D9bvysBtur91rbST8X
oD+433sfO/tRkw+DdIFnn797Z2L3RS1hV7vnAus9QuEa9ibbPfHCLS6Q/TzL
lDU//raArcPjLtBT1xJ+FjtjOutJg5grlHBZVoVgd7/5bHZ3tyv0vrD9F4i9
Pk2494KdK7yorJD0wz78Ysmrvx9dQThY2MQO+8nw34JDDDewMcltps3HpyXm
enW5geSrkpZ92CKFalneXu7QGmI7Y4TtU7pu+eCQOwz+Ygswxn5aw3fUP8gD
NuftnjbF9isU9P055gGSqmy5ZthrUkUPegYcgFX/evUssW9VPw86NnUAImsM
ntPn96eHGRUZeRAMB2+0MbB5fultv8DuCdLKco622D1jQs2sCE9Qi247Nz/f
wcxtXWIznhD4/redPfYEgzqUduIQmIbWjsy7A3hES9m8IPPUXkcH7JotrzWb
z3tB3zr/1HlPj+WOf+f2ho+JExXzVq2+VDB52hueLN/6Zt7GT0Ujkvl94PbE
9cZ5u9XdoFHifcB2KPrlvDOPMC+5S/hCv796zbwHJPc/u3DDF05E9JTM+1S+
dvwdKT+I0govnLc4RcX9ebIfKA7yZc/7Mnfz3qANh8H9lt7NebO/Prxzc+5h
eNezMmXe7uVXLPtE/OGN9smkeb8gj6zUsvSHB8TWq/PW0Qw8bR7rD7udcuLn
/bjn+PjBJn8IHjl2Zd4btzWO1AkfAYca3gUT/puHNlgfAdqR7rh5r7sT/Wg2
/giwsw4v+P7X0bCPLUfg5ajDglXuFbydFg+A7CjTBT884y27ziEAOtJnY+ft
uldVu+p6AERualzwcoE5B+eOAGDXKltwx0XC3eJLAOz+W7rgnKVS3vqdASBd
tGh9di2m/PcA+Cm86LCxk7F//guA4zmPFjzYPvGM/BcAd3QeLLgha3Bn9Zqj
kGB7d8Gk9hd2GZujIMF+c8FDOZ6PAzuPQuKh1wvO+COwrNoxEC6Xf1mwaoiz
f+qPQOjLYltYz2j2DGXG9xicX4sWzPX44S2r/47B5E364nNOCSnK0eMQl2S7
YFWFZHmZkePQe8V6wbeWHLx9zi8IRAfsFvxb6ItKyHgQaP46sGAW5xGG91Em
CGV7LpjK8Ssn5RgTzP7vP2yHZhqDmHD6/3aedb6pEsKE+v9b6S/t58wZJuzI
WfT7QYUIMoEJOXcXLdU+lFVcygT+V4tubvOZ+lHOhMaGRZ//0Ge8poIJ7c2L
HmrpHA6rYULzp0XXNDZpGr5iQuLwog/UFTa2dzChacehBa+plZdZ/pUJ5uqL
bqy5E0jpYoKhzqLVq9JXZ/QwIcF60XzlpJvvIBO4oxZdUcr/MG2ICZ7xiz5a
EsXTPILHu7XojuKIPLVJJrysWjT5YHrO8y8T7JsWrXefaZ78jwmnOhc9VTSW
8WaGCZrDi84v9J+cm2NCNIfXgv8HsHTlnA==
           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["E1_KKK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["E1_KKK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["E1_KKK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJw11Xk81F0XAHAJydKiQkRFZX0eiqRScyrrzGAwM8YWWSL7MphSlqi0oSwp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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["E2", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["E2", "compartment"], Editable -> False, Selectable -> 
          False]], Annotation[#, 
         Toolbox`species["E2", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc8ld8fAHA7aYmSn/qqiJBSQgrHR8m+9rhc196bjBtCkYi4I1IUskeE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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["E2_P_KKK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["E2_P_KKK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["E2_P_KKK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc81d8bAHB7JyuJslJSRoSMch4rO+69sse99s4KoUgqSkhE+Bplk+zK
jBQNkbZSoULKuhQyfuf28wev9+u8Puccz3Oe5xwJl+NEdwY6OroR/Iv2VzJl
7Wae6IjWgX8/VGQQVMru79WBBhKGlGgmjMim7PHqR3duVeyjeYPpgemm5LfI
TtaWnWar6zMEFq/PyKSkoEIJ+41gcuVGwRg6yxb5WRGbgSIlv3p5HCUYkP32
Y8tVNtcsRU4hotQZVnlsm0WLA4ueM4jH8JXDXuyufOpQRMUcemW8xrkL+223
1vY/BVSkz+5XsQP752Si44nMRaQmHNrNT5t/8+s86uU/qM424iMLtpCy+Jeg
+GVkFaLq91uJiuRtfSVmI/+i8LGUbyPYeqebXAKC1pDFL8O6Xmzbm/RFPz03
UFdZn3IF9kG3kmCV23Sw8zrT43PYXb9NroZW0INha1O3HbZZ4lx9fTED3KoL
PLEH+51I5qv5AkZQ/flk97QiFblWH1pUzGUCt1LLHZXY0zC6JSiTGX49dcl0
wo54eUG1Jo0FzCNUB1mxGT3krGcus8LVTf0MJfupKHlpMFw+kQ3Es3Ud1LCF
LkVk+cezA1vDBne7AhXd3CF6ryqGAzoYQ/RVseVrHryfiuQEZ2tJmQJ5Krqn
472yN4wLFjK/flqRw//va24Rn6BN4LdZPFEfu9+zQbPcjxtEH3MZxchSkd2K
rcOE52agT6Folu6jouBHMe1XFXlgNXJ3dOteKrqbMnj0wG0e8HSOkGqXoaI1
m12fB2V5ITyN16RyDxXpSEYcD67gBa5KVZaz0lSUMPVkg3cPH1gIFHvp7aai
voYdqbXFfODxxj1+Wgrn2+BBzWwBP7S7fty9LEFFeTyC2qmiAuAkstprLU5F
Y++9XijkCgD90QP2OaJUFODHPR+QuQXabTZO9AlTUYMKJY57iyB4C2Rvahai
ouX1er7qNEGQzX9ef0GQiuKv2B74dXkrsO5ZUOvipaIndlUPkjiFYIh/RFhu
MxVtltogySYKQc+IBc8JLirKbioK9Y3fBmN0YjJZLFT0OeYPEyeDMJQEVUIQ
IxVJGRlnVMQIQ5rF/mM76ajo9oeZxslIERD1236Ee3keLRTpHElcEgG2/06x
6C/OI42AjDd7wrZDoFxOosXcPOqm0/zjGbQD0i+xxI9MzKOhXefVvnuKQdUz
UZ1nr+fRmlT8Z8FZMfB6dPOK4MA84uHTfrDzkDiMbzNx2PlkHinxIh/LbnFI
2ZtmcLoNz8fT3ubHJgGDdEGGj5vm0TGew7znTCWg3efv2YHb8yhis+bdxlcS
0COSKLypcB5xbG7mfC4kCRpndwui6/Moh1vd+buDJESTzS/vvjKP2jcdZNn6
TRL4Xjs/4I6dR0xcBywjFnfCaOvltM128+gaZ11pqroUrFJbZ++azyNpTsW/
Zaek4OG9TQps+vPImEPhxnvmXfDLydk6RX4efWSvXpwz2gVlAov5XZLzyJ9d
zogjeRcwJfLHpAnOo1S2fbMagruBKYj11drqHJJkq9Al2e2GIzNuS1dn5lA9
q0ymb95uWGAo5mkdmUNvWKS1cndLQ3hQo0lT9xzazrwzaU11D+xALneW4+dQ
NdONz1ui9oC1wbXBRyFzCDFJHJDv2ANTdhcnOFzmkAuj2JCTgQxc/i4dP35o
Di0w5MmFX5KBs3ZMNuEyc+gcw44zKf0y0Jzd2OS3ZQ6V0YvsuW+9FybE6jRC
p2aRBn121LucvSCczzcc9XoWPaXb1j/7eS/ImWxZetk+i6Y3BMMkvPYBf+vT
RMeUWXRgna87LkIWfn2g6IlIz6LutStbc1pl4dWH3q5fHLPIao3Ht55ODqzG
v7Dis4QiVrn5vibIAY+X9/0sygziWL3svvpMDhQFpHYlSMygnL9c9wR45SGI
055k83kata9wkPWvy0OvJDFY23IaWawk1jsOy4P3hf3dezmn0cgyG2uYhAIU
Wri4ZnT8QkzLLNUl5QpQ6bY19Yz4L1QcRb/O6LgfUk9ONQd1TKG4hZ6k59H7
ga65s6vUfQqR/ZNFrufuh4cZs0Hv2KbQdmcRdfmP+yGMINJYr/8Drbwd6Vn6
ux+kOKMDJT9PorcWZVYPRBThRu+nNIETkyhNRyXUxl4R9IJ472y6NoECW/4y
7IxSBBnS9ycfxSeQmXLXlV/ZikDHbJp8v3Qcse02vx03pAghJCWdwPLvKIbd
+0eVrRLMsF+32h31FTnEKZwMP6kEGcly24y/jSGNv4usOteVoE3UVPGUyRj6
/TNu19t3SvByNWHkDdco8hvIJdPbHADzRRU7zfefkLGR68zT8ANQyrmNRTd2
GEl3yZy+lnkAuvjLyu12f0Sj9U05+94egMDw620iYe+RbebAm2NWytAQ3hw1
ZPkKqfJkuouHKUPz7b28vTtfIoFEx4UfGcrwiTqwtrH+As3TS51tbFSGc4bP
igvHB9BA5A/e2NfKcMU324m9rR9VU2sKjBeVYVdBq4J3bx+65BeusGWLCrw4
fzl5ZO4pOuLEZFZhqQLPkqkaznm9SOrtkw+hoSog9uKv/4hYD6K3uOKD0lXg
/vQv1aLWh+hTr/Uye4MKGDScG9sX0o1atUUTXr1UgXN0zvIftB+g7OavgvlU
FfjKZtrMKt2FIg5UFnvzq8Id15l0VolOdGCX2oN1oircfmzsqJrdjnjy1gmP
g1Uh4/CimutSK5oWfPjlapoqmFvJqpmFtqBnKZeOO9WpgpBg37YIzmZUwUZc
3zOoCrVH5d1yW+6ihDNCl6lzqlBV685aHHcHua98EmnnPQjbkw9aVDk1IfGf
vuokwkFQ03Hd+HO0Aa27KfXuCDoI/ue3BWuR69GH4SWridSDkHlQ63FsbB26
a9Xxra7mINCt/N6dVl2LrvWfCz01cBCalrIZKJM1KNTQlNFw9iA4MQxELirU
IGInXxofjxr4M33c9JbhNtpUn3+71FwN6kR/XKs7W4XCBJezBgPUgJXAssXD
rRJ9OkmMW7usBiqtSqL/WVagGmA+RnqmBjNlC65+zmVIqMhJ6/SUGmyp/Kqy
K6IUnWG9K13OoQ5XdvrSFeSWIOJzn5V1Q3U4V2G66wtzMWpR7B6T8VIH5er0
ZlOjIiSVsaPP8oI63F9Sv92TcRMt2g/kVzxUB56ohnctBjeQU4dM4uuv6sBa
PvBOraoQPZI8G0zHpAGT7BFHHm8tRFmTKvpWOhqQdy7+RQJDAaIzS5E/Q9GA
hD/Fckv0+ci7ZmJrVawGXGzadZ6fIw9phOf8oO/QgIaB7JBT6rno5tDCS9lP
GhDYKDZw2zkHcWkdbbNe0wDCdznD4eRsNMxEn3pLUxOqepqELFiuoyNediff
2WmCrNqz6hazLFT9tN6FMVITigRvJvrnZqLYNA8V27uaIM3fN6Ry9BqSFH82
xKRyCIR+q3+MXbmKLp3d1a1geQhOD90IFAq5iha+n75lF3IIPqW5jV2bTUMP
bynG1tQegp5sGcvA5StInveS94eBQ9A7Yr3kGH8FXQv9SmSZPQQFZSJ7XPiv
IC/NzF0O8odh2s1rafFQKhrIm+W+YHYYotfiNijVKUidwXip1u8wPNBGNTWT
yYjj8eoT1srDIGb6xrYu5DK6ZeUSWC+tBbzqYt/5n19Egs0ttp+OaIHGWon0
quJFdHrHFl12Dy04t6je0ZudiCy+9mxxLtKCnrGJU5aRCeiugcRG4gMteNu2
eu7u7AUkURk50TCqBX89D74y8b2A5oPkWjgkENz7b6HWye88sn99vkgFEMwq
NVhfnT+HutW+XCY7I0jS1uclR59DGRtp5Kb/EBRRxferZcej3COrDIqbAGrH
lNYy/sYhLufT2UKiAOyDx5oEr8ah6HA6JToFgNWCsqxWuTjkUMZE6bcAeFzi
cZDZ7wzazrGpwz8dYMvcm8gL7LEoSTLF6lgxwNuMu2TvgBi0qsE7fagJYPze
B83jz0+jj75bdnC9AzDOCmgdyzmFcvt2RFWIaIN7atIXOa8oxPU9ny9NVhsa
r1TltH6NRNHrEhUnD2tD2NaW0ddukchBYfd7Q2dtuCW0dG//8ZNo+xX5g+M3
tCHQcqD5XHk4Siqvef68XhscKEoijigcrXYqeTR1a0N86JNtv96GoY/zqhnn
vmvDhiGF4zNPGPrPElF37tUBNikVv7f5oYjbv/Mip6YOHHuxv/WgUSg6fU5X
kmqiA131LdC0EIKcmgwIXf46MNfS7dNHCEGiQha3ybU6ECdDvdIpGYyS9w8e
MezSARb4e8f3QxBaN7T8pPBSBwQDn2R1ZgTherfZtLGgA2IJMYVam4NQ3gey
739qupCo4MClJxCIuBdGGc4Z6UJ65/QQf91xdJrLPdvPTheU003ojLSOI6fD
3o81o3UBUQd+ujsFINH8IOmhDl34bVqYebbFDyXfobZ3DugC4/OIwSAbP7Te
f8KqfEQXWn8dbj77xxd9oos8F8GoB2b+XI+HNX1RnkvcmKCBHuyS7aiY+uCN
sv5cuDVspQclDI0/WJK90dWky+FFHnrwkFdopETbGyU0ZXEqndeDPoeRYItb
XiiY4/YBs4d6YHd++0HHDE/kl9+wxv9aD+ou35O7RfREnsrNPUNf9eCtj8JX
xOuJHJwe2nsx6cNM3+Ls5jQPdKTuw9mzuvpwtPzHRl6hOwKDETNjkj5QJ0MP
6ni5I82P37fyuuqDlkoi8beCO9rPMl+ZF6cPcCF71q/LDQnbsb2616kPsQ5U
RTqqK5qmV5GaRUcgPCX648XTLmjimsZ0k/kREG+ItssmuaCxfXD3lPMRYNEy
ZvGScUHvjpmYcsYcAetPh2xV3lJQVzkldHf7EXjxfbZTVpOCWrU8tX71HQHp
4f/WXm6hoDsv/dgaho/AlcvWeaJzZFS1Fp6rvXYEhv7Tir5STkbXCMndDocM
YLPQ5vFMCTJK/X41eaepAbTtM51moiejS1HXbX7YG8AH57LAv53OKLa46Gd4
lAE4vKBq8Og7I5/lZoGrzQbQnRHPGmLthA4Xjrs9VjOEC7kiVXzlDmght4sw
amQIooqyfYwhDqgi6z+tv3aG4PPtid/EYQckmEoSkjtlCPftCgoj3tij6dMd
T1M7DSFeZGZAg88eFUVm3y0fNAQDjs9BRmN2yC7sRHHXmCHwmaq82dNoh3r8
98UsMBtBk6Vrr5G9HSpwyFSyMTYCTt7Sh7dqbJGVTbBYkD0e94tfeXfBFnFZ
mnFd9DOCzy0b63ecbVGECeP3lmQjuMYW/+Msry0iaBy/LvbSCPgKk3pWo20Q
g5AB3bi9MbDeqEr9GWiN7vJL/trwM4abBG2vaYI1Cti89l7otDGkcmzmCT9g
jT6w1NcbFxiD71XfEP4lK9SwKOpZ/dUYmm+U62hesEI+c8uknkVjkFAxW1T2
s0Liv17BFxYTGNV4x1BEsEJJXy8K88mYwBv7Ie2hHVbI/eXvvhP+JqDWuHo3
pOUY2t7/ojn5tAkIJtrIj908hgafVJWWppiA85lKxntJx5BWl8uZ97UmoKCo
wHzF+RgSrH2ufPi3CZTekbrXy34M9SaX5DDFmMLPNFLbnwBL1L3xpLEvxRQc
zz266eVoie4HzvRfKzCFBI7NaztNLdEdohqTTJcpXAw5PR+61xKVCD7xM2M2
g4GFw3FRP0joxoXp84KCZrDroryX4gcS+m+Jr/DzbjO4sXNuTvoZCaUP2b8O
MjQD3z6jG0+rSehs3q/D1y6ZwZvG/Jy1MBI6vZnPxjnXDN7OVzJXe5NQZKxq
8J5bZtDmVu+b6UBCwS4xJc3PzcCYi12AQ5eEyLt5N3/mPQrt4tLKKXwkpFWt
/EU66yikC9o5ObYQkYaY7cps2VE4rWxUSKglItXUUwLN945ClBuRJbSUiOSC
HxmafjgK+9PqZCCdiLar2tQGipqDlahF+thxIhIqjX6qrmAOt65UX1PxJCJ+
ocJvDGAOfgx3yDVORMSxMrktg2IONyp5xnYcJaLltqi4e0XmMLJo9KpHnogW
5Aty4xrNIf3EVmdzaSKaze9uMnlkDskzmcx/xYho4symqeFxc3AOMQxs5SWi
qRv9Mme2WIBTybO5d78JaMiDklZsYwFalJhxth4C+s+x8e5JsgU8XVbrnesk
ILIl+2czLwvIbRY2orYS0Hft2n2/wy1A2JC7R6uegOa30z88kmkBEvF6atMF
BNTIf2xKON8CtC+/uZaWS0ARHOW8MyUWIDhkNmWaRUDrfyycMpss4OTeXjWG
VALifFnwZ/y1BSTlSI54xBLQ88cLO1qHLWA99LJPXTQBpd031Ev9ZgGp2UXn
eU8SkFD1bKraogUUBP+2Yg8mIKlE2JsoQIDM2Ndtb90IaDwm3cJxOwHKohYO
3KUQUEXYRJiiFAHqR1K3VjgR0H631AfvDxBAfmaXdKcNAR1CXxz2kgiwc9Or
i41mBLShonx23Y4Av7YXJwmbEFCXbEL5oAsB3rt1bk4xJCBD4f2/I4MJ0GDG
XFusS0DHFmNSnl4hQOFhsV1nNfD+fr5szL9OAM3YxGVHNQL6OCr9MaSQAHbr
qleOqBKQy0D/nu21BLiv0agBSgQUUCnW5TeA95/VM9u/l4AUb4RMwDsCcBea
E/hlCGghq4d7yxcCvCwt/+YiTUCR54/bt80QwC9Xb2aXFAEdPvXgzJU/BHhD
bWa9LklAdKFby9w3CNAoK5ezVYKAzlM6FjZtJoJTlP4ZVVECMrLhFxkVJEIf
t0T0m+0ExGXuqd0kSoSs+HmdMyI43oc2JzvJE2FaXPDibyECyt/qLH3bjAhj
XOmR9gIEdL9zh7OsFRH2a/HMqPIT0Bffj9fKnYgQ+yT/yg4+ApK8b8tSdJwI
K6ee5HPyEJCuj5CWRAQRbjuUV/NtJiA3gbcn8mKJEHB+i7wUNwGVeFl+y7pC
hMCja23uXATUw8e/QzCbCOrRn8IzOAloovWF5dUbRIiv6Zt9zkFAe3nNuy/X
4/GMi+5O7ARk0rJplaOVCImMUZwNbATk5/7sQEI3EXJj69v5sKvvGd2Me02E
F4P8+MImoH5Xtg8bw0RI+Lbrhiv27KYevlPfiUBuS1//ykxAvHfPGa9ME2GW
IpEfgK3kohcX/ocIf45/I9Nhk7gYmxc2iCD8/ZpYNhMBhTZ1zgWxkaCo73GN
JnY6OVZmhocEKo8CZr4y4nrgQBS/bSRoV+G8l4H9pmEta1KCBNuaX/www/7t
1DrgsZcE4nMLlE3YW9mj2L4qkaA6ovTvSwYCUqtXB4omCQbYtl0txLZ1XAr/
pEuCFk8N5jDsSNY7t+1NSfD+IJ0SATun9sT4O0sSeEk7Lytht9ori1k54v19
NdEUwR5mplq9dCeBxP2tb9mx12/XJlsEkMDWZ7linZ6AxOwCH/WFkaDZ4FTW
MjYwKawbx5BATvnMmRVsSvUvld4LJPiPc8yAHn8fZ1Plr59Kgp+3T/Ztwr7J
4FvclUUC3cPfqWLY3VUyw6iQBAE+iXkHsb9ZTQi0lZPALs281hKbhb7UVKOO
BIubd/GEY0tXusffaSaBrNbvvDxsw2NSrcoPSKDIrqD9FNt7Y5Ra+5QEq0YC
H1axL5YX7lN4RQLn0V7iARy/p2uiOTLfSPDkplFoNfbP0uHBkl8kCNum9WMe
m4uYyyH1mwQ1tz6/puXraMm2SFFWS2AsO3RrCPu4xbvanM2WsCHK5r0f5zt1
5dqkkJAltMrqa1zEHjwqYMsvYwlNu1vvGeHzQ10aTE1VtIStTdMat7EFbl7p
3aRhCZ8m004IsRKQ1R9uNTYTPD9r5v1F7KF89q1rfpYQk+Zo/h6fX2DjmJgM
tYRt407pBHy+SwI57r2JtoT6s1vin2EHa3Pa1yRZwt+WMOknuB44x7jyXass
waNl59vRTbh/7eaRfjJlCRYqo+3RuP5uJPMsNVEtoW7Uq1EI1yfbH57HN/9a
wk63ucAm7Fc9vL6nOI/BAHs+4x9cz/7e/Lf37zsGLX7pCpe2ElBeleDBTJ9j
8Hv+gN4i7g9MW7ayxQcfg11ls0OlOwjI59TW94GRxyDGNTvaHvcT1aNCUcYX
jwH9SnLjQzFcXzPbOtbKj4Go1qXFIlo/OrDDwG0Sf2+pfe/8HgJyvbfTWtHL
Cq4Pjlv+p4zr9WOv1u/jVjDt2Z3qoILracN/d0u4Fbi88n8rgvvlef27i3oX
rIBXp9U/+yDu5y9M021KrKC95vX2TNxv5ydPvIj5agXx3walLwIBxQr3mjwn
W8OtLoaGg6YElHjY/8BVL2vQ5SUsT2OnkflEbAKtIbB+ub0Y9/uiEocfIzHW
oH4xqYPXHPcfpbmExTxrUCkV1h0jEBC3ifCj7cPWEHzRZ8rbGt+PUX7ga2sD
DhodDr/x/cJEjFZ/T7GBuucPGktccHz2JCkZ+NiAH7uJtJUrrt/XlVI7o2zg
7qNrR+vw/fRSfortQ64N8At7XXD2JCD2Ue8Xxl9sYN2cJTzJj4BOGHq67PW0
hYSrkux7w/D9IRpun3XcFnxcgtxasHUWz1uyRNhCbdx0m0k4AfHcKDkymmAL
dEuffL0jCKjy77e92RV4fOpoY1YkAY1Uu1HZp21BQyV9c89pAjLb4hI/GWoH
onJXRd3PE9BSeb1gT7QdTFV8F+/HLtJiLi+Kt4NvJS9M1S4Q0KpnWZ9zuh24
/eWSYksgoKrmacE39XYQDJ1j/yXieiJHlXfN24GX2hzcSCKguwvPNAtW7GCb
dZjCBrZboujzUwz28Eh2E8n+Mu5HdZ3zanz20FNUcog3Geefme3QbUV7IDuy
1oSkENCzivTnOYH2oL6U8ZI/Db8f0HfyyQh7uGsjHu6GLfXqINUq1h7GvgU7
NmBHrw1t5Uu1B/0pxt+EqwQkayFBSbhtD3TX3gTGpxNQ0uItaug0Xs801L3n
Gr4voEfoqJ8DFJRKSD7LJiDLhLOtr0Id4PLC3e+cOQTkNIDI9qccQF16dc4Y
O5h8t9Qr2QF8WspGHmFnx5arnq1xALu6DKMm/L6ZuH/J8u6CA/TnFTiH5uHz
yGa4pLXmAMyvt+wtx161YMp9yOwIzbkfzYexN49Ejw0KOsKlO/V1uvm4fugD
gn+pOcKBMZNlNvx+OqdtkSp5yhGudx0pDiskoORELuXyc45gQCW1F2Jnveh9
q5DsCEF0K0eeYVdRtMUO5zuC1ruVSrEbuL7PKFVbdzrC0V0a4x3Ykl0Cz5KY
nWB5UEx5/CaOD8eL4/zcTuARufk9exFen3iZP1vQCRRYxulksY1Gme1LpZ1g
9obIpwDsQIY/k51GThA4WDs9jd2h8571z2UniD11w/19Mc6fvkbXsWtOcE/3
iO4CtpBhTnRDnhO0CzTc4y7B8TNznAu67QQWhiuhOthSNiNDPwecwPdKgnYx
9oCdTobJeycQaH9H34Z9yvGmecWIE3z4weT6CvuNi3u357wTiEV2cDKUElCC
/+StUX5n4PxG5rXFVg409tLe7gxyCcpUf+yR4ErJAiln2HMt9lQctkaEf6aj
ijPwVZNSKrB/xc3FvrNyhn2E452/sYlZy6Tn151h2Tl6d2wZvg+z7bjlbjhD
yLjtagp25X8tvZcqnEFv6UNCPjbTzVOHjVqcwS9k2+M27Du36KW7PzrDpfVL
a7+x3WpcRiS/OcPe0oJ8pnJcn/UPcs78cob90jPrvNg+d8/xoHVn+CxmsLQP
O3mEae3jZjKM0clMOWB/dVGx4xIgw4kIuyQvbI2v7nc0hchQMzs0G4I9/v1R
ULY4GSoCXrJcxIafCd+tFclQfVssqh77mv893QsqZMhMsDdpw/45PVnQpE4G
xl/FXx9hX58ztt+ig+fLUTjxHnv+N9fAIJEMe74OSKxi+1p/Wr5nRQYIfNLF
WIH3c+f2zkI7MoSGdKpxYr+JIIYfdyFD1v3c4m3Y91YyRbmCyXAjvzlVGVvJ
3tuQeoIMx7mJ4xrYFS0awUMn8fx3BgS1sXOjhx+WnSFDV2YEgxl27Lqkv/4V
MoR0SAm7Yi87LVyTzSBDkHSZvhd2cMfD+/zXySCTtGrmj+0W6yUwWkCG/XKb
/oRhD39R13pcRAbloQdZUdhW2pxeNWVkMHykvS0W25ChuuV0DRmSTyXeTcDu
dIn55t5ABgMXyXdJ2BoPLDab3SVDsY/Gu1Rs2Xiqi8h9MmxGUVFZ2JtZ1Dnu
9pPhvauBbQl2ggeHcv5LMiwNfrlQjk3X88Hx/FsyHNoqnl2FPX/hdK3lZzLM
h+/0rcP2nTD/oDlGhm6o3dtIi6ehBPPOcTJEH4zov0OLJ3u3zdw0GexZ9Z+0
Ypv7ZMS9myfDaJKARAd27xOPqo7feD/Xa5w6sZsvsdMlr5NBKG8k5SH2gZ9D
MicYKHBMF+J7sKtMq0gOLBTQm+KgPMbO22ReupebApnMnq+fYW8NEH/By0eB
TvEs/+fYqc/nVpa2UCCV8dJMPza7wgOpL9so8CA6xf4FdlxK+tGeHRTYar9Y
O4j9d8Y9olqCAgb+XNSX2KEWB29k7KIAf5yU2Gtsd96hRVc5CvhPX1N/i/0p
qFLMRJECYWOpe97R8jMYbaSkQgFuwaeM77H7lY6GbFOnwJxlxlOaDa+K/Ud3
mALDASh2iJYv6uyjcaBAitI2yQ+0fFl2zT7Xw/sLCK6lub7hqnCTIQXU5rPl
P9Lyt8Vd7z9TCpRfGr1Os2X/1O93FhTYS3JboTk6Mbhc4BgFOKsLjwxjF+ku
21vYUuD+cboYmp+uxXAnOVKgzff7TZqFgy+HMHrgeKqsNNDs8z37XWQABU68
bI+mOa1A4lJTMAUUk37o09xsV3Z4PowCAba1a7T1RgUUZuWiKND82qWIZo7+
xhveMRQoyTmqQbNS4qFjxWcp0K7f3UH7f+x0H7COXKBAegC/Cs1xa0bN25Mo
0FhzKZsWj/I7A342qRSoKYmepcVrIMhaLD2dAoJTKgdpXtr36UV/FgVChFiP
0+JtWDClalBIAcsshfo32IF2wZNxxRRYFNt9n5avLIHlnPZyCjxZCe54hT2R
wEKvWkcBM4Gj12j55tG9XB/URAHhhKgA2nlQW+P3uNVMgT2MWhoD2BeCJJ5K
PaBAw4m6W33Yu+0OZfC/okBuuQRnL/ZRgQcG5u8owLr18IVH2GHPjVYufqSA
8/jUUjf2Ix1rZ4ZvOP8pf9po59t9X7DM3CIFiMLBr5tp+VktbXu+1QXiGoyP
V2I/a5IP5NjuAn/Hd1Bo9bcQ2Ch5RNwFlm4dMC3F1v3WdaFtjwvYsn7kvkmL
f98woUrdBQoS+E2ysSXy+b8n2rvA66TmRxew/dQ03U85u8DBvtGL57CbXrh8
DXR1ATrjApOz2MZMdaPWvi5wSS3gwWnaefe2+LwrygVuFfCmnqDV54HL7zqz
XUC58UuDC/bxXpany+9doHvmy5gmdtvc8m1vG1fo0i2Knsb9tenrmzu1Dq5g
UJc+N4Vd87a+Y5nsCvnMkV6T2Dfa/PsTvV2h75yTw1fshMSR6fJIV/DZJuc0
hE2UeCz3I9cVeOsiX9H6+YRFVqXPiCvwxIg/KsQe1T1RX/fNFa5e9UzOx/6g
SmxZmXSFfZfu2/6H/Xw719OL865w7ubd5Szs+omYHxWMbiCzpOycin061lNm
apcb5O1beRCDLVCjWurr4wYKuqPsFGxnOo/m/AA3CGDn1nXGrrDI6HsZ7AZ6
gmExjthojkrVjHIDf9l1ejvafadUC1xJbvDek0mehH2/Yd9Q1S03OBthJXEE
m5PZ/teXWjf4lrgjWQ/b6thFui1NbmB5jmddB3tqcWL3qXY3eMhyYhxhCx4s
CTHrd4MfT/i/qGP73RPfND3rBhUL8Z7y2HfYLcQlF92AYOjBIofNYBdzwGrZ
DSbOWpTR7tvMlWHbdnp3MLBSWdyD3aWZU5LM5w5Bn//U7cQWat8CCsrukALb
W7dhP+jiCAkMd4ect8MzrNj754eIDlHucJ2r6i8Ldp5EpZJhjDsMX37ITnNE
rMm82AV30G3ol6Xd//JaSUH919zhr9HiZTrsrHubAuWb3AF2/bq3jN8LLJPD
5sLN7vAjjnVyCTtEqFqBpd0dGIrVhGk+Gn50ZvihO/B7vYyjvS8YVVICLr/G
6+ll+VGxA2p4/H8uuIOw0pP8X9gfP38xfbfkDnYl09M/sY0218p2r7qDW/EK
olkqgPAzh8kDOMtbx39gv9+X5msi4AE3h23MJrD1Svl9Kg54gFGJcMAYdt2b
MaNrBz3gW+Ha+1FsMZYGmThND/i4eMWA5hU3y0lbXezmLukR7NuSGV7sJA8w
1p/7+wlbOE/Q0yvYA+LTi2eHsFWlc/vLwjxgsn3Yl2ZijYTaZKQHdK++nniP
falLlt3nrAdYHlwaf4e9+l2n0jfdA1gN8lbeYH9SOD4T0OQB8EQ/4CVt/bsL
1rebPSDi/DNGmgV1Iu/PtHtAs8Cb7EFsc8tzVwJ7PEAkj9z3Avt+RM6B4Hd4
/MFv3QHsm5094SdWPOD8MZ3QPtq4sdmXxnUP0FC2Eqf548tBw98MnkCqa+p7
hi3wfXhbOKcnKBMsZGk+z7HQErHdE/bviV96gn3j6kmpe+KeEClxvZrm9u0b
SctSnvCmctid5j/yHE6Rcp4Q2jL59jG2F0mcLlrLE7hbWx73Ysd/LPZq1fGE
mgN/E2gucN/3YvWIJ3Q9JRrR/D5c9cYpc08YLdLq68E2zjXViyHj+WebRh5h
y36LSIiL84T7u89rPMT2NctvizzvCUV5fJtormh8OB980RNCWHy+dGPvOc/n
6JrmCQOeQYk075SuUtS74QlGHWVfH2C7pAx6HCrxBFsmUhvNBX+WcpQrPMGg
7c41mkV79Vl21XlCg2mZCc3C3p+HmLs8IVvhZ1sXdpa6rP7vx57w56JoFM2C
HCdvf3+Bv38yrUEzbyVffM+IJ8xrS3R1YidHOU/fmfSEG8GeiTRzmVbZlM15
wiUKN4lmtl/6con0XrDx5Miv+7T4t6VlnmT3AqaA1jaamZI/0/vweoGauH0q
zRvyJ98YS3iBOONHTZqjNx6CpowX9AwVCtC80s9XuU/RC4xsj850YP8OrIrh
0vaCkkKpCprneY9Y/rLwgtF0Dj+ap+s+73lO9oKxXzXKNP8gnVyrDvSCFM9e
Rpq/LfANpsR6wdNW+vfttPxKvH9dm+8FXx06Mmj+YZb//mW7F5jPJnrQ7Bfp
Prw47AUPZjiNaJ4u2Teydc0LXknGa9A8v3Fnwl7TGzrm5nVo/m2jN5t/0huK
0phP0DxLbFT3yPGGm8zMeTRPmu4+K9vmDa/2v+yjefRI5rP5T96Q1bfOQNvf
R2ATvEfnA53JdYdofqNx0jlG0ge2S2+LpLlf+UeZvp4PRBk5NtPcteeZ5uAF
HxA/44Ro8RoQ0fthVeoD8sxrp2j+zN2a9eGRDxT+sW2leXWhcvErsy/MD1xW
peWLY2JnkfcuX3gc9DaIZqEPOcRpPV8IsnhQSbNK56Xbf876gq6EiTDtPDSf
qb4pXuIL5fkXiTSDzotMo15f6Ep6dYHmRwwLl4J/+MJUWmkzzaYPBGNzuPwg
/jXdFM2DZ9VDu+X9wMyrXoh2Hm30HLx+WfgBs3OaLs2uDwstUIYfPJf6L5Xm
eJFN04R3fhApmjNIc0lQxCU3EX8o4jXlpNVDb8/YnnAnf3AcQ5o0/9hh/iix
0B+S07tdaT5TrZ1RJhoAe8lH/6NZCCm79eQE4PfBvm6ak5gHjcJ3HgdFU6NP
NNM/O64gXXkcZjP+TNHs1pJuOSEQCEkHz879Wy81iPewZSAst7bP06yjGXqW
mBYIM/UJ/8Zbv4Uteg4EgtMMYYbmXfv65x/yB4HL4OxPmpMDpWd3WgfBwNWE
HzSLl12+s54RBF/pz0/QXP+Zevr9qyAoMLg1TrNy3e0Xq0LB8HD3qe80N8X7
Sok7BkNc+uevNLsYqWjfzw2G1XG7f97EveFI/hgM0bv5xmh+Xjqt0CkcAn3S
x0doTtX+RC9pGwLcHsf/9RcI2+n8NDcEPHdv+0zzbIVXa+iXEBgRfDJM85MX
LWPZYqGQyrL2keaiJW7OTqdQUKY/+c9+zXfaFG6GQprLtn9WiSYH5o2HglvD
ww80C/ArvOvbewKEu33+mVq+htb8TwB/2P5/XlUaCiqvOgEijwT/mam16eax
qRPArcH///HPE2RjhTAwF5T8//eMIqIoJAy+lR/+//zC9sU1dWHw46HDP6vs
z5GVnA+DSeOof/YTofe23B8ORspX//kmi2fx+YBwIA/m//PjJEl/+rpw6G0p
/OcZvk/K0YvhcDi95J/RpdJHIcoR8CP+1j+nMAbZ+IZEAOO9xn8WHZotbbwX
ATcFO/65uibwz8ZGBDTo9fzz/wB4jx9J
           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["K", "compartment"], Editable -> False, Selectable -> 
          False]], Annotation[#, 
         Toolbox`species["K", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwd13c81V0YAHBEyV5JKStKZqGFOg8hK/Pa617zXpsUKZFKZDUUUTRJd9iz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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KK", "compartment"], Editable -> False, Selectable -> 
          False]], Annotation[#, 
         Toolbox`species["KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc4le8bAHCkQaQhZCUjQpGV2XvbKmQd5xyZ57z2TDIiREsJiSgzREZG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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KKK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KKK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KKK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[1, 0.75, 0], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc8lV8YAHAykn2NSxGSItkrI53H3uvea69r7xlRtiRKSIUkO7usBqXM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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KKPase", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KKPase", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KKPase", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.647624, 0.37816, 0.614037], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nk8lF8XAHCEZlCy+0mWIUWWrGlzj1JZw4zsy8zY930na0qWVNYIRfai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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KKPase_P_KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KKPase_P_KK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KKPase_P_KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.571589, 0.586483, 0.], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl13c8Ve8fAHCEEMlIRPa4ITITOedjVPa4ZI977axsKlJS+Ca0EJWRTSGR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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KKPase_PP_KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KKPase_PP_KK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KKPase_PP_KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.915, 0.3325, 0.2125], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwt13c8ld8fAHCErGRTokgZGdkz52NkJtd1s3ey946MNDWE6qt4rOxNsrll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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KPase", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KPase", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KPase", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc8ld8fAHA7CVmhZCQqEZkZ5Xzsvfe+17rXnlkRofAliQqRvSIUkZWE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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KPase_P_K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KPase_P_K", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KPase_P_K", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[
           0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc8VW8YAHArIWQnhUhJVva+72Nk72vPe+29EkpGSpSIioRQyc4IN0qZ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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["KPase_PP_K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["KPase_PP_K", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["KPase_PP_K", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl13c8Ve8fAHCE7BWSZEUopZDKej7ZlHXtfa91rxkistOQCJkVce2Mr5Eo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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["P_K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["P_K", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["P_K", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl13k8VF8bAHBEP0SWJEX2irJv2c+DFCIM2Zexj31JSJREJWuLCEUlEUWJ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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["P_KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["P_KK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["P_KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwd13k8VF8UAPAIyVpIfmmxlIrKmKGouEeRfc0ymLHO2PedFElFISUlS5Sd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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["P_KKK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["P_KKK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["P_KKK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.880722, 0.611041, 0.142051], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nk81M8bAHBK2nXfR0VIKfexixzNo8OV2+66s7uudeRKKGf4SicdIoQk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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["P_KKK_KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["P_KKK_KK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["P_KKK_KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.560181, 0.691569, 0.194885], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl13c81d8bAHCrYSUjlD3qXptb+ZLc89iSbPfa417j2jsyUrQUUkqKkJRR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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["P_KKK_P_KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["P_KKK_P_KK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["P_KKK_P_KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.922526, 0.385626, 0.209179], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl2Xc8lV8YAHCEZGVTGRmFrBApuecxsmXvda+9V0TJCBVltYwUUlkJpWQ1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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["PP_K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["PP_K", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["PP_K", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.528488, 0.470624, 0.701351], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl13c81d8bAHCEzLITGqQSoqwycp5Khey93Wte49qZGdFSkooQSYhIZkai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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["PP_KK", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["PP_KK", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["PP_KK", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.772079, 0.431554, 0.102387], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc81d8bAPAIITtJkhCViOztPEa27L3ute41s1dWKtlJg1L2JiMllMqI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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["PP_KK_K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["PP_KK_K", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["PP_KK_K", "compartment"], "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           Opacity[1.], 
           RGBColor[0.363898, 0.618501, 0.782349], 
           AbsoluteThickness[1.6]], 
          LineBox[CompressedData["
1:eJwl1nc8Ve8fAHCEzLIpklWUVVbmfT4he1573ysrK5vIjigrJUJSioxsN8qm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           "]]}, 
         InterpretationBox[
          SuperscriptBox[
           StyleBox["PP_KK_P_K", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True], 
           StyleBox["compartment", 
            RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> 
            False, AutoSpacing -> False, ZeroWidthTimes -> True]], 
          Toolbox`species["PP_KK_P_K", "compartment"], Editable -> False, 
          Selectable -> False]], Annotation[#, 
         Toolbox`species["PP_KK_P_K", "compartment"], "Tooltip"]& ]}}, {}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> True, ImagePadding -> All, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {False, False}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {
      "FontFamily" -> "Helvetica", FontSize -> 12, ImagePadding -> {{
          Scaled[0.035], 
          Scaled[0.01]}, {Automatic, Automatic}}}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 350, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None}, 
     PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       InterpretationBox[
        SuperscriptBox[
         StyleBox["E1", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["E1", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["E1_KKK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["E1_KKK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["E2", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["E2", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["E2_P_KKK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["E2_P_KKK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["K", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KK", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KKK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KKK", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KKPase", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KKPase", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KKPase_P_KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KKPase_P_KK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KKPase_PP_KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KKPase_PP_KK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KPase", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KPase", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KPase_P_K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KPase_P_K", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["KPase_PP_K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["KPase_PP_K", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["P_K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["P_K", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["P_KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["P_KK", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["P_KKK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["P_KKK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["P_KKK_KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["P_KKK_KK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["P_KKK_P_KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["P_KKK_P_KK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["PP_K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["PP_K", "compartment"], Editable -> False, Selectable -> 
        False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["PP_KK", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["PP_KK", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["PP_KK_K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["PP_KK_K", "compartment"], Editable -> False, 
        Selectable -> False], 
       InterpretationBox[
        SuperscriptBox[
         StyleBox["PP_KK_P_K", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True], 
         StyleBox["compartment", 
          RGBColor[0, 0, 0], StripOnInput -> False, ShowSyntaxStyles -> False,
           AutoSpacing -> False, ZeroWidthTimes -> True]], 
        Toolbox`species["PP_KK_P_K", "compartment"], Editable -> False, 
        Selectable -> False]}, "LineLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #5}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #6}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #7}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[1, 0.75, 0], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #8}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"], 
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #9}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.571589, 0.586483, 0.], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #10}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.915, 0.3325, 0.2125], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #11}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #12}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #13}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #14}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #15}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #16}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"], 
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #17}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #18}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #19}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #20}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #21}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    Opacity[1.], 
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #22}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.528488, 0.470624, 0.701351]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5147193333333333, 0.28770266666666666`, 
                    0.06825800000000001], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.772079, 0.431554, 0.102387]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.772079, 0.431554, 0.102387]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.772079, 0.431554, 0.102387], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24259866666666668`, 0.412334, 0.521566], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.363898, 0.618501, 0.782349]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.363898, 0.618501, 0.782349]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.363898, 0.618501, 0.782349], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.75, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0.5, 0.],
                     FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0.75, 0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.75, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.75, 0], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.647624, 0.37816, 0.614037], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4317493333333333, 0.2521066666666667, 
                    0.40935800000000006`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.647624, 0.37816, 0.614037]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.647624, 0.37816, 0.614037]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.647624, 0.37816, 0.614037], Editable -> False, 
                    Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.571589, 0.586483, 0.], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.38105933333333336`, 0.39098866666666665`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.571589, 0.586483, 0.]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.571589, 0.586483, 0.]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.571589, 0.586483, 0.], Editable -> False, 
                    Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.915, 0.3325, 0.2125], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6100000000000001, 0.22166666666666668`, 
                    0.14166666666666666`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.915, 0.3325, 0.2125]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.915, 0.3325, 0.2125]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.915, 0.3325, 0.2125], Editable -> False, 
                    Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.2672148173956843, 0.34800444289592275`, 
                    0.5666666666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.40082222609352647, 0.5220066643438841, \
0.85]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
                    Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6485525936249404, 0.4144296347913687, 
                    0.048907997212660946`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.9728288904374106, 0.621644452187053, \
0.07336199581899142]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[
                    0.9728288904374106, 0.621644452187053, 
                    0.07336199581899142], Editable -> False, Selectable -> 
                    False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.4911884484706007, 0.23866666666666667`, 
                    0.3353511049170246], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.736782672705901, 0.358, 0.5030266573755369]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
                    Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.18684294025131137`, 0.4766666666666667, 
                    0.2861392881649977], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.28026441037696703, 0.715, \
0.4292089322474965]"], Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965],
                     Editable -> False, Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.528488, 0.470624, 0.701351], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.3523253333333333, 0.3137493333333333, 
                    0.46756733333333333`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.528488, 0.470624, 0.701351]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.528488, 0.470624, 0.701351]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.528488, 0.470624, 0.701351], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.772079, 0.431554, 0.102387], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.5147193333333333, 0.28770266666666666`, 
                    0.06825800000000001], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.772079, 0.431554, 0.102387]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.772079, 0.431554, 0.102387]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.772079, 0.431554, 0.102387], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.363898, 0.618501, 0.782349], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.24259866666666668`, 0.412334, 0.521566], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.363898, 0.618501, 0.782349]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.363898, 0.618501, 0.782349]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.363898, 0.618501, 0.782349], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             
             RowBox[{#, ",", #2, ",", #3, ",", #4, ",", #5, ",", #6, ",", #7, 
               ",", #8, ",", #9, ",", #10, ",", #11, ",", #12, ",", #13, 
               ",", #14, ",", #15, ",", #16, ",", #17, ",", #18, ",", #19, 
               ",", #20, ",", #21, ",", #22}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.6704906473552437`*^9, 3.6704908726632414`*^9, 
  3.6716140864707885`*^9, 3.6716142925535755`*^9, 3.6775543098910832`*^9, 
  3.713270856107361*^9, 3.7132710252860374`*^9, 3.7132711830970635`*^9},
 ExpressionUUID -> "852efff1-c400-47a5-86d0-80a6f46d0e67"]
}, Open  ]],

Cell[TextData[{
 "Man erkennt, dass sich das System in einen Fixpunkt bewegt. Mit einem \
einfachen numerischen Experiment wollen wir nun die wichtigste Eigenschaft \
der MAPK-Kaskade reproduzieren: ihre Ultrasensitivit\[ADoubleDot]t. Dazu \
verwenden wir den Befehl ",
 StyleBox["updateInitialConditions",
  FontWeight->"Bold"],
 ", um das ankommende Signal (also die Anfangskonzentration der dynamischen \
Variablen ",
 StyleBox["E",
  FontSlant->"Italic"],
 "1) zu variieren. Die (nahezu) asymptotischen Werte (bei ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 1000) f\[UDoubleDot]r den Output der Signalkaskade (",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["PP", 
     StyleBox["K",
      FontSlant->"Plain"]],
    FontWeight->"Bold"], TraditionalForm]],
  ExpressionUUID -> "13198cfd-3779-431b-918a-f655fe2eaa02"],
 ", was in der Notation von Huang und Ferrell (1996) der Variablen ",
 StyleBox["MAPK-PP",
  FontSlant->"Italic"],
 " entspricht) und den Output der mittleren Ebene (",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["PP", 
     StyleBox["K",
      FontSlant->"Plain"]],
    FontWeight->"Bold"], TraditionalForm]],
  ExpressionUUID -> "cc1dc189-1aad-4353-bd5b-a05b70818a90"],
 StyleBox["K",
  FontWeight->"Bold"],
 "; bzw. ",
 StyleBox["MAPKK",
  FontSlant->"Italic"],
 "-",
 StyleBox["PP",
  FontSlant->"Italic"],
 ") werden gespeichert."
}], "Text",
 CellChangeTimes->{{3.677482285783856*^9, 3.6774822905730643`*^9}, 
   3.677482328702532*^9, {3.677484799411647*^9, 3.6774848414306335`*^9}, {
   3.677484877792698*^9, 3.677484883487708*^9}, 3.6774851526927814`*^9},
 ExpressionUUID -> "c7fa14ab-e649-4f1a-8bf1-20bad10985ed"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"updateInitialConditions", "[", 
      RowBox[{"model", ",", 
       RowBox[{"{", 
        RowBox[{
         InterpretationBox[
          SuperscriptBox[
           StyleBox["E1",
            StripOnInput->False,
            ShowSyntaxStyles->False,
            AutoSpacing->False,
            ZeroWidthTimes->True,
            LineColor->RGBColor[0, 0, 0],
            FrontFaceColor->RGBColor[0, 0, 0],
            BackFaceColor->RGBColor[0, 0, 0],
            GraphicsColor->RGBColor[0, 0, 0],
            FontColor->GrayLevel[0]], 
           StyleBox["compartment",
            StripOnInput->False,
            ShowSyntaxStyles->False,
            AutoSpacing->False,
            ZeroWidthTimes->True,
            LineColor->RGBColor[0, 0, 0],
            FrontFaceColor->RGBColor[0, 0, 0],
            BackFaceColor->RGBColor[0, 0, 0],
            GraphicsColor->RGBColor[0, 0, 0],
            FontColor->GrayLevel[0]]],
          Toolbox`species["E1", "compartment"],
          Editable->False,
          Selectable->False], "\[Rule]", 
         RowBox[{"xx", "  ", "micromole", 
          SuperscriptBox["Liter", 
           RowBox[{"-", "1"}]]}]}], "}"}]}], "]"}], ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"concSol2", ",", "fluxSol2"}], "}"}], "=", 
      RowBox[{"simulate", "[", 
       RowBox[{"model", ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", "1000"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"out1", "[", "xx", "]"}], "=", " ", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         SuperscriptBox[
          StyleBox["PP_K",
           StripOnInput->False,
           ShowSyntaxStyles->False,
           AutoSpacing->False,
           ZeroWidthTimes->True,
           LineColor->RGBColor[0, 0, 0],
           FrontFaceColor->RGBColor[0, 0, 0],
           BackFaceColor->RGBColor[0, 0, 0],
           GraphicsColor->RGBColor[0, 0, 0],
           FontColor->GrayLevel[0]], 
          StyleBox["compartment",
           StripOnInput->False,
           ShowSyntaxStyles->False,
           AutoSpacing->False,
           ZeroWidthTimes->True,
           LineColor->RGBColor[0, 0, 0],
           FrontFaceColor->RGBColor[0, 0, 0],
           BackFaceColor->RGBColor[0, 0, 0],
           GraphicsColor->RGBColor[0, 0, 0],
           FontColor->GrayLevel[0]]],
         Toolbox`species["PP_K", "compartment"],
         Editable->False,
         Selectable->False], " ", "/.", " ", "concSol2"}], " ", "/.", " ", 
       RowBox[{"t", "\[Rule]", "1000"}]}]}], ",", 
     RowBox[{
      RowBox[{"out2", "[", "xx", "]"}], "=", " ", 
      RowBox[{
       RowBox[{
        InterpretationBox[
         SuperscriptBox[
          StyleBox["PP_KK",
           StripOnInput->False,
           ShowSyntaxStyles->False,
           AutoSpacing->False,
           ZeroWidthTimes->True,
           LineColor->RGBColor[0, 0, 0],
           FrontFaceColor->RGBColor[0, 0, 0],
           BackFaceColor->RGBColor[0, 0, 0],
           GraphicsColor->RGBColor[0, 0, 0],
           FontColor->GrayLevel[0]], 
          StyleBox["compartment",
           StripOnInput->False,
           ShowSyntaxStyles->False,
           AutoSpacing->False,
           ZeroWidthTimes->True,
           LineColor->RGBColor[0, 0, 0],
           FrontFaceColor->RGBColor[0, 0, 0],
           BackFaceColor->RGBColor[0, 0, 0],
           GraphicsColor->RGBColor[0, 0, 0],
           FontColor->GrayLevel[0]]],
         Toolbox`species["PP_KK", "compartment"],
         Editable->False,
         Selectable->False], " ", "/.", " ", "concSol2"}], " ", "/.", " ", 
       RowBox[{"t", "\[Rule]", "1000"}]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"xx", ",", "0.0", ",", "0.00004", ",", "0.0000005"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6169851420733433`*^9, 3.616985262609152*^9}, {
   3.616987949169179*^9, 3.616988013986041*^9}, {3.616988377153222*^9, 
   3.616988470100637*^9}, {3.616989688026081*^9, 3.616989700058906*^9}, {
   3.616989816293261*^9, 3.6169898386805973`*^9}, 3.616989906371393*^9, {
   3.61784866438923*^9, 3.617848685935554*^9}, 3.617848800832975*^9, {
   3.617848930493519*^9, 3.617848950257251*^9}, 3.617848997660305*^9, {
   3.617849078645046*^9, 3.6178490928763514`*^9}, 3.6178492408029118`*^9},
 ExpressionUUID -> "7ac6e53c-307f-4b32-82e9-9b1e9e17d2ba"],

Cell["\<\
Diese Werte lassen sich nun in Tabellen schreiben und gemeinsam darstellen.\
\>", "Text",
 CellChangeTimes->{{3.677485158651992*^9, 3.677485183050435*^9}},
 ExpressionUUID -> "7df05cce-ba7d-4e8b-a723-cf35cf5a1743"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tabA", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xx", ",", 
       RowBox[{"out1", "[", "xx", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "0.0", ",", "0.00004", ",", "0.0000005"}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tabB", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xx", ",", 
       RowBox[{"out2", "[", "xx", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "0.0", ",", "0.00004", ",", "0.0000005"}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"tabB", ",", "tabA"}], "}"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Input (E1)\>\"", ",", " ", "\"\<Output\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<MAPKK-PP\>\"", ",", "\"\<MAPK-PP\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Red"}], "}"}]}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.616989722947013*^9, 3.616989741417321*^9}, 
   3.617849134511921*^9, 3.6178491764319897`*^9, 3.617849245787016*^9, 
   3.61784933006277*^9, {3.617849390920623*^9, 3.617849393972106*^9}},
 ExpressionUUID -> "ddcc9d4a-a457-45b7-865c-7c21548a51bb"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         AbsoluteThickness[1.6], ImagePadding -> {{
            Scaled[0.035], 
            Scaled[0.01]}, {Automatic, Automatic}}, 
         RGBColor[0, 0, 1]], 
        LineBox[CompressedData["
1:eJxdkn1U01UYx8c2s0byFhAgWsgM44iIgpjY8xjDDAwGIgYDAjEUPHEUX8AE
xEROKKIzBOTIdECZwiHHAuKlFDiiEQxpCGLE2zbGtt+ACRMYIFSn+1f3nHvu
uefe+9zn+/18HWKO7Iml02i0oH/mv+v/R85YtXDmkRAqZb5ue8s98b+9CEod
Y0TnXXi4V2GWeNy5DoKzmYmDHx0l541wWgrhac3pqIuTZ1XPPoTbm20TQy2y
yf1WsGyxXbJxysOfoyDMLUICF9P14X2Rt8j7TmhdXZuaceo2Ynn7tZ5BKShs
HuYe3nSP1HsK31/fvVy7UIUl782lXjN/Bh1Hy1Z+EdVA6j+HE+VR41HcJlxW
4hS7h9MHhyt0fabeLeS/fuhsGWKmHmrFuFUh/mYnByE+1M6WL5SQ/4fgcsXd
yVp1Jx78tMnuUNcwfHXFTXVmWkr6kYF/c7PbVt1TfJvVa/KxVg5JUuOYlV09
pD8FWMpKM/0Evdj6eJy+dpkS3riQd9Mr4E/S7ygITp9lc5R9mJK5bIaxWgUZ
BclmeLCf9K+GfncxO+LJAK7n2FOyLRrYt3AjONl8iOihoL7tTsL6yiEcoG0e
bOJqwblAcSJt1zDRNwYjQgPfsnsY+fd9u4Rx49A30b0llycjeiegkMNp4vfK
0AFE8gc7dBDQbaUp5MqJfh3wUzVPNjbK0VDUEOnq/wK2p0gCJc4K4scL2Fm7
O6//igKl84+e3QybhI4sdtWjCQXxZxKuZ34ZNeI3guU8aZDJwSnwZgmuXi4e
IX5NwUDQb+5m+hE8X9fflnZMDxaiO42V3krinx48Vj2XVOUoMdJGvXPszEtY
IcwXhHQriZ/T4K1k5rfZjqJHsv5BRPY0NMtjfvINHyX+zgB7+ePxxcJRNOlZ
+qC9YAZCp9fdsO4ZJX7PwtRiSl2tqQpH3Y2rvL6bBc/mUh/WLhXx3wDfPH4t
ySVVhY251hvKRQYQ1ycyvO+pCI85UApm9sUOqbBw0uGO3a9zEEA/1CQ2VRM+
82BlIfuB86EajwW5rLnYOg/vXrercI1XE14LgIeLey7lqtFPtLXI0L0ADTzx
j0d+URN+r6Ay+nkMJVejo6mPdbzsFQT7NQ2aszSE5yII4pM1Uxs0uJDA5feO
L8LXg7GexXs0hO8SvB8N6etOarC7ncf6ZH4JpsyNvy3I1xDeNLT+PDduvkaD
z6w2N/dl0FC4Cd2jezSEPw1NGgUJf+g1yGnZmv4Wywj5evFwmAVF8mCEXmL2
fYYrhaITsH033wh1bfFFvX4UyYcRiqVvXhqOpdCe7WM4Z03HFe129k5nKZIX
Ola7Sg9UFlKY1eVbU19Ex4S5W6wsMUXyQ0fdX2e54t8pfHmOe3xyDQNny9tN
PWUUyRMDJb7pEnsDhfs3hWx0vstApcPr1fGmWpIvBr5jWVbiuFaLHcO8sf2u
TAzkJTkFbtOSvDGxuEadow/Q4rar0WWF1Uy8MO8xYHVAS/LHxM9Oeclqk7T4
N6eAix4=
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.009166666666666668], 
         AbsoluteThickness[1.6], ImagePadding -> {{
            Scaled[0.035], 
            Scaled[0.01]}, {Automatic, Automatic}}, 
         RGBColor[1, 0, 0]], 
        LineBox[CompressedData["
1:eJxdUmsw3FcU3122ZSk6EhoVQ0TSRpeGJBXVc7Q0aSQiDMoSIa13Eu+KCdFo
mjExkTXSigZRjzSojBiimHp16QhRZRFrvCWo3f9FvNejOrn7pXfmzp0z995z
fi+j82Eu/hwWi+W8vf87/79uySpzl1tywWX62frq0Ul4XZfBm6MZfNYZM3Sd
0IqIOlANBiOi7NpUAb6+bwBh2IRBuX0izgaNJ1euiGDI+/3SOEkOfd8KZ8zH
QtrCarDqHHge9H4Ggp7stIkbnfR/J7TOBn/UMT+AWNJ+p3e4C6Z85f4+98Zo
PzHUFTXk1i29wLx9a/F33u4DOSQZe7hO0f79IGgQi/I2p5Gbt9/fxW4AnPf2
JaTwZ+i8QfBq0HfmqkgxaLebo1bMMAQksEVXH0rp/BFoCp/rqDWUYcCpRr3A
7lFoFiU0F8fLKJ4xuJD/bZ5AJENd3nONY9JxsDEtqD65IaP4JsAyP5/raMpg
658Mx4T7EtT57l+qOzMU7yQYSrkQHc7gle+5y0oGUzDs65M6fZOh+KdBTy3q
3eifGfzATn9m7Mg/wFXdpySpYCifGTin5v9JeTODQyzL4UYnKSSXW4VEiBnK
Twa3/3qjNXKUQWHdie7cIAZ2xHMzNqUM5UvgxUBp4ellBo2gbLzedhYS+3kV
aSxC+c+C8HzclEyF4GpW7VlzxzlIkzQXJ2kRqsccuFUO8kJ0CXbJW/pyPOfh
ikS7u3o3ofrMw+HaGa/rxgRLBF3OGgGvQHzP4mD/e4Tq9QpiDMXpzXyC16sH
2xIiFyDe9umIqwWh+i0Aq8pvXHiE4Nl3pj+XXV0E7cUw3SRrQvVcgqYV1rA5
EDwcu1DvnbIEIg/DR7mfEqrvMkwNtZtJ7Alq9G4dbc9YBlF+oc/ocUL1XoG8
9tu/1DgQnDykVvFxwQoUah5fCHYkVP9VKAzJaZx3ItiQrmNWUrYKp9tU+R4u
hPqxBhx3KSvblWDmvNFDvd/XwEauUf+HO6H+yMHEPLWow4NgpDN/z81WOaSo
X3taLyDUr3X4VTt17a43QYcyq6zVnnWIZme+9PIh1L8N0Kx+tIPnS9BY014n
eGwDJqscpgr8CPVzEwJbtR7wvyK4ftFJ+JzZhLZSjdjCrwn1dwvEl34MfSuA
YE+7gPeFfAv+Tm5ICAgk1G8W7uTnpT8OIti307Jp4DsWqnfYXiPBCv9ZaDl8
imcUStCu2SpRm8dGdm/J+LELijyw8be74gq/iwTLosHmpJCNug4quyIvKfLB
xp8eBOVeDiOov9d+NUmHg3q35jpjwhV54WBglMf+kAiCyd0nntRkcdC0r0fX
PVKRHw4+LpFoWEcRXExyiprfo4QFa+UROtGKPCmh5/1d92e2az8Ltw8PFCnh
jeA6Uh2jyJcSZlbWPbn2DcGOUYHMz1wZTRy0P7OLVeRNGdVCFySb27V1mm9x
ZqUyqi4daqm4rMifMhrY/mDvH0fwX+mDiyo=
         "]]}}}, {}}, {DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 0.000039999999999999996`}, {0, 0.9835687961112887}}, 
     PlotRangeClipping -> True, ImagePadding -> All, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {False, False}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     BaseStyle -> {
      "FontFamily" -> "Helvetica", FontSize -> 12, ImagePadding -> {{
          Scaled[0.035], 
          Scaled[0.01]}, {Automatic, Automatic}}}, DisplayFunction :> 
     Identity, Frame -> {{True, True}, {True, True}}, FrameLabel -> {{
        FormBox["\"Output\"", TraditionalForm], None}, {
        FormBox["\"Input (E1)\"", TraditionalForm], None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 350, 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
            Part[#, 1]], 
           (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
            Part[#, 2]]}& )}}, 
     PlotRange -> {{0, 0.000039999999999999996`}, {0, 0.9835687961112887}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"MAPKK-PP\"", "\"MAPK-PP\""}, "PointLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    RGBColor[1, 0, 0]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.16500000000000004`], 
                    AbsoluteThickness[1.6], ImagePadding -> {{
                    Scaled[0.035], 
                    Scaled[0.01]}, {Automatic, Automatic}}, 
                    RGBColor[1, 0, 0]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0, 0, 1]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.009166666666666668`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   RowBox[{"ImagePadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Scaled", "[", "0.035`", "]"}], ",", 
                    RowBox[{"Scaled", "[", "0.01`", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Automatic", ",", "Automatic"}], "}"}]}], "}"}]}],
                    ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0.6666666666666666, 0., 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[1, 0, 0]"], Appearance -> None, BaseStyle -> {},
                     BaselinePosition -> Baseline, DefaultBaseStyle -> {}, 
                    ButtonFunction :> With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0, 0], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.670490649757648*^9, 3.6716141038267813`*^9, 
  3.677554310811485*^9, 3.7132708719142647`*^9, 3.7132710417229776`*^9, 
  3.713271198018917*^9},
 ExpressionUUID -> "17d57bed-4a2b-41d6-9d91-a5ab642f7c4a"]
}, Open  ]],

Cell["\<\
Man erkennt, dass sich der Output der Kaskade unter dem linear anwachsenden \
Input wesentlich sprunghafter \[ADoubleDot]ndert als der Output der mittleren \
Ebene. Diese Alles-oder-nichts-Antwort ist eine Konsequenz der \
Kaskadenarchitektur und ist die in Huang und Ferrell (1996) als \
\[OpenCurlyQuote]Ultrasensitivit\[ADoubleDot]t\[CloseCurlyQuote] bezeichnete \
Signalantwort.\
\>", "Text",
 CellChangeTimes->{{3.6774852371241302`*^9, 3.67748524846535*^9}},
 ExpressionUUID -> "be884696-bd78-4de2-83d2-b8faed11930c"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "37"], TraditionalForm]],
  ExpressionUUID -> "93a99b43-62fb-4588-a27a-9dabbd119708"],
 " MASS steht f\[UDoubleDot]r ",
 StyleBox["Mass Action Stoichiometric Simulation",
  FontSlant->"Italic"],
 "; der Entwickler ist mittlerweile Forscher am ",
 StyleBox["Novo Nordisk Foundation Center for Biosustainability",
  FontSlant->"Italic"],
 " in Kopenhagen/D\[ADoubleDot]nemark."
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.674621151407549*^9, 3.6746211807235928`*^9}, {
   3.674622662511799*^9, 3.6746227213398905`*^9}, 3.674622755272942*^9, {
   3.6771332497970695`*^9, 3.6771332889727383`*^9}, {3.677397498260234*^9, 
   3.67739750751105*^9}, {3.6773975387493057`*^9, 3.6773975615877457`*^9}, {
   3.6773975998546133`*^9, 3.6773976298846655`*^9}, {3.6774853377815075`*^9, 
   3.677485341697114*^9}, {3.677485501500596*^9, 3.677485501500596*^9}, 
   3.6774855415800667`*^9},
 ExpressionUUID -> "fdd7392f-f960-4f43-8321-334ae62829db"]
}, Open  ]]
},
WindowSize->{505, 812},
WindowMargins->{{93, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 929, 37, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1512, 61, 435, 11, 66, "Subtitle"],
Cell[1950, 74, 1348, 32, 317, "Text"],
Cell[3301, 108, 238, 4, 52, "Input"],
Cell[3542, 114, 903, 15, 258, "Text"],
Cell[CellGroupData[{
Cell[4470, 133, 319, 5, 31, "Input"],
Cell[4792, 140, 1349171, 28609, 402, "Output"]
}, Open  ]],
Cell[1353978, 28752, 682, 12, 144, "Text"],
Cell[CellGroupData[{
Cell[1354685, 28768, 209, 3, 31, "Input"],
Cell[1354897, 28773, 27959, 850, 496, "Output"]
}, Open  ]],
Cell[1382871, 29626, 403, 9, 68, "Text"],
Cell[1383277, 29637, 573, 14, 31, "Input"],
Cell[CellGroupData[{
Cell[1383875, 29655, 547, 11, 72, "Input"],
Cell[1384425, 29668, 374986, 6680, 237, "Output"]
}, Open  ]],
Cell[1759426, 36351, 1669, 48, 220, "Text"],
Cell[1761098, 36401, 4415, 114, 158, "Input"],
Cell[1765516, 36517, 224, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[1765765, 36525, 1432, 38, 172, "Input"],
Cell[1767200, 36565, 16263, 324, 271, "Output"]
}, Open  ]],
Cell[1783478, 36892, 532, 9, 125, "Text"],
Cell[1784013, 36903, 1017, 21, 97, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

